<?php
/* @wordpress-plugin
 * Plugin Name: Advanced Local Pickup PRO
 * Plugin URI: https://www.zorem.com/products
 * Description: The Advanced Local Pickup Pro extends the free version and lets you set up multiple pickup locations, apply discounts for local pickup, display local pickup messages, split the business hours and more..
 * Version: 1.7.0
 * Author: zorem
 * Author URI: https://zorem.com 
 * License: GPLv3
 * License URI: http://www.gnu.org/licenses/gpl-3.0
 * Text Domain: advanced-local-pickup-pro
 * Domain Path: /lang/
 * WC tested up to: 8.3
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package zorem
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
//raz0r
update_option( 'zorem_license_connected', 1 );
update_option( 'zorem_license_email', 'mail@zorem.com' );
update_option( 'alp_pro_license_status', true );
update_option( 'alp_pro_license_key', '******************' );
class Advanced_Local_Pickup_PRO {

	/**
	 * Advanced Local Pickup PRO
	 *
	 * @var string
	 */
	public $version = '1.7.0';
	public $plugin_path;
	public $admin;
	public $install;
	public $license;
	public $email;
	public $common;
	public $session;
	public $per_item_session;
	public $ajax;
	public $fulfillment;
	public $customizer;

	/**
	 * Constructor
	 *
	 * @since  1.0.0
	*/
	public function __construct() {

		// Check if Wocoomerce is activated
		if ( $this->is_wc_active() ) {

			//deactivate free on activate pro plugin
			register_activation_hook( __FILE__, array( $this, 'on_activation' ) );
			add_action( 'upgrader_process_complete', array( $this, 'on_upgrade_plugin' ), 10, 2);

			//callback for notices hook in admin
			add_action( 'admin_notices', array( $this, 'not_allow_admin_notice' ) );
			add_action( 'admin_notices', array( $this, 'alp_pro_admin_notice' ) );

			$this->includes_for_all();

			require_once $this->get_plugin_path() . '/include/wc-alp-license.php';
			$this->license = Advanced_Local_Pickup_License::get_instance();

			//update-manager
			require_once $this->get_plugin_path() . '/include/wc-alp-update-manager.php';
			new Advanced_Local_Pickup_Update_Manager(
				$this->version,
				'advanced-local-pickup-pro/advanced-local-pickup-pro.php',
				$this->license->get_item_code()
			);	

			$subscription_status = $this->license->check_subscription_status();

			if ( $subscription_status ) { 
				$this->includes();
				$this->init();		
				add_action( 'admin_footer', array( $this, 'uninstall_notice') );
			}
			
		}
	}
	
	/**
	 * Check if WooCommerce is active
	 *
	 * @since  1.0.0
	 * @return bool
	*/
	private function is_wc_active() {
		
		if ( ! function_exists( 'is_plugin_active' ) ) {
			require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
		}
		if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			$is_active = true;
		} else {
			$is_active = false;
		}		

		// Do the WC active check
		if ( false === $is_active ) {
			add_action( 'admin_notices', array( $this, 'notice_activate_wc' ) );
		}		
		return $is_active;
	}
	
	/**
	 * Display WC active notice
	 *
	 * @since  1.0.0
	*/
	public function notice_activate_wc() {
		?>
		<div class="error">
			<p><?php printf( esc_html( 'Please install and activate %sWooCommerce%s for WC local pickup to work!', 'advanced-local-pickup-pro' ), '<a href="' . esc_url(admin_url( 'plugin-install.php?tab=search&s=WooCommerce&plugin-search-input=Search+Plugins' )) . '">', '</a>' ); ?></p>
		</div>
		<?php
	}
	
	/*
	 * @NOTICE: function callback in ALP Free
	 * not allow ALP free plugin activate
	 *
	 * @since  1.0.0
	*/
	public function not_allow_admin_notice() {
		if ( isset($_GET['alp-not-allow']) && 'true' == sanitize_text_field($_GET['alp-not-allow'])) {
			?>
			<div class="error">
				<p><?php printf( esc_html( "Please note, you can't activate the Advanced Local Pickup Free version when the PRO version is active.", 'advanced-local-pickup-for-woocommerce' ) ); ?></p>
			</div>
			<?php
		}
	}

	public function includes_for_all() {
		
		//includes
		require_once $this->get_plugin_path() . '/include/wc-alp-admin.php';
		$this->admin = Advanced_Local_Pickup_Admin::get_instance();	

		require_once $this->get_plugin_path() . '/include/wc-alp-installation.php';
		$this->install = Advanced_Local_Pickup_Installation::get_instance();
		
		//callback for migration function
		add_action( 'admin_init', array( $this->install , 'wclp_update_install_callback' ) );

	}

	/**
	 * Include plugin file.
	 *
	 * @since 1.0.0
	 *
	 */	
	public function includes() {		
		
		//includes
		require_once $this->get_plugin_path() . '/include/wc-alp-email-notification.php';
		$this->email = Advanced_Local_Pickup_Email::get_instance();
		
		require_once $this->get_plugin_path() . '/include/wc-alp-common-functions.php';
		$this->common = Advanced_Local_Pickup_Common_Functions::get_instance();

		require_once $this->get_plugin_path() . '/include/wc-alp-session.php';
		$this->session = Advanced_Local_Pickup_Session::get_instance();
		
		require_once $this->get_plugin_path() . '/include/wc-alp-per-item-session.php';
		$this->per_item_session = Advanced_Local_Pickup_Per_Item_Session::get_instance();
		
		require_once $this->get_plugin_path() . '/include/wc-alp-ajax.php';
		$this->ajax = Advanced_Local_Pickup_Ajax::get_instance();
		
		require_once $this->get_plugin_path() . '/include/wc-alp-fulfillment-dashboard.php';
		$this->fulfillment = ALP_Fulfillment_Dashboard::get_instance();	

		//customizer
		require_once $this->get_plugin_path() . '/include/customizer/customizer-admin.php';	
		$this->customizer = ALP_Customizer_Admin::get_instance();
		
	}
	
	/**
	 * Initialize plugin
	 *
	 * @since  1.0.0
	*/
	private function init() {
		
		// Load plugin textdomain
		add_action('plugins_loaded', array($this, 'load_textdomain'));
		
		add_action( 'wp_ajax_reassign_order_status', array( $this, 'reassign_order_status' ) );
		
		//callback for add action link for plugin page	
		add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'my_plugin_action_links' ) );
		
		// Add to custom email for WC Order statuses
		add_filter( 'woocommerce_email_classes', array( $this, 'custom_init_emails' ), 10 );
		add_action( 'woocommerce_order_status_processing-lp', array( $this, 'email_trigger_processing_lp' ), 10, 2 );
		add_action( 'woocommerce_order_status_ready-pickup', array( $this, 'email_trigger_ready_pickup' ), 10, 2 );
		add_action( 'woocommerce_order_status_pickup', array( $this, 'email_trigger_pickup' ), 10, 2 );
	}

	/**
	 * Gets the absolute plugin path without a trailing slash, e.g.
	 * /path/to/wp-content/plugins/plugin-directory.
	 *
	 * @return string plugin path
	 */
	public function get_plugin_path() {
		if ( isset( $this->plugin_path ) ) {
			return $this->plugin_path;
		}

		$this->plugin_path = untrailingslashit( plugin_dir_path( __FILE__ ) );
		return $this->plugin_path;
	}

	public static function get_plugin_domain() {
		return __FILE__;
	}

	/*
	* plugin file directory function
	*/	
	public function plugin_dir_url() {
		return plugin_dir_url( __FILE__ );
	}

	/*
	* free plugin deactivate on activation
	*/	
	public function on_activation() {
		deactivate_plugins('advanced-local-pickup-for-woocommerce/woo-advanced-local-pickup.php' );
		set_transient( 'free_alp_plugin', 'notice', 3 );
	}

	/*
	* free plugin deactivate on upgrade plugin
	*/	
	public function on_upgrade_plugin( $upgrader_object, $options ) {
		$current_plugin_path_name = plugin_basename( __FILE__ );
		
		if ( !empty($options) && 'update' == $options['action'] && 'plugin' == $options['type'] ) {
			foreach ($options['plugins'] as $each_plugin) {
				if ($each_plugin == $current_plugin_path_name) {
					deactivate_plugins('advanced-local-pickup-for-woocommerce/woo-advanced-local-pickup.php' );
					set_transient( 'free_alp_plugin', 'notice', 3 );
				}
			}
		}
	}

	/**
	 * ALP pro admin notice
	 *
	 * @since 1.0.0
	 */
	public function alp_pro_admin_notice() {
		
		//Display ALP Free notice
		if ( 'notice' == get_transient( 'free_alp_plugin' ) ) {
			?>
			<div id="message" class="updated notice is-dismissible">
				<p><?php printf( esc_html( 'We deactivated the Advanced Local Pickup Free version when the PRO is installed, you can remove the free version from your store.', 'advanced-local-pickup-pro' ), '<a href="' . esc_url(admin_url( 'plugin-install.php?tab=search&s=WooCommerce&plugin-search-input=Search+Plugins' )) . '">', '</a>' ); ?></p>
			</div>
			<?php
			delete_transient( 'free_alp_plugin' );
		}
	}

	/*
	* load text domain
	*/
	public function load_textdomain() {
		load_plugin_textdomain( 'advanced-local-pickup-pro', false, plugin_dir_path( plugin_basename(__FILE__) ) . 'lang/' );
	}

	/**
	 * Add plugin action links.
	 *
	 * Add a link to the settings page on the plugins.php page.
	 *
	 * @since 1.0.0
	 *
	 * @param  array  $links List of existing plugin action links.
	 * @return array         List of modified plugin action links.
	 */
	public function my_plugin_action_links( $links ) {
		$links = array_merge( array(
			'<a href="' . esc_url( admin_url( '/admin.php?page=local_pickup' ) ) . '">' . esc_html( 'Settings', 'woocommerce' ) . '</a>'
		), array(
			'<a href="' . esc_url( 'https://www.zorem.com/docs/local-pickup-pro/?utm_source=wp-admin&utm_medium=ALP&utm_campaign=docs' ) . '" target="_blank">' . esc_html( 'Docs', 'woocommerce' ) . '</a>'
		), array(
			'<a href="' . esc_url( 'https://www.zorem.com/my-account/contact-support/?utm_source=wp-admin&utm_medium=contact&utm_campaign=support' ) . '" target="_blank">' . esc_html( 'Support', 'woocommerce' ) . '</a>'
		), array(
			'<a href="' . esc_url( 'https://wordpress.org/support/plugin/advanced-local-pickup-for-woocommerce/reviews/#new-post' ) . '" target="_blank">' . esc_html( 'Review', 'woocommerce' ) . '</a>'
		), $links );
		
		return $links;
	}

	/*
	* Plugin uninstall code 
	*/	
	public function uninstall_notice() {
		$screen = get_current_screen();
		
		if ('plugins.php' != $screen->parent_file) {
			return;
		}
		
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';	
		wp_enqueue_style( 'alp-admin-js', plugin_dir_url(__FILE__) . 'assets/css/admin.css', array(), $this->version );
		wp_register_script( 'jquery-blockui', WC()->plugin_url() . '/assets/js/jquery-blockui/jquery.blockUI' . $suffix . '.js', array( 'jquery' ), '2.70', true );
		wp_enqueue_script( 'jquery-blockui' );
		
		$ready_pickup_count = wc_orders_count( 'ready-pickup' );
		$pickup_count = wc_orders_count( 'pickup' );
		
		$order_statuses = wc_get_order_statuses();
		unset($order_statuses['wc-ready-pickup']);				
		unset($order_statuses['wc-pickup']);
		
		if ($ready_pickup_count > 0 || $pickup_count > 0) { 
			?>
			<script>
				jQuery(document).on("click","[data-slug='advanced-local-pickup-pro'] .deactivate a",function(e) {			
					e.preventDefault();
					jQuery('.alp_uninstall_popup').show();
					var theHREF = jQuery(this).attr("href");
					jQuery(document).on("click",".alp_uninstall_plugin",function(e) {
						jQuery("body").block({
							message: null,
							overlayCSS: {
								background: "#fff",
								opacity: .6
							}	
						});	
						var form = jQuery('#wplp_order_reassign_form');
						jQuery.ajax({
							url: ajaxurl,		
							data: form.serialize(),		
							type: 'POST',		
							success: function(response) {
								jQuery("body").unblock();			
								window.location.href = theHREF;
							},
							error: function(response) {
								console.log(response);			
							}
						});				
					});			
				});
				jQuery(document).on("click",".alp_popupclose",function(e) {
					jQuery('.alp_uninstall_popup').hide();
				});
				jQuery(document).on("click",".alp_uninstall_close",function(e) {
					jQuery('.alp_uninstall_popup').hide();
				});
			</script>
			<div id="" class="alp_popupwrapper alp_uninstall_popup" style="display:none;">
				<div class="alp_popuprow" style="text-align: left;max-width: 380px;">
					<h3 class="alp_popup_title">Advanced Local Pickup for WooCommerce</h3>
					<form method="post" id="wplp_order_reassign_form">					
					<?php if ( $ready_pickup_count > 0 ) { ?>
						
						<p><?php echo sprintf(esc_html('We detected %s orders that use the Ready for pickup order status, You can reassign these orders to a different status', 'advanced-local-pickup-pro'), esc_html($ready_pickup_count)); ?></p>
						
						<select id="reassign_ready_pickup_order" name="reassign_ready_pickup_order" class="reassign_select">
							<option value=""><?php esc_html_e('Select', 'woocommerce'); ?></option>
							<?php foreach ($order_statuses as $key => $status) { ?>
								<option value="<?php echo esc_html($key); ?>"><?php echo esc_html($status); ?></option>
							<?php } ?>
						</select>
					
					<?php } ?>
					<?php if ( $pickup_count > 0 ) { ?>
						
						<p><?php echo sprintf(esc_html('We detected %s orders that use the Picked up order status, You can reassign these orders to a different status', 'advanced-local-pickup-pro'), esc_html($pickup_count)); ?></p>					
						
						<select id="reassign_pickedup_order" name="reassign_pickedup_order" class="reassign_select">
							<option value=""><?php esc_html_e('Select', 'woocommerce'); ?></option>
							<?php foreach ($order_statuses as $key => $status) { ?>
								<option value="<?php echo esc_html($key); ?>"><?php echo esc_html($status); ?></option>
							<?php } ?>
						</select>
					
					<?php } ?>				
					<p class="" style="text-align:left;">
						<input type="hidden" name="action" value="reassign_order_status">
						<input type="hidden" name="nonce" value="<?php echo esc_html(wp_create_nonce('alp-ajax-nonce')); ?>">
						<input type="button" value="Deactivate" class="alp_uninstall_plugin button-primary btn_green">
						<input type="button" value="Close" class="alp_uninstall_close button-primary btn_red">				
					</p>
				</form>	
				</div>
				<div class="alp_popupclose"></div>
			</div>		
		<?php 
		} 
	}

	public function reassign_order_status() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$reassign_ready_pickup_order = isset($_POST['reassign_ready_pickup_order']) ? sanitize_text_field($_POST['reassign_ready_pickup_order']) : '';
		$reassign_pickedup_order = isset($_POST['reassign_pickedup_order']) ? sanitize_text_field($_POST['reassign_pickedup_order']) : '';
		
		if ( isset($reassign_ready_pickup_order) && '' != $reassign_ready_pickup_order) {
			
			$args = array(
				'status' => 'ready-pickup',
				'limit' => '-1',
			);
			
			$orders = wc_get_orders( $args );
			
			foreach ($orders as $order) {				
				$order_id = $order->get_id();
				$order = new WC_Order($order_id);
				$order->update_status($reassign_ready_pickup_order);				
			}			
		}
		
		if ( isset($reassign_pickedup_order) && '' != $reassign_pickedup_order) {
			
			$args = array(
				'status' => 'pickup',
				'limit' => '-1',
			);
			
			$ps_orders = wc_get_orders( $args );
			
			foreach ($ps_orders as $order) {				
				$order_id = $order->get_id();
				$order = new WC_Order($order_id);
				$order->update_status($reassign_pickedup_order);				
			}			
		}
		exit;
		echo 1;
		die();		
	}

	// Add to custom email for WC Order statuses
	public function custom_init_emails( $emails ) {

		// Include the email class file if it's not included already
		if (!defined('WC_LOCAL_PICKUP_TEMPLATE_PATH')) {
			define('WC_LOCAL_PICKUP_TEMPLATE_PATH', alp_pro_addon()->get_plugin_path() . '/templates/');
		}

		$processing_lp = get_option( 'wclp_status_processing_lp', 0);
		if (true == $processing_lp) {
			if ( ! isset( $emails[ 'WC_Email_Customer_Processing_LP_Order' ] ) ) {
				$emails[ 'WC_Email_Customer_Processing_LP_Order' ] = include_once( 'include/emails/processing-lp-order.php' );
			}
		}

		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0 );
		if (true == $ready_for_pickup) {
			if ( ! isset( $emails[ 'WC_Email_Customer_Ready_Pickup_Order' ] ) ) {
				$emails[ 'WC_Email_Customer_Ready_Pickup_Order' ] = include_once( 'include/emails/ready-pickup-order.php' );
			}
		}
		$picked = get_option( 'wclp_status_picked_up', 0 );
		if (true == $picked) {
			if ( ! isset( $emails[ 'WC_Email_Customer_Pickup_Order' ] ) ) {
				$emails[ 'WC_Email_Customer_Pickup_Order' ] = include_once( 'include/emails/pickup-order.php' );
			}
		}

		return $emails;		
	}

	/**
	 * Send email when order status change to "processing LP"
	 *
	*/
	public function email_trigger_processing_lp( $order_id, $order = false ) {
		$processing_lp = get_option( 'wclp_status_processing_lp', 0 );
		if (true == $processing_lp) {
			WC()->mailer()->emails['WC_Email_Customer_Processing_LP_Order']->trigger( $order_id, $order );
		}
	}

	/**
	 * Send email when order status change to "ready for pickup"
	 *
	*/
	public function email_trigger_ready_pickup( $order_id, $order = false ) {
		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0 );
		if (true == $ready_for_pickup) {
			WC()->mailer()->emails['WC_Email_Customer_Ready_Pickup_Order']->trigger( $order_id, $order );
		}
	}

	/**
	 * Send email when order status change to "pickuped"
	 *
	*/
	public function email_trigger_pickup( $order_id, $order = false ) {	
		$picked = get_option( 'wclp_status_picked_up', 0 );
		if (true == $picked) {
			WC()->mailer()->emails['WC_Email_Customer_Pickup_Order']->trigger( $order_id, $order );
		}
	}

}

/**
 * Returns an instance of Advanced_Local_Pickup_PRO.
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 * @return Advanced_Local_Pickup_PRO
*/
function alp_pro_addon() {
	static $instance;

	if ( ! isset( $instance ) ) {		
		$instance = new Advanced_Local_Pickup_PRO();
	}

	return $instance;
}

/**
 * Register this class globally.
 *
 * Backward compatibility.
*/
alp_pro_addon();

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

if ( ! function_exists( 'zorem_tracking' ) ) {
	function zorem_tracking() {
		require_once dirname(__FILE__) . '/zorem-tracking/zorem-tracking.php';
		$plugin_name = 'Advanced Local Pickup PRO';
		$plugin_slug = 'advanced-local-pickup-pro';
		$user_id = '1';
		$setting_page_type = 'submenu';
		$setting_page_location =  "A submenu under other plugin's top level menu";
		$parent_menu_type = 'A custom top-level admin menu (admin.php)';
		$menu_slug = 'local_pickup';
		$plugin_id = '13';
		$zorem_tracking = WC_Trackers::get_instance( $plugin_name, $plugin_slug, $user_id, $setting_page_type, $setting_page_location, $parent_menu_type, $menu_slug, $plugin_id );


		return $zorem_tracking;
	}
	zorem_tracking();
}
