<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Advanced_Local_Pickup_Admin {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return Advanced_Local_Pickup_Admin
	*/
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	*/
	private static $instance;
	public $table;
	public $data;

	
	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	*/
	public function __construct() {
		$this->init();		
	}
	
	/*
	 * init function
	 *
	 * @since  1.0
	*/
	public function init() {

		//adding hooks
		
		add_action( 'admin_menu', array( $this, 'register_woocommerce_menu' ), 99 );
		add_filter( 'admin_body_class', array( $this, 'wp_body_classes') );

		//fulfillment hooks
		add_action( 'admin_menu', array( $this, 'register_alp_fulfillment_menu' ), 100 );
		add_filter( 'ast_fulfillment_tab_options', array( $this, 'alp_fulfillment_tab_option'), 10, 1 );
		add_action( 'ast_fulfillment_tab_page', array( $this, 'alp_fulfillment_tab_page' ) );

		//load javascript in admin
		add_action('admin_enqueue_scripts', array( $this, 'alp_script_enqueue' ) );

		// Register new status
		add_action( 'init', array( $this, 'register_pickup_order_status') );
		
		// Add to list of WC Order statuses
		add_filter( 'wc_order_statuses', array( $this, 'add_pickup_to_order_statuses') );
		add_filter( 'bulk_actions-edit-shop_order', array( $this, 'add_bulk_actions_change_order_status'), 50, 1 );
		add_filter( 'bulk_actions-woocommerce_page_wc-orders', array( $this, 'add_bulk_actions_change_order_status'), 50, 1 );			
		
		$wclp_local_pickup_message_controls = get_option('wclp_local_pickup_message_controls');
		if (isset($wclp_local_pickup_message_controls['display_message_product_page']) 
			&& 1 == $wclp_local_pickup_message_controls['display_message_product_page']) {
				$position = get_option('wclp_local_pickup_message_position', 33 );
				add_action( 'woocommerce_single_product_summary', array($this, 'meta_area_message' ), $position );
		}
		add_action( 'woocommerce_product_options_shipping', array( $this, 'product_options' ) );
		add_action( 'woocommerce_process_product_meta', array( $this, 'save_custom_product_fields' ) );
		
		// Add Addition content for processing email
		add_filter( 'woocommerce_admin_order_actions', array( $this, 'add_local_pickup_order_status_actions_button'), 100, 2 );
		add_filter( 'woocommerce_admin_order_preview_actions', array( $this, 'add_local_pickup_order_status_preview_actions_button'), 100, 2 );
		
		add_action( 'admin_footer', array( $this, 'footer_function'), 1 );
		
		add_filter( 'woocommerce_valid_order_statuses_for_order_again', array( $this, 'add_reorder_button_pickup'), 50, 1 );
		
		add_filter( 'woocommerce_hidden_order_itemmeta', array( $this, 'custom_woocommerce_hidden_order_itemmeta'), 10, 1 );
		
		add_action( 'wp_enqueue_scripts', array( $this, 'wclp_load_frontend_scripts' ) );
		
	}
	
	public function wp_body_classes( $classes ) {
		if ( isset($_GET['page']) && 'local_pickup' == $_GET['page']) {
			$classes .= ' woocommerce_page_local_pickup';
		}
		return $classes;
	}
	
	/*
	*  hide item meta data in order
	*/
	public function custom_woocommerce_hidden_order_itemmeta( $arr ) {
		$arr[] = 'Pickup location';
		return $arr;
	}

	
	/*
	* Admin Menu add function
	* WC sub menu 
	*/
	public function register_woocommerce_menu() {		
		add_submenu_page( 'woocommerce', 'Local Pickup', 'Local Pickup <strong style="color:#009933;">Pro</strong>', 'manage_options', 'local_pickup', array( $this, 'woocommerce_local_pickup_page_callback' ) ); //woocommerce_local_pickup_page_callback
	}
	
	/*
	* Admin Menu add function
	* WC sub menu 
	*/
	public function register_alp_fulfillment_menu() {
		
		$subscription_status = alp_pro_addon()->license->check_subscription_status();

		if ( $subscription_status ) { 
			if ( !class_exists('Ast_Pro') ) {
				add_submenu_page( 'woocommerce', __( 'Fulfillment', 'advanced-local-pickup-pro' ), __( 'Fulfillment', 'advanced-local-pickup-pro' ), 'manage_woocommerce', 'fulfillment-dashboard', array( alp_pro_addon()->fulfillment, 'alp_fulfillment_dashboard_page_callback' ) );				
				add_action('admin_footer', array( $this, 'admin_footer_enqueue_scripts' ), 10, 1 );
				
			}
			add_submenu_page( 'fulfillment-dashboard', esc_html__( 'Store Pickup', 'advanced-local-pickup-pro' ), esc_html__( 'Store Pickup', 'advanced-local-pickup-pro' ), 'manage_woocommerce', 'alp-fulfillment-dashboard', array( alp_pro_addon()->fulfillment, 'alp_fulfillment_dashboard_page_callback' ) );
		}		

	}

	/*
	* Add panel in AST fulfillment menu
	*/	
	public function alp_fulfillment_tab_option( $setting_data ) {
		$setting_data['local_pickup_orders'] = array(					
			'title'		=> __( 'Local Pickup Orders', 'advanced-local-pickup-pro' ),
			'show'      => true,
			'class'     => 'tab_label',
			'data-tab'  => 'local-pickup-orders',
			'data-label' => __( 'Local Pickup Orders', 'advanced-local-pickup-pro' ),
			'name'  => 'tabs',
		);		
		return $setting_data;
	}

	/*
	* Add panel in AST fulfillment menu
	*/	
	public function alp_fulfillment_tab_page() {
		require_once( 'views/fulfillment_dashboard.php' );
	}
	
	/*
	* Add admin javascript
	*/	
	public function alp_script_enqueue() {
		
		
		// Add condition for css & js include for admin page  
		$page = isset($_GET['page']) ? sanitize_text_field($_GET['page']) : '';
		
		if ( 'local_pickup' != $page ) {
			return;
		}

		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';	
		// Add the color picker css file       
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
			
		// Add the WP Media 
		wp_enqueue_media();
		
		// Add tiptip js and css file
		wp_register_style( 'woocommerce_admin_styles', WC()->plugin_url() . '/assets/css/admin.css', array(), WC_VERSION );
		wp_enqueue_style( 'woocommerce_admin_styles' );

		wp_register_script( 'jquery-tiptip', WC()->plugin_url() . '/assets/js/jquery-tiptip/jquery.tipTip.min.js', array( 'jquery' ), WC_VERSION, true );
		wp_register_script( 'jquery-blockui', WC()->plugin_url() . '/assets/js/jquery-blockui/jquery.blockUI' . $suffix . '.js', array( 'jquery' ), '2.70', true );
		wp_enqueue_script( 'jquery-tiptip' );
		wp_enqueue_script( 'jquery-blockui' );
		
		// Add jquery-ui js file
		//wp_enqueue_script('alp-ui-js', alp_pro_addon()->plugin_dir_url() . 'assets/js/jquery-ui.js', array(), alp_pro_addon()->version );
		wp_enqueue_script('alp-ui-min-js', alp_pro_addon()->plugin_dir_url() . 'assets/js/jquery-ui.min.js', array(), alp_pro_addon()->version );
		wp_enqueue_style('alp-ui', alp_pro_addon()->plugin_dir_url() . 'assets/css/jquery-ui.css', array(), alp_pro_addon()->version);

		//MultiDatesPicker library
		wp_enqueue_style( 'MultiDatesPicker-css', alp_pro_addon()->plugin_dir_url() . 'assets/css/jquery-ui.multidatespicker.css', array(), '1.6.4', 'all');				
		wp_enqueue_script( 'MultiDatesPicker-js', alp_pro_addon()->plugin_dir_url() . 'assets/js/jquery-ui.multidatespicker.js', array ( 'jquery' ), '1.6.4', true);
		
		// Add select2 js file
		wp_enqueue_style('select2-wclp', alp_pro_addon()->plugin_dir_url() . 'assets/css/select2.min.css', array(), alp_pro_addon()->version );
		wp_enqueue_script('select2-wclp', alp_pro_addon()->plugin_dir_url() . 'assets/js/select2.min.js', array(), alp_pro_addon()->version );
		
		wp_enqueue_script( 'alp-admin-js', alp_pro_addon()->plugin_dir_url() . 'assets/js/admin.js', array(), alp_pro_addon()->version );
		wp_enqueue_style( 'alp-admin-css', alp_pro_addon()->plugin_dir_url() . 'assets/css/admin.css', array(), alp_pro_addon()->version );
		
		wp_localize_script( 'alp-admin-js', 'alp_object', 
			array( 
				'admin_url' => admin_url(),
				'nonce' => wp_create_nonce('alp-ajax-nonce')
			) 
		);
	}
	
	/*
	 * Add admin javascript
	 *
	 * @since  2.4
	 * WC sub menu 
	*/
	public function admin_footer_enqueue_scripts() {
		?>
		<style type="text/css">
			#toplevel_page_fulfillment-dashboard .wp-first-item { display: none !important; }
		</style>
		<?php
	}
	
	/*
	* callback for Advanced Local Pickup page
	*/
	public function woocommerce_local_pickup_page_callback() {		
		$tab = isset( $_GET['tab'] ) ? sanitize_text_field($_GET['tab']) : '';
		$section = isset( $_GET['section'] ) ? sanitize_text_field($_GET['section']) : '';
		?>
		<div class="zorem-layout__header">
			<?php if ( 'edit' !== $section && 'add' !== $section ) { ?>
				<img class="zorem-layout__header-logo" src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__)) . 'assets/images/alp-logo.png'; ?>">
			<?php } else { ?>
				<h1 class="tab_section_heading">
					<a href="<?php echo esc_url(admin_url() . 'admin.php?page=local_pickup&tab=locations'); ?>" class="link decoration"><?php esc_html_e( 'Pickup Locations', 'advanced-local-pickup-pro' ); ?></a> > 
					<?php esc_html_e( 'Edit Pickup Location', 'advanced-local-pickup-pro' ); ?>
				</h1>
			<?php } ?>
			<div class="woocommerce-layout__activity-panel">
				<div class="woocommerce-layout__activity-panel-tabs">
					<button type="button" id="activity-panel-tab-help" class="components-button woocommerce-layout__activity-panel-tab">
						<span class="dashicons dashicons-editor-help"></span>
						Help 
					</button>
				</div>
				<div class="woocommerce-layout__activity-panel-wrapper">
					<div class="woocommerce-layout__activity-panel-content" id="activity-panel-true">
						<div class="woocommerce-layout__activity-panel-header">
							<div class="woocommerce-layout__inbox-title">
								<p class="css-activity-panel-Text">Documentation</p>            
							</div>								
						</div>
						<div>
							<ul class="woocommerce-list woocommerce-quick-links__list">
								<li class="woocommerce-list__item has-action">
									<?php
									$support_link = class_exists( 'Advanced_local_pickup_PRO' ) ? 'https://www.zorem.com/?support=1' : 'https://wordpress.org/support/plugin/advanced-local-pickup-for-woocommerce/#new-topic-0' ;
									?>
									<a href="<?php echo esc_url( $support_link ); ?>" class="woocommerce-list__item-inner" target="_blank" >
										<div class="woocommerce-list__item-before">
											<img src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__)) . 'assets/images/get-support-icon.svg'; ?>" >
										</div>
										<div class="woocommerce-list__item-text">
											<span class="woocommerce-list__item-title">
												<div class="woocommerce-list-Text">Get Support</div>
											</span>
										</div>
										<div class="woocommerce-list__item-after">
											<span class="dashicons dashicons-arrow-right-alt2"></span>
										</div>
									</a>
								</li>            
								<li class="woocommerce-list__item has-action">
									<a href="https://www.zorem.com/docs/advanced-local-pickup-for-woocommerce/?utm_source=wp-admin&utm_medium=ALPDOCS&utm_campaign=add-ons" class="woocommerce-list__item-inner" target="_blank">
										<div class="woocommerce-list__item-before">
											<img src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__)) . 'assets/images/documentation-icon.svg'; ?>" >
										</div>
										<div class="woocommerce-list__item-text">
											<span class="woocommerce-list__item-title">
												<div class="woocommerce-list-Text">Documentation</div>
											</span>
										</div>
										<div class="woocommerce-list__item-after">
											<span class="dashicons dashicons-arrow-right-alt2"></span>
										</div>
									</a>
								</li>
								<?php if ( !class_exists( 'Advanced_local_pickup_PRO' ) ) { ?>
									<li class="woocommerce-list__item has-action">
										<a href="https://www.zorem.com/product/advanced-local-pickup-for-woocommerce/?utm_source=wp-admin&utm_medium=ALP&utm_campaign=add-ons" class="woocommerce-list__item-inner" target="_blank">
											<div class="woocommerce-list__item-before">
												<span class="dashicons dashicons-media-document"></span>
											</div>
											<div class="woocommerce-list__item-text">
												<span class="woocommerce-list__item-title">
													<div class="woocommerce-list-Text">Upgrade To Pro</div>
												</span>
											</div>
											<div class="woocommerce-list__item-after">
												<span class="dashicons dashicons-arrow-right-alt2"></span>
											</div>
										</a>
									</li>
								<?php } ?>
							</ul>
						</div>
					</div>
				</div>
			</div>	
		</div>
		<div class="woocommerce wclp_admin_layout">
			<div class="wclp_admin_content">
				<?php 
				$style = '';
				if ( 'edit' == $section || 'add' == $section ) {
					$style = 'style=display:none;';
				} 

				$subscription_status = alp_pro_addon()->license->check_subscription_status();

				if ( $subscription_status ) { 
					?>
					<input id="tab1" type="radio" name="tabs" class="wclp_tab_input" data-label="<?php esc_html_e('Settings', 'woocommerce'); ?>" data-tab="settings" checked>
					<a for="tab1" href="admin.php?page=local_pickup&tab=settings" class="wclp_tab_label first_label <?php echo ( 'settings' === $tab ) ? 'nav-tab-active' : ''; ?>" <?php esc_html_e($style); ?>><?php esc_html_e('Settings', 'woocommerce'); ?></a>
					<input id="tab3" type="radio" name="tabs" class="wclp_tab_input" data-label="<?php esc_html_e('Pickup Locations', 'advanced-local-pickup-pro'); ?>" data-tab="locations" <?php echo ( 'locations' == $tab ) ? 'checked' : ''; ?>>
					<a for="tab3" href="admin.php?page=local_pickup&tab=locations" class="wclp_tab_label <?php echo ( 'locations' === $tab ) ? 'nav-tab-active' : ''; ?>" <?php esc_html_e($style); ?>><?php esc_html_e('Pickup Locations', 'advanced-local-pickup-pro'); ?></a>
					<input id="tab5" type="radio" name="tabs" class="wclp_tab_input" data-label="<?php esc_html_e('Customize', 'advanced-local-pickup-pro'); ?>" data-tab="customize" <?php echo ( 'customize' == $tab ) ? 'checked' : ''; ?>>
					<a for="tab5" href="<?php echo esc_url(admin_url() . 'admin.php?page=alp_customizer&preview=ready_pickup'); ?>" class="wclp_tab_label <?php echo ( 'customize' === $tab ) ? 'nav-tab-active' : ''; ?>" <?php esc_html_e($style); ?>><?php esc_html_e('Customize', 'advanced-local-pickup-pro'); ?></a>
					<input id="tab4" type="radio" name="tabs" class="wclp_tab_input" data-label="<?php esc_html_e('License', 'advanced-local-pickup-pro'); ?>" data-tab="license" <?php echo ( 'license' == $tab ) ? 'checked' : ''; ?> >
					<a for="tab4" href="admin.php?page=local_pickup&tab=license" class="wclp_tab_label <?php echo ( 'license' === $tab ) ? 'nav-tab-active' : ''; ?>" <?php esc_html_e($style); ?>><?php esc_html_e('License', 'advanced-local-pickup-pro'); ?></a>
					<div class="menu_devider" <?php esc_html_e($style); ?>></div> 
					<?php
					require_once( 'views/wclp_setting_tab.php' );
					require_once( 'views/wclp_locations_tab.php' );
					require_once( 'views/wclp_addon_tab.php' );
				} else {
					?>
					<input id="tab4" type="radio" name="tabs" class="wclp_tab_input" data-label="<?php esc_html_e('License', 'advanced-local-pickup-pro'); ?>" data-tab="license" checked>
					<a for="tab4" href="admin.php?page=local_pickup&tab=license" class="wclp_tab_label nav-tab-active" <?php esc_html_e($style); ?>><?php esc_html_e('License', 'advanced-local-pickup-pro'); ?></a>
					<div class="menu_devider" <?php esc_html_e($style); ?>></div> 
					<?php
					require_once( 'views/wclp_addon_tab.php' );
				}
				?>
			</div>
		</div>
		<?php
	}
	
	/*
	* get all data 
	*/
	public function get_data() {
		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';
		// Avoid database table not found errors when plugin is first installed
		// by checking if the plugin option exists
		if ( empty( $this->data ) ) {
			$this->data = array();

			$wpdb->hide_errors();
			
			$results = $wpdb->get_results( $wpdb->prepare('SELECT * FROM %1s ORDER BY position ASC', $this->table) );//ORDER BY name ASC	
	
			$this->data = $results;
		}
		return $this->data;
	}

	/*
	* get all data with available location
	*/
	public function get_available_locations_data() {
		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';
		// Avoid database table not found errors when plugin is first installed
		// by checking if the plugin option exists
		if ( empty( $this->data ) ) {
			$this->data = array();

			$wpdb->hide_errors();
			
			$results = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1s WHERE store_enable = 1 ORDER BY position ASC', $this->table) );//ORDER BY name ASC	
	
			$this->data = $results;
		}
		return $this->data;
	}
	
	/*
	* get data by id
	*/
	public function get_data_byid( $id ) {
		global $wpdb;

		$this->table = $wpdb->prefix . 'alp_pickup_location';
		
		$results = $wpdb->get_row( $wpdb->prepare( 'SELECT * FROM %1s WHERE id = %2d', $this->table, $id ) );
		
		$results = $this->get_slaches_data_byid($results);
		
		return $results;
	}
	
	/**
	 * Remove slashes from strings, arrays and objects
	 * 
	 * @param    mixed   input data
	 * @return   mixed   cleaned input data
	 */
	public function get_slaches_data_byid( $results ) {

		//WPML string tranlate filters
		global $sitepress;

		if (is_array($results)) {
			$results = array_map('get_slaches_data_byid', $results);
		} elseif (is_object($results)) {
			$vars = get_object_vars($results);
			foreach ($vars as $k=>$v) {
				if ( $sitepress ) {
					$v = apply_filters( 'wpml_translate_single_string', $v, 'advanced-local-pickup-pro', $v );
				}
				$results->$k = stripslashes($v);
			}
		} else {
			if ( $sitepress ) {
				$results = apply_filters( 'wpml_translate_single_string', $results, 'advanced-local-pickup-pro', $results );
			}
			$results = isset($results) ? stripslashes($results) : '';
		}
		return $results;
	}
	
	// Register new status
	public function register_pickup_order_status() {
		
		$processing_lp = get_option( 'wclp_status_processing_lp', 0);
		if (true == $processing_lp) {
			register_post_status( 'wc-processing-lp', array(
				'label'                     => esc_html__( 'Processing LP', 'advanced-local-pickup-pro' ),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				/* translators: %s: search term */
				'label_count'               => _n_noop( 'Processing LP (%s)', 'Processing LP (%s)' )
			) );
		}

		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0);
		if (true == $ready_for_pickup) {
			register_post_status( 'wc-ready-pickup', array(
				'label'                     => esc_html__( 'Ready for Pickup', 'advanced-local-pickup-pro' ),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				/* translators: %s: search term */
				'label_count'               => _n_noop( 'Ready for Pickup (%s)', 'Ready for Pickup (%s)' )
			) );
		}
		
		$picked = get_option( 'wclp_status_picked_up', 0);
		if (true == $picked) {
			register_post_status( 'wc-pickup', array(
				'label'                     => esc_html__( 'Picked up', 'advanced-local-pickup-pro' ),
				'public'                    => true,
				'exclude_from_search'       => false,
				'show_in_admin_all_list'    => true,
				'show_in_admin_status_list' => true,
				/* translators: %s: search term */
				'label_count'               => _n_noop( 'Picked up (%s)', 'Picked up (%s)' ) 
			) );
		}
		
	}
	
	// Add to list of WC Order statuses
	public function add_pickup_to_order_statuses( $order_statuses ) {
	 
		$new_order_statuses = array();
	 
		// add new order status after processing
		foreach ( $order_statuses as $key => $status ) {
	 
			$new_order_statuses[ $key ] = $status;

			$processing_lp = get_option( 'wclp_status_processing_lp', 0);
			if (true == $processing_lp) {
				if ( 'wc-processing' === $key ) {
					$new_order_statuses['wc-processing-lp'] = esc_html__( 'Processing LP', 'advanced-local-pickup-pro' );
				}
			}

			$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0);
			if (true == $ready_for_pickup) {
				if ( 'wc-processing-lp' === $key ) {
					$new_order_statuses['wc-ready-pickup'] = esc_html__( 'Ready for Pickup', 'advanced-local-pickup-pro' );
				}
				if ( 'wc-processing' === $key ) {
					$new_order_statuses['wc-ready-pickup'] = esc_html__( 'Ready for Pickup', 'advanced-local-pickup-pro' );
				}
			}
			
			$picked = get_option( 'wclp_status_picked_up', 0);
			if (true == $picked) {
				if ( 'wc-processing-lp' === $key ) {
					$new_order_statuses['wc-pickup'] = esc_html__( 'Picked up', 'advanced-local-pickup-pro' );
				}
				if ( 'wc-processing' === $key ) {
					$new_order_statuses['wc-pickup'] = esc_html__( 'Picked up', 'advanced-local-pickup-pro' );
				}
			}
		}
	 
		return $new_order_statuses;
	}
	
	// Add bulk action change status to custom order status
	public function add_bulk_actions_change_order_status( $bulk_actions ) {
		$processing_lp = get_option( 'wclp_status_processing_lp', 0);
		if (true == $processing_lp) {
			$bulk_actions['mark_processing-lp'] = esc_html__( 'Change status to Processing LP', 'advanced-local-pickup-pro' );
		}
		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0);
		if (true == $ready_for_pickup) {
			$bulk_actions['mark_ready-pickup'] = esc_html__( 'Change status to ready for pickup', 'advanced-local-pickup-pro' );
		}
		$picked = get_option( 'wclp_status_picked_up', 0);
		if (true == $picked) {
			$bulk_actions['mark_pickup'] = esc_html__( 'Change status to picked up', 'advanced-local-pickup-pro' );
		}
		return $bulk_actions;		
	}
	
	/*
	* alp message for local pickup item on product page
	*/
	public function meta_area_message() {
		global $product;
		if ($product->is_virtual()) {
			return;
		}
		$product_id = $product->get_id();
		$message = get_option('wclp_local_pickup_message_content');
		
		if ( alp_pro_addon()->common->is_local_pickup_item($product_id) ) {
			if (!empty($message)) {
				echo '<p>' . esc_html(stripslashes($message)) . '</p>';	
			} else {
				echo '<p>This Product is available for local Pickup.</p>';	
			}
		}
	}
	
	/**
	 * Output product options for force local pickup
	 */
	public function product_options() {
		global $post, $wpdb;

		echo '</div><div class="options_group per_product_pickedup">';

		woocommerce_wp_checkbox( array(
			'id'          => '_per_product_pickedup',
			'label'       => esc_html__( 'Force local pickup', 'advanced-local-pickup-pro' ),
			'description' => esc_html__( 'only allow local pickup orders for this product', 'advanced-local-pickup-pro' ),
		) );

	}
	
	/*
	* Save the product meta settings of force local pickup for simple product 
	*
	* @para $post_id
	*/
	public function save_custom_product_fields( $post_id ) {
		$_per_product_pickedup = ! empty( $_POST['_per_product_pickedup'] ) ? 'yes' : 'no';
		update_post_meta( $post_id, '_per_product_pickedup', $_per_product_pickedup );
	}
	
	public function wclp_general_setting_fields_func() {		
		$show_pickup_instraction_option = array( 
			'display_in_order_details_page' => esc_html__( 'My Account (orders history)', 'advanced-local-pickup-pro' ),
			'display_in_order_received_page' => esc_html__( 'Order received page', 'advanced-local-pickup-pro' ),			
		);
		
		$order_statuses_array = wc_get_order_statuses();
		unset($order_statuses_array['wc-processing-lp']);
		unset($order_statuses_array['wc-ready-pickup']);
		unset($order_statuses_array['wc-pickup']);
		$order_statuses_array['customer_invoice'] = 'Customer Invoice';
		$order_statuses_array['customer_note'] = 'Customer note';
		
		if ( class_exists( 'SMS_for_WooCommerce' ) ) { 
			$show = true;
		} else {
			$show = false;
		}
			
		$settings = array(						
			'wclp_show_pickup_instruction' => array(
				'id'       => 'wclp_show_pickup_instruction',
				'css'      => 'min-width:50px;',
				'default'  => '',
				'show'	   => true,
				'type'     => 'multiple_checkbox',
				'options'  => $show_pickup_instraction_option,
				'class'	   => '',
				'desc_tip' => '',
			),
			'wclp_display_pickup_instruction_statuses' => array(
				'title'    => esc_html__( 'Additional order emails display', 'advanced-local-pickup-pro' ),
				'tooltip'  => esc_html__( 'you can choose multiple order statuses for display pickup instruction in emails.', 'advanced-local-pickup-pro' ),
				'id'       => 'wclp_display_pickup_instruction_statuses',
				'css'      => 'min-width:50px;',
				'show'	   => true,
				'multiple' => 'wclp_display_pickup_instruction_statuses[]',
				'type'     => 'dropdown',
				'class'	   => 'display_pickup_instruction_statuses',
				'options'	=> $order_statuses_array,
			),
			'wclp_emails_additional_content' => array(
				'title'    => esc_html__( 'Additional content on additional emails', 'advanced-local-pickup-pro' ),
				'tooltip'  => esc_html__( 'Additional content on additional emails', 'advanced-local-pickup-pro' ),
				'id'       => 'wclp_emails_additional_content',
				'css'      => 'min-width:50px;',
				'default'  => esc_html__( 'You will receive an email when your order is ready for pickup.', 'advanced-local-pickup-pro' ),
				'placeholder' => esc_html__( 'Additional content on emails in case of local pickup orders', 'advanced-local-pickup-pro' ),
				'show'	   => true,
				'type'     => 'textarea',
				'class'	   => 'additional_textarea',
				'desc_tip' => '',
			),
		);
		return $settings;
		
	}
	
	public function wclp_dashboard_setting_fields_func() {
		
		$action_order_status_array = wc_get_order_statuses();
			
		$settings = array(
			'alp_order_display_in_fulfillment_dashboard' => array(
				'title'    => esc_html__( 'Order statuses to display', 'advanced-local-pickup-pro' ),
				'tooltip'  => esc_html__( 'You can choose multiple order statuses for display order in fulfillment dashboard.', 'advanced-local-pickup-pro' ),
				'id'       => 'alp_order_display_in_fulfillment_dashboard',
				'css'      => 'min-width:50px;',
				'show'	   => true,
				'multiple' => 'alp_order_display_in_fulfillment_dashboard[]',
				'type'     => 'dropdown',
				'class'	   => 'order_display_in_fulfillment_dashboard',
				'options'	=> $action_order_status_array,
			),
		);
		return $settings;
		
	}
	
	/*
	* add local pickup options field function
	*/
	public function wclp_local_pickup_setting_fields_func() {		
		
		$wclp_local_pickup_options = array(
			'allow_mixed_orders' => esc_html__( 'Allow mixed orders -  local pickup / shipping', 'advanced-local-pickup-pro' ),
			'allow_pickup_per_item' => esc_html__( 'Allow pickup per item ', 'advanced-local-pickup-pro' ),
			'display_location_address' => esc_html__( 'Display local pick address on cart/checkout', 'advanced-local-pickup-pro' ),	
		);

		$wclp_cart_checkout_layout = array( 
			'inline' => esc_html__( 'Inline', 'advanced-local-pickup-pro' ),
			'popup' => esc_html__( 'Popup', 'advanced-local-pickup-pro' ),
		);
		
		$wclp_pickup_location_sort = array( 
			'manual' => esc_html__( 'Manually', 'advanced-local-pickup-pro' ),
			'distance' => esc_html__( 'Distance', 'advanced-local-pickup-pro' ),
		);

		$processing_lp = get_option( 'wclp_status_processing_lp', 0);
		if ( true == $processing_lp ) {
			$show = true;
		} else {
			$show = false;
		}

		$settings = array(	
			'wclp_cart_checkout_layout' => array(
				'title'    => esc_html__( 'Select pickup location layout', 'advanced-local-pickup-pro' ),				
				'id'       => 'wclp_cart_checkout_layout',
				'css'      => '',
				'default'  => '',
				'show'	   => true,
				'type'     => 'dropdown',
				'options'  => $wclp_cart_checkout_layout,
				'class'	   => 'wclp_cart_checkout_layout',
				'desc_tip' => '',
			),
			'wclp_pickup_location_sort' => array(
				'title'    => esc_html__( 'Pickup locations sort by', 'advanced-local-pickup-pro' ),				
				'id'       => 'wclp_pickup_location_sort',
				'css'      => '',
				'default'  => '',
				'show'	   => true,
				'type'     => 'dropdown',
				'options'  => $wclp_pickup_location_sort,
				'class'	   => 'wclp_pickup_location_sort',
				'desc_tip' => '',
			),
			'wclp_google_maps_apikey' => array(
				'title'    => esc_html__( 'Google map API-key', 'advanced-local-pickup-pro' ),
				'id'       => 'wclp_google_maps_apikey',
				'css'      => 'min-width:50px;',
				'placeholder' => esc_html__( 'Enter the API-key', 'advanced-local-pickup-pro' ),
				'show'	   => true,
				'type'     => 'text',
				'class'	   => 'wclp_google_maps_apikey',
				'afterDiv' => '<a href="https://docs.zorem.com/docs/advanced-local-pickup-pro/how-to/how-to-get-your-google-map-api-credentials/" target="_blank">How to get your Google Map API credentials?</a>',
			),
			'allow_force_date_selection' => array(
				'title'    => esc_html__( 'Allow force date selection', 'advanced-local-pickup-pro' ),				
				'id'       => 'allow_force_date_selection',
				'css'      => '',
				'default'  => '',
				'show'	   => true,
				'type'     => 'checkbox',
				'class'	   => 'allow_force_date_selection',
				'desc_tip' => '',
			),
			'enable_processing_lp_automation' => array(
				'title'    => esc_html__( 'Automatically change the order status from processing to processing LP for local pickup orders', 'advanced-local-pickup-pro' ),				
				'id'       => 'enable_processing_lp_automation',
				'css'      => '',
				'default'  => '',
				'show'	   => $show,
				'type'     => 'checkbox',
				'class'	   => 'enable_processing_lp_automation',
				'desc_tip' => '',
			),			
			'wclp_local_pickup_controls' => array(
				'id'       => 'wclp_local_pickup_controls',
				'css'      => 'min-width:50px;',
				'default'  => '',
				'show'	   => true,
				'type'     => 'multiple_checkbox',
				'options'  => $wclp_local_pickup_options,
				'class'	   => 'local_pickup_control_options',
				'desc_tip' => '',
			),
		);
		return $settings;
		
	}
	
	/*
	* add local pickup options field function
	*/
	public function wclp_local_pickup_message_setting_fields_func() {		
		
		$wclp_local_pickup_message_options = array( 
			'display_message_product_page' => esc_html__( 'Display local pickup message on the product page', 'advanced-local-pickup-pro' ),		
		);
		$settings = array(						
			'wclp_local_pickup_message_controls' => array(
				'id'       => 'wclp_local_pickup_message_controls',
				'css'      => 'min-width:50px;',
				'default'  => '',
				'show'	   => true,
				'type'     => 'multiple_checkbox',
				'options'  => $wclp_local_pickup_message_options,
				'class'	   => '',
				'desc_tip' => '',
			),
			'wclp_local_pickup_message_position' => array(
				'title'    => esc_html__( 'Product page message location', 'advanced-local-pickup-pro' ),				
				'id'       => 'wclp_local_pickup_message_position',
				'css'      => 'min-width:50px;',
				'default'  => '33',
				'show'	   => true,
				'type'     => 'dropdown',
				'class'	   => 'drodown_position',
				'options'	=> array(
					'3'			=> esc_html__( 'Before title', 'advanced-local-pickup-pro' ),
					'8'			=> esc_html__( 'After title', 'advanced-local-pickup-pro' ),
					'13'		=> esc_html__( 'After price', 'advanced-local-pickup-pro' ),
					'23'		=> esc_html__( 'After short description', 'advanced-local-pickup-pro' ),
					'33'		=> esc_html__( 'After add to cart', 'advanced-local-pickup-pro' ),
					'43'		=> esc_html__( 'After meta', 'advanced-local-pickup-pro' ),
					'53'		=> esc_html__( 'After sharing', 'advanced-local-pickup-pro' ),
				),
				'desc_tip' => '',
			),
			'wclp_local_pickup_message_content' => array(
				'title'    => esc_html__( 'Product page message', 'advanced-local-pickup-pro' ),
				'tooltip'  => esc_html__( 'This is a local pickup message for product page', 'advanced-local-pickup-pro' ),
				'id'       => 'wclp_local_pickup_message_content',
				'css'      => 'min-width:50px;',
				'default'  => esc_html__( 'This product is available for local Pickup.', 'advanced-local-pickup-pro' ),
				'placeholder' => esc_html__( 'This product is available for local Pickup.', 'advanced-local-pickup-pro' ),
				'show'	   => true,
				'type'     => 'textarea',
				'class'	   => 'message_textarea',
				'desc_tip' => '',
			),
		);
		return $settings;
		
	}
	
	/*
	* get html of fields
	*/
	public function get_html2( $arrays ) {
		
		$checked = '';
		?>
		<?php 
		foreach ( (array) $arrays as $id => $array ) {
			if ($array['show']) {	
				?>
		<?php if ('dropdown' == $array['type']) { ?>               	
			<tr valign="top" class="html2_title_row <?php echo esc_html($array['class']); ?>">
				<?php if ( !empty($array['title']) && isset($array['title'])) { ?>										
				<th><ul class="row-label">
					<li for=""><?php echo esc_html($array['title']); ?>
						<?php 
						if (isset($array['title_link'])) { 
							echo esc_html($array['title_link']); 
						} 
						?>
						<?php if ( isset($array['tooltip']) ) { ?>
							<span class="woocommerce-help-tip tipTip" title="<?php echo esc_html($array['tooltip']); ?>"></span>
						<?php } ?>
					</li>
					<?php if ( isset($array['desc_tip']) ) { ?>
							<p class="description"><?php echo esc_html($array['desc_tip']); ?></p>
						<?php } ?>
					<?php if ( isset( $array['type'] ) && 'dropdown' == $array['type'] ) { ?>
						<?php
							if ( isset($array['multiple']) ) {
								$multiple = 'multiple';
								$field_id = $array['multiple'];
							} else {
								$multiple = '';
								$field_id = $id;
							}
							?>
						<li>
							<select class="select select2" id="<?php echo esc_html($id); ?>" name="<?php echo esc_html($field_id); ?>" <?php echo esc_html($multiple); ?> style="width:150px;"> <?php foreach ( (array) $array['options'] as $key => $val ) { ?>
									<?php
									$selected = '';
									if ( isset($array['multiple']) ) {
										if (in_array($key, (array) get_option($array['id']))) {
											$selected = 'selected';
										}
									} else {
										if ( get_option($array['id']) == (string) $key ) {
											$selected = 'selected';
										}
									}
									?>
									<option value="<?php echo esc_html($key); ?>" <?php echo esc_html($selected); ?> ><?php echo esc_html($val); ?></option>
								<?php } ?><p class="description"><?php echo ( isset($array['desc']) ) ? esc_html($array['desc']) : ''; ?></p>
							</select>
						</li>
					<?php } ?></ul>
				</th>
				<?php } ?>
			</tr>
			<?php 
				}
				if ( !empty($array['title']) && 'textarea' == $array['type'] ) { 
					?>
		<tr valign="top" class="html2_title_row <?php echo esc_html($array['class']); ?>">
			<th><ul class="row-label">
				<li for=""><?php echo esc_html($array['title']); ?>
					<?php 
					if (isset($array['title_link'])) { 
						echo esc_html($array['title_link']); 
					} 
					?>
					<?php if ( isset($array['tooltip']) ) { ?>
						<span class="woocommerce-help-tip tipTip" title="<?php echo esc_html($array['tooltip']); ?>"></span>
					<?php } ?>
				</li>
				<?php if ( isset($array['desc_tip']) ) { ?>
					<p class="description"><?php echo esc_html($array['desc_tip']); ?></p>
				<?php } ?>
				<li>
					<textarea rows="4" cols="20" class="input-text regular-input" type="textarea" name="<?php echo esc_html($id); ?>" id="<?php echo esc_html($id); ?>" style="" placeholder="<?php echo ( !empty($array['placeholder']) ) ? esc_html($array['placeholder']) : ''; ?>"><?php echo esc_html(stripslashes(get_option($array['id'], $array['default']))); ?></textarea>
				</li>
				</span>
			</th>
		</tr>
		<?php } ?>
		<?php if ('dropdown' != $array['type'] && 'textarea' != $array['type']) { ?>
			<tr class="<?php echo esc_html($array['class']); ?>">
				<td class="forminp"  <?php echo ( 'desc' == $array['type'] ) ? 'colspan=2' : ''; ?>>
					<?php 
					if ( 'checkbox' == $array['type'] ) {								
						if (get_option($array['id'])) {
							$checked = 'checked';
						} else {
							$checked = '';
						} 

						if (isset($array['disabled']) && true == $array['disabled']) {
							$disabled = 'disabled';
							$checked = '';
						} else {
							$disabled = '';
						}							
						?>
					<?php if ('toggle' == $array['class']) { ?>
					<span class="mdl-list__item-secondary-action">
						<label class="mdl-switch mdl-js-switch mdl-js-ripple-effect" for="<?php echo esc_html($id); ?>">
							<input type="hidden" name="<?php echo esc_html($id); ?>" value="0"/>
							<input type="checkbox" id="<?php echo esc_html($id); ?>" name="<?php echo esc_html($id); ?>" class="mdl-switch__input" <?php echo esc_html($checked); ?> value="1" <?php echo esc_html($disabled); ?>/>
						</label><p class="description"><?php echo ( isset($array['desc']) ) ? esc_html($array['desc']) : ''; ?></p>
					</span>
					<?php } else { ?>
					<div class="wplp_multiple <?php echo esc_html($id); ?>">
						<span class="wplp_multiple_checkbox">
							<label class="" for="<?php echo esc_html($id); ?>">
								<input type="hidden" name="<?php echo esc_html($id); ?>" value="0"/>
								<input type="checkbox" id="<?php echo esc_html($id); ?>" name="<?php echo esc_html($id); ?>" class=""  <?php echo esc_html($checked); ?> value="1" <?php echo esc_html($disabled); ?>/>
								<span class="multiple_label"><?php echo esc_html($array['title']); ?></span>
							</label>																		
						</span>
					</div>
					<?php } ?>
					<?php } elseif ( 'textarea' == $array['type'] ) { ?>
					<fieldset>
						<textarea rows="4" cols="20" class="input-text regular-input" type="textarea" name="<?php echo esc_html($id); ?>" id="<?php echo esc_html($id); ?>" style="" placeholder="<?php echo ( !empty($array['placeholder']) ) ? esc_html($array['placeholder']) : ''; ?>"><?php echo esc_html(stripslashes(get_option($array['id'], $array['default']))); ?></textarea>
					</fieldset>
					<?php } elseif ( 'multiple_checkbox' == $array['type'] ) { ?>
						<?php
						$op = 1;	
						foreach ( (array) $array['options'] as $key => $val ) {									
							$multi_checkbox_data = get_option($id);
							if (isset($multi_checkbox_data[$key]) && 1 == $multi_checkbox_data[$key]) {
								$checked = 'checked';
							} else {
								$checked = '';
							}
							?>
					<div class="wplp_multiple <?php echo esc_html($key); ?>">
						<span class="wplp_multiple_checkbox">
							<label class="" for="<?php echo esc_html($key); ?>">
								<input type="hidden" name="<?php echo esc_html($id); ?>[<?php echo esc_html($key); ?>]" value="0"/>
								<input type="checkbox" id="<?php echo esc_html($key); ?>" name="<?php echo esc_html($id); ?>[<?php echo esc_html($key); ?>]" class=""  <?php echo esc_html($checked); ?> value="1" />
								<span class="multiple_label"><?php echo esc_html($val); ?></span>
							</label>																		
						</span>
					</div>								
					<?php 
						} 
					} else if ('text' == $array['type']) { 
						?>
						<ul class="row-label">
							<li>
								<label>
									<?php echo esc_html($array['title']); ?>
									<?php if ( isset($array['tooltip']) ) { ?>
										<span class="woocommerce-help-tip tipTip" title="<?php echo esc_html($array['tooltip']); ?>"></span>
									<?php } ?>
								</label>
							</li>
							<li>
								<input class="input-text regular-input " type="text" name="<?php echo esc_html($id); ?>" id="<?php echo esc_html($id); ?>" style="" value="<?php echo esc_html(get_option($array['id'], isset($array['default']) ? get_option($array['default']) : '')); ?>" placeholder="<?php echo ( !empty($array['placeholder']) ) ? esc_html($array['placeholder']) : ''; ?>">
								<?php echo wp_kses_post( html_entity_decode($array['afterDiv']) ); ?>
							</li>
						</ul>
					<?php } ?>
				</td>
			</tr>
		<?php } ?>
	<?php } } ?>
<?php 
	}
	
	/*
	* Change style of available for pickup and picked up order label
	*/	
	public function footer_function() {
		if ( !is_plugin_active( 'woocommerce-order-status-manager/woocommerce-order-status-manager.php' ) ) {

			$ppl_bg_color = get_option('wclp_processing_lp_status_label_color', '#255abc');
			$ppl_color = get_option('wclp_processing_lp_status_label_font_color', '#fff');

			$rfp_bg_color = get_option('wclp_ready_pickup_status_label_color', '#255abc');
			$rfp_color = get_option('wclp_ready_pickup_status_label_font_color', '#fff');
			
			$pu_bg_color = get_option('wclp_pickup_status_label_color', '#dd9933');
			$pu_color = get_option('wclp_pickup_status_label_font_color', '#fff');						
			?>
			<style>
			.order-status.status-processing-lp,.order-status-table .order-label.wc-processing-lp{
				background: <?php echo !empty($ppl_bg_color) ? esc_html($ppl_bg_color) : '#255abc'; ?>;
				color: <?php echo esc_html($ppl_color); ?>;
			}	
			.order-status.status-ready-pickup,.order-status-table .order-label.wc-ready-pickup{
				background: <?php echo !empty($rfp_bg_color) ? esc_html($rfp_bg_color) : '#255abc'; ?>;
				color: <?php echo esc_html($rfp_color); ?>;
			}						
			.order-status.status-pickup,.order-status-table .order-label.wc-pickup{
				background: <?php echo !empty($pu_bg_color) ? esc_html($pu_bg_color) : '#dd9933'; ?>;
				color: <?php echo esc_html( $pu_color ); ?>;
			}	
			</style>
			<?php
		}
	}
	
	/*
	* Add action button in order list to change order status from processing to ready for pickup and ready for pickup to Picked Up
	*/
	public function add_local_pickup_order_status_actions_button( $actions, $order ) {			

		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
				
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return $actions;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
			return $actions;
		}
		
		wp_enqueue_style( 'alp-order', alp_pro_addon()->plugin_dir_url(__FILE__) . 'assets/css/order.css', array(), alp_pro_addon()->version );
		
		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0);
		$picked = get_option( 'wclp_status_picked_up', 0);
		
		if ( $order->has_status( array( 'processing' ) ) || $order->has_status( array( 'processing-lp' ) ) ) {
			// Get Order ID (compatibility all WC versions)
			$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
			// Set the action button
			if (true == $ready_for_pickup) {
				$actions['ready_for_pickup'] = array(
					'url'       => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=ready-pickup&order_id=' . $order_id ), 'woocommerce-mark-order-status' ),
					'name'      => esc_html__( 'Ready for pickup', 'advanced-local-pickup-pro' ),
					'action'    => 'ready_for_pickup_icon', // keep "view" class for a clean button CSS
				);
			}
			/*if (true == $picked) {
				$actions['pickup'] = array(
					'url'       => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=pickup&order_id=' . $order_id ), 'woocommerce-mark-order-status' ),
					'name'      => esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'action'    => 'picked_up_icon', // keep "view" class for a clean button CSS
				);
				unset($actions['complete']);
			}*/
		}

		if (true == $picked) {
			if ( $order->has_status( array( 'ready-pickup' ) ) ) {
				// Get Order ID (compatibility all WC versions)
				$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
				// Set the action button
				$actions['pickup'] = array(
					'url'       => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=pickup&order_id=' . $order_id ), 'woocommerce-mark-order-status' ),
					'name'      => esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'action'    => 'picked_up_icon', // keep "view" class for a clean button CSS
				);
				unset($actions['complete']);
			}
		} else {
			if ( $order->has_status( array( 'ready-pickup' ) ) ) {
				$actions['complete'] = array(
					'url'    => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=completed&order_id=' . $order->get_id() ), 'woocommerce-mark-order-status' ),
					'name'   => esc_html__( 'Complete', 'woocommerce' ),
					'action' => 'complete',
				);
			}
		}			
				
		return $actions;
	}

	/*
	* Add action button in order list to change order status from processing to ready for pickup and ready for pickup to Picked Up
	*/
	public function add_local_pickup_order_status_preview_actions_button( $actions, $order ) {			
		
		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
				
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return $actions;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
			return $actions;
		}
		
		wp_enqueue_style( 'alp-order', alp_pro_addon()->plugin_dir_url(__FILE__) . 'assets/css/order.css', array(), alp_pro_addon()->version );
		
		$ready_for_pickup = get_option( 'wclp_status_ready_pickup', 0);
		$picked = get_option( 'wclp_status_picked_up', 0);
		if ( $order->has_status( array( 'processing' ) ) || $order->has_status( array( 'processing-lp' ) ) ) {
			// Get Order ID (compatibility all WC versions)
			$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
			// Set the action button

			if (true == $ready_for_pickup) {
				$actions['status']['group'] = 'Change status: ';
				$actions['status']['actions']['ready_for_pickup'] = array(
					'url'    => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=ready-pickup&order_id=' . $order->get_id() ), 'woocommerce-mark-order-status' ),
					'name'   => esc_html__( 'Ready for pickup', 'advanced-local-pickup-pro' ),
					'title'  => __( 'Change order status to', 'woocommerce' ) . ' ' . esc_html__( 'Ready for pickup', 'advanced-local-pickup-pro' ),
					'action' => 'ready_for_pickup_icon',
				);
			}
			if (true == $picked) {
				$actions['status']['group'] = 'Change status: ';
				$actions['status']['actions']['pickup'] = array(
					'url'    => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=pickup&order_id=' . $order->get_id() ), 'woocommerce-mark-order-status' ),
					'name'   => esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'title'  => __( 'Change order status to', 'woocommerce' ) . ' ' . esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'action' => 'picked_up_icon',
				);
				unset($actions['status']['actions']['complete']);
			}
			
		}
		
		if (true == $picked) {
			if ( $order->has_status( array( 'ready-pickup' ) ) ) {
				// Get Order ID (compatibility all WC versions)
				$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
				// Set the action button
				$actions['status']['group'] = 'Change status: ';
				$actions['status']['actions']['pickup'] = array(
					'url'    => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=pickup&order_id=' . $order->get_id() ), 'woocommerce-mark-order-status' ),
					'name'   => esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'title'  => __( 'Change order status to', 'woocommerce' ) . ' ' . esc_html__( 'Picked Up', 'advanced-local-pickup-pro' ),
					'action' => 'picked_up_icon',
				);
				unset($actions['status']['actions']['complete']);
			}
		} else {
			if ( $order->has_status( array( 'ready-pickup' ) ) ) {
				$actions['status']['group'] = 'Change status: ';
				$actions['status']['actions']['complete'] = array(
					'url'    => wp_nonce_url( admin_url( 'admin-ajax.php?action=woocommerce_mark_order_status&status=completed&order_id=' . $order->get_id() ), 'woocommerce-mark-order-status' ),
					'name'   => esc_html__( 'Complete', 'woocommerce' ),
					'action' => 'complete',
				);
			}
		}			
		//print_r($actions);
		return $actions;
	}
	
	/*
	* Add order again button for delivered order status	
	*/
	public function add_reorder_button_pickup( $statuses ) {
		$picked = get_option( 'wclp_status_picked_up', 0);
		if (true == $picked) {
			$statuses[] = 'pickup';
		}
		return $statuses;	
	}
	
	public function get_option_value_from_array( $array, $key, $default_value ) {		

		$array_data = get_option($array);	
		$value = '';
		
		if (isset($array_data[$key])) {
			$value = $array_data[$key];	
		}					
		
		if ('' == $value) {
			$value = $default_value;
		}
		return $value;
	}
	
	/*
	* Return checkbox option value for customizer
	*/
	public function get_checkbox_option_value_from_array( $array, $key, $default_value ) {		
		$array_data = get_option($array);	
		$value = '';
		
		if (isset($array_data[$key])) {
			$value = $array_data[$key];				
			return $value;
		}							
		if ('' == $value) {
			$value = $default_value;
		}		
		return $value;
	}	
	
	/*
	* Load script in frontend cart/checkout page
	*/
	public function wclp_load_frontend_scripts() {
		
		if ( is_cart() || is_checkout() || is_wc_endpoint_url( 'view-order' ) ) { 
			
			// Add jquery-ui js file
			wp_enqueue_script('alp-ui', alp_pro_addon()->plugin_dir_url() . 'assets/js/jquery-ui.min.js', array('jquery'), alp_pro_addon()->version, true);
			wp_enqueue_style('alp-ui', alp_pro_addon()->plugin_dir_url() . 'assets/css/jquery-ui.css', array(), alp_pro_addon()->version);
			
			//Daterangepicker library
			wp_enqueue_style( 'daterangepicker', alp_pro_addon()->plugin_dir_url() . 'assets/css/daterangepicker.css', array(), '3.14.1', 'all');				
			wp_enqueue_script( 'moment_js', alp_pro_addon()->plugin_dir_url() . 'assets/js/moment.min.js', array ( 'jquery' ), '2.18.1', true);
			wp_enqueue_script( 'daterangepicker', alp_pro_addon()->plugin_dir_url() . 'assets/js/daterangepicker.min.js', array ( 'jquery' ), '3.14.1', true);

			wp_enqueue_style( 'dashicons' );

			wp_enqueue_style( 'alp-pro-front-css', alp_pro_addon()->plugin_dir_url() . 'assets/css/front.css', array(), alp_pro_addon()->version );
			wp_enqueue_script( 'alp-pro-front-js', alp_pro_addon()->plugin_dir_url() . 'assets/js/front.js', array('jquery'), alp_pro_addon()->version, true );
			wp_localize_script( 'alp-pro-front-js', 'alp_ajax_object',
				array( 
					'alp_ajax_url' => admin_url( 'admin-ajax.php' ),
					'nonce' => wp_create_nonce('alp-ajax-nonce')
				)
			);
			?>
			<style>
			.alp-cart-option .enabled_pickup {margin: -.28rem .25rem 0 0;vertical-align: middle;}
			.selected_location {width: 100%;margin-bottom: 5px;}
			.woocommerce-shipping-totals [data-title="Local Pickup"] p, .woocommerce-shipping-totals [data-title="Local Pickup"] .shipping__list_label {display: none;}
			.woocommerce-shipping-totals [data-title="Local Pickup"] .shipping__list_item {display: block;}
			.pickup__items_locations .pickup__title {display: block;padding-bottom: 5px;}
			.datepicker{background-image: url( "<?php echo esc_url(alp_pro_addon()->plugin_dir_url()); ?>assets/images/calendar-icon.png" );background-repeat: no-repeat;background-position: 95% center;background-size: 18px;}
			.rtl .datepicker {background-position: 5% center;margin-left: 10px;margin-right: 0 !important;}
			.pickup__items_locations .selected_pickup_location, .pickup__items_locations .datepicker, .pickup__items_locations .appt_time--items, .pickup__items_locations .pickup-appt-fields {width: 100%;}
			.pickup__items_locations small {margin-bottom: 10px;}
			.pickup__items_locations .pickup-appt-fields {display: inline-flex;margin: 0;}
			@media only screen and (max-width: 600px) {.pickup__items_locations .pickup-appt-fields {display: block;}}
			</style>
			<?php
			if ( is_checkout() && is_plugin_active('checkout-for-woocommerce/checkout-for-woocommerce.php') ) {
				?>
				<style>
				.woocommerce-shipping-totals [data-title="Local Pickup"] p, .woocommerce-shipping-totals [data-title="Local Pickup"] .shipping__list_label {display: none;}
				.woocommerce-shipping-totals [data-title="Local Pickup"] .shipping__list_item {display: block;}
				.pickup__items_locations small {margin:0}
				.pickup__items_locations .cfw-input-wrap {margin:10px 0 5px !important}
				.datepicker{background-image: url( "<?php echo esc_url(alp_pro_addon()->plugin_dir_url()); ?>assets/images/calendar-icon.png" );background-repeat: no-repeat;background-position: 95% center;background-size: 18px;}
				</style>
				<?php
			}
			
		}
	}
	
	/*
	* Return pickup data by order id for SMSWOO.
	*/
	public function get_pickup_data( $order_id ) {
		
		if (empty($order_id)) {
			return array();
		}
		
		$locations = $this->get_data();
		$order = wc_get_order( $order_id );
		$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : array();
		$appt_data = $order ? $order->get_meta( 'alp_appt_data', true ) : array();
		$new_product_data = array();
		
		foreach ( (array) $location_ids as $product_id => $location_id) { 
				
			if ( isset($appt_data) && !empty($appt_data) ) {
				if ( isset($appt_data[$order_id][$product_id]) ) {
					$val = $appt_data[$order_id][$product_id];
					$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
					$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
				} else {
					$val = $appt_data[$order_id];
					$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
					$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
				}
			}

			$new_product_data[$product_id] = array(
				'location_id' => $location_id,
				'date'	=> isset($date) ? $date : '',
				'time' => isset($time) ? $time : '',
			);
			
		}
		
		$outputArray = alp_pro_addon()->common->get_grouping_array_of_appt_data($new_product_data);


		if ( isset($outputArray) && !empty($outputArray) ) {
			foreach ( $outputArray as $val ) {
				
				//appt header text
				$alp = new Advanced_Local_Pickup_Admin();
				$header_appointment_text = $alp->get_option_value_from_array('pickup_instruction_customize_settings', 'header_appointment_text', 'Appointment detail');
				
				$date = isset( $val[ 'date' ] ) ? $val[ 'date' ] : '';
				$time = isset( $val[ 'time' ] ) ? $val[ 'time' ] : '';

				$pickup_appt_data = $header_appointment_text . ': ' . $date . ' ' . $time;
				$location_data[] = array( 
					'pickup_appt_data' => $pickup_appt_data,
					'date' => !empty($date) ? gmdate('F j, Y', strtotime($date)) : '',
					'time' => $time
				);
			} 
		}
		if (empty($location_ids)) { 
			$ids[get_option('location_defualt', min($locations)->id)] = '123';
		}
		
		foreach ( (array) $location_ids as $product_id => $id) {
			$ids[$id] = $product_id;
		}
		
		foreach ( $ids as $location_id => $id) { 
			
			$location = $this->get_data_byid($location_id);
			$item_location = $this->get_store_address_by_id($location_id);
			$pickup_hour = $this->get_store_hours_by_id($location_id);
				
			$location_data[] = array(
				'pickup_location_name' => isset($location->store_name) ? $location->store_name : '',
				'pickup_location_address' => $item_location,
				'pickup_location_hours' => strip_tags($pickup_hour),
			);
		}
		
		return $location_data;
	}
	
	/*
	* Return pickup store address by id.
	*/
	public function get_store_address_by_id( $location_id ) {
		
		if ( empty( $location_id ) ) {
			return '';
		}
		
		$location = $this->get_data_byid($location_id);
		$country_code = isset($location->store_country) ? $location->store_country : get_option('woocommerce_default_country');
		$split_country = explode( ':', $country_code );
		$store_country = isset($split_country[0]) && isset($location->store_display_country) && 1 != $location->store_display_country ? $split_country[0] : '';
		$store_state   = isset($split_country[1]) && isset($location->store_display_country) && 1 != $location->store_display_country ? ', ' . $split_country[1] . ' ' : '';
		
		$store_address = !empty($location->store_address) ? $location->store_address : '';
		$store_address_2 = !empty($location->store_address_2) ? ', ' . $location->store_address_2 : '';
		$store_city = !empty($location->store_city) ? ', ' . $location->store_city : '';
		$store_postcode = !empty($location->store_postcode) ? ', ' . $location->store_postcode : '';
		$store_country = !empty( WC()->countries->countries[$store_country] ) ? ', ' . WC()->countries->countries[$store_country] : '';
		
		//WPML string tranlate filters
		global $sitepress;
		if ( $sitepress ) {
			$store_address = apply_filters( 'wpml_translate_single_string', $store_address, 'advanced-local-pickup-pro', $store_address );
			$store_address_2 = apply_filters( 'wpml_translate_single_string', $store_address_2, 'advanced-local-pickup-pro', $store_address_2 );
			$store_city = apply_filters( 'wpml_translate_single_string', $store_city, 'advanced-local-pickup-pro', $store_city );
		}
		
		$address = $store_address . $store_address_2 . $store_city . $store_state . $store_postcode . $store_country;
		if ( !empty($address) ) {
			$address = $address . '.';
		}
		return $address;
	}
	
	/*
	* Return pickup store hours by id.
	*/
	public function get_store_hours_by_id( $location_id ) {

		if ( empty( $location_id ) ) {
			return '';
		}
		$time_format = get_option('time_format', 'g:ia');
		$location = $this->get_data_byid($location_id);
		$store_days = isset($location->store_days) ? unserialize( $location->store_days ) : array();
		$all_days = array(
			'sunday' => esc_html__( 'Sunday', 'advanced-local-pickup-pro' ),
			'monday' => esc_html__( 'Monday', 'advanced-local-pickup-pro'),
			'tuesday' => esc_html__( 'Tuesday', 'advanced-local-pickup-pro' ),
			'wednesday' => esc_html__( 'Wednesday', 'advanced-local-pickup-pro' ),
			'thursday' => esc_html__( 'Thursday', 'advanced-local-pickup-pro' ),
			'friday' => esc_html__( 'Friday', 'advanced-local-pickup-pro' ),
			'saturday' => esc_html__( 'Saturday', 'advanced-local-pickup-pro' ),
		);
		$w_day = array_slice($all_days, get_option('start_of_week'));
		foreach ($all_days as $key=>$val) {
			$w_day[$key] = $val;
		}
		foreach ( (array) $store_days as $key => $val) {
			if ( isset($w_day[$key]) && $w_day[$key]) {
				$w_day[$key] = $val;
			}
		}
				
		$wclp_default_time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
		if ('12' == $wclp_default_time_format) {
			$time_format = 'H:i' == $time_format ? 'g:ia' : $time_format;
			foreach ($w_day as $key=>$val) {	
				if (isset($val['wclp_store_hour']) && !empty($val['wclp_store_hour'])) {
					$last_digit = explode(':', $val['wclp_store_hour']);
					if ('00' == end($last_digit)) {
						$val['wclp_store_hour'] = gmdate($time_format, strtotime($val['wclp_store_hour']));
					} else {
						$val['wclp_store_hour'] = gmdate($time_format, strtotime($val['wclp_store_hour']));
					}
				}
				if (isset($val['wclp_store_hour_end']) && !empty($val['wclp_store_hour_end'])) {
					$last_digit = explode(':', $val['wclp_store_hour_end']);
					if ('00' == end($last_digit)) {
						$val['wclp_store_hour_end'] = gmdate($time_format, strtotime($val['wclp_store_hour_end']));
					} else {
						$val['wclp_store_hour_end'] = gmdate($time_format, strtotime($val['wclp_store_hour_end']));
					}
				}
				if (isset($val['wclp_store_hour2']) && !empty($val['wclp_store_hour2'])) {
					$last_digit = explode(':', $val['wclp_store_hour2']);
					if ('00' == end($last_digit)) {
						$val['wclp_store_hour2'] = gmdate($time_format, strtotime($val['wclp_store_hour2']));
					} else {
						$val['wclp_store_hour2'] = gmdate($time_format, strtotime($val['wclp_store_hour2']));
					}
				}
				if (isset($val['wclp_store_hour_end2']) && !empty($val['wclp_store_hour_end2'])) {
					$last_digit = explode(':', $val['wclp_store_hour_end2']);
					if ('00' == end($last_digit)) {
						$val['wclp_store_hour_end2'] = gmdate($time_format, strtotime($val['wclp_store_hour_end2']));
					} else {
						$val['wclp_store_hour_end2'] = gmdate($time_format, strtotime($val['wclp_store_hour_end2']));
					}
				}
				$w_day[$key] = $val;				
			}	
		}
		
		if (!empty($w_day)) { 	
		$n = 0;
		$new_array = [];
		$previousValue = [];
		
			foreach ($w_day as $day=>$value) {				
				if (isset($value['checked']) && 1 == $value['checked']) {																	
					if ($value != $previousValue) {
						$n++;
					}
					$new_array[$n][$day] = $value;					
					$previousValue = $value;
				} else {
					$n++;
					$new_array[$n][$day] = '';	
					$previousValue = '';
				}							
			}
		}
		$pickup_hour = '';
		foreach ($new_array as $key => $data) {
			if (1 == count($data)) {	
				$pickup_hour .= '<p class="wclp_work_hours_p">';					
				if (isset(reset($data)['wclp_store_hour']) && '' != reset($data)['wclp_store_hour'] && isset(reset($data)['wclp_store_hour_end']) && '' != reset($data)['wclp_store_hour_end']) {
					reset($data);
					$pickup_hour .= esc_html__(ucfirst(key($data)), 'advanced-local-pickup-pro') . ' : ' . reset($data)['wclp_store_hour'] . ' - ' . reset($data)['wclp_store_hour_end'];
				}
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] ) {
					$pickup_hour .=  esc_html__(' and ', 'advanced-local-pickup-pro');
				} else { 
					$pickup_hour .=  ' '; 
				}
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] && isset(reset($data)['wclp_store_hour_end2']) && '' != reset($data)['wclp_store_hour_end2']) {
					reset($data);
					$pickup_hour .= reset($data)['wclp_store_hour2'] . ' - ' . reset($data)['wclp_store_hour_end2'] . ' ';
				}
				$pickup_hour .= '</p>';
			}
			if (2 == count($data)) {
				$pickup_hour .= '<p class="wclp_work_hours_p">';	
				if (isset(reset($data)['wclp_store_hour']) && '' != reset($data)['wclp_store_hour'] && isset(reset($data)['wclp_store_hour_end']) && '' != reset($data)['wclp_store_hour_end']) {
					reset($data);
					$array_key_first = key($data);
					end($data);
					$array_key_last = key($data);
					$pickup_hour .= esc_html__(ucfirst($array_key_first), 'advanced-local-pickup-pro') . ' - ' ;
					$pickup_hour .= esc_html__(ucfirst($array_key_last), 'advanced-local-pickup-pro') . ' : ' . reset($data)['wclp_store_hour'] . ' - ' . reset($data)['wclp_store_hour_end'];
				}
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] ) {
					$pickup_hour .=  esc_html__(' and ', 'advanced-local-pickup-pro');
				} else {
					$pickup_hour .=  ' ';
				}
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] && isset(reset($data)['wclp_store_hour_end2']) && '' != reset($data)['wclp_store_hour_end2']) {
					reset($data);
					$pickup_hour .=  reset($data)['wclp_store_hour2'] . ' - ' . reset($data)['wclp_store_hour_end2'] . ' ';
				}
				$pickup_hour .= '</p>';
			}
			
			if (count($data) > 2) { 
				$pickup_hour .= '<p class="wclp_work_hours_p">';	
				if (isset(reset($data)['wclp_store_hour']) && '' != reset($data)['wclp_store_hour'] && isset(reset($data)['wclp_store_hour_end']) && '' != reset($data)['wclp_store_hour_end']) {
					reset($data);
					$array_key_first = key($data);
					end($data);
					$array_key_last = key($data);
					$pickup_hour .= esc_html__(ucfirst($array_key_first), 'advanced-local-pickup-pro') . ' ' . esc_html__(' To ', 'advanced-local-pickup-pro') . esc_html__(ucfirst($array_key_last), 'advanced-local-pickup-pro') . ' : ' . reset($data)['wclp_store_hour'] . ' - ' . reset($data)['wclp_store_hour_end']; 
						
				}		
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] ) {
					$pickup_hour .=  esc_html__(' and ', 'advanced-local-pickup-pro');
				} else {
					$pickup_hour .=  ' '; 
				}	
				if (isset(reset($data)['wclp_store_hour2']) && '' != reset($data)['wclp_store_hour2'] && isset(reset($data)['wclp_store_hour_end2']) && '' != reset($data)['wclp_store_hour_end2']) {
					reset($data);
					$pickup_hour .=  reset($data)['wclp_store_hour2'] . ' - ' . reset($data)['wclp_store_hour_end2'] . ' ';
				}
				$pickup_hour .= '</p>';
			}	
		}
		
		return $pickup_hour;
	}
	
}
