<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Advanced_Local_Pickup_Ajax {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return Advanced_Local_Pickup_Ajax
	*/
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	*/
	private static $instance;
	
	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	*/
	public function __construct() {
		$this->init();		
	}
	
	/*
	 * init function
	 *
	 * @since  1.0
	*/
	public function init() {
		
		//adding hooks
		
		//set a cart item pickup
		add_action( 'wp_ajax_alp_set_cart_item_must_be_pickup', array( $this, 'alp_set_cart_item_must_be_pickup_handling' ) );
		add_action( 'wp_ajax_nopriv_alp_set_cart_item_must_be_pickup', array( $this, 'alp_set_cart_item_must_be_pickup_handling' ) );
		add_action( 'wp_ajax_alp_set_cart_item_data', array( $this, 'set_cart_item_handling' ) );
		add_action( 'wp_ajax_nopriv_alp_set_cart_item_data', array( $this, 'set_cart_item_handling' ) );
		add_action( 'wp_ajax_alp_set_cart_items_location_data', array( $this, 'set_cart_items_location_handling' ) );
		add_action( 'wp_ajax_nopriv_alp_set_cart_items_location_data', array( $this, 'set_cart_items_location_handling' ) );

		//on popup save
		add_action( 'wp_ajax_alp_set_location_data_after_save', array( $this, 'set_location_handling_after_save' ) );
		add_action( 'wp_ajax_nopriv_alp_set_location_data_after_save', array( $this, 'set_location_handling_after_save' ) );
		
		//order-view-ajax update call
		add_action( 'wp_ajax_alp_reschadule_pickup_form_update', array( $this, 'alp_reschadule_pickup_form_update_callback' ) );
		add_action( 'wp_ajax_nopriv_alp_reschadule_pickup_form_update', array( $this, 'alp_reschadule_pickup_form_update_callback' ) );
		add_action( 'wp_ajax_appt_reschadule_time_slot_html', array( $this, 'get_reschadule_time_slot_html') );
		add_action( 'wp_ajax_nopriv_appt_reschadule_time_slot_html', array( $this, 'get_reschadule_time_slot_html') );
		add_action( 'wp_ajax_appt_reschadule_datepicker_html', array( $this, 'reschadule_datepicker_html') );
		add_action( 'wp_ajax_nopriv_appt_reschadule_datepicker_html', array( $this, 'reschadule_datepicker_html') );
		
		//ajax save admin api settings
		add_action( 'wp_ajax_wclp_setting_form_update', array( $this, 'wclp_setting_form_update_callback') );	
		add_action( 'wp_ajax_wclp_location_edit_form_update', array( $this, 'wclp_location_edit_form_update_callback') );
		add_action( 'wp_ajax_wclp_choose_default_location_form_update', array( $this, 'wclp_choose_default_location_form_callback') );
		add_action( 'wp_ajax_wclp_location_delete', array( $this, 'wclp_location_delete_callback') );
		add_action( 'wp_ajax_wclp_location_enable', array( $this, 'wclp_location_enable_callback') );
		
		//ajax get html data
		add_action( 'wp_ajax_wclp_update_state_dropdown', array( $this, 'wclp_update_state_dropdown_fun') );
		add_action( 'wp_ajax_wclp_update_edit_location_form', array( $this, 'wclp_update_edit_location_form_fun') );
		add_action( 'wp_ajax_wclp_location_duplicate', array( $this, 'wclp_location_duplicate_callback' ) );
		add_action( 'wp_ajax_wclp_apply_work_hours', array( $this, 'wclp_apply_work_hours_fun') );
		add_action( 'wp_ajax_wclp_apply_appt_hours', array( $this, 'wclp_apply_appt_hours_fun') );
		add_action( 'wp_ajax_wclp_appt_hours_popup_html', array( $this, 'wclp_appt_hours_popup_html') );
				
	}
	
	/**
	 * Set a cart item for session with pickup data for force pickup item
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function alp_set_cart_item_must_be_pickup_handling() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}
		
		if ( ! empty( $_POST ) ) {
			foreach ( WC()->cart->get_cart() as $item_key => $item ) {
				
				$must_be_pickedup = get_post_meta( $item['product_id'], '_per_product_pickedup', true );
				$session_data = unserialize(WC()->session->get( $item_key ));
				$enabled = isset($_POST['enabled']) ? sanitize_text_field($_POST['enabled']) : '';
				$locations = alp_pro_addon()->admin->get_available_locations_data();
				$defualt_location = count($locations) == 1 ? min($locations)->id : '';
				
				if ( isset($must_be_pickedup) && 'yes' == $must_be_pickedup ) {
					if ( ! empty( $enabled ) && empty($session_data) ) {
						$session_data['pickup_data'][$item_key]['enabled'] = $enabled;
						$session_data['pickup_data'][$item_key]['location_id'] = $defualt_location;
					}
				} else {
					if ( count($locations) == 1 && empty($session_data) ) {
						$session_data['pickup_data'][$item_key]['enabled'] = $enabled;
						$session_data['pickup_data'][$item_key]['location_id'] = $defualt_location;
					}
				}
				WC()->session->set( $item_key, serialize($session_data) );
			}
		}
		
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');		
		if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {

			global $wpdb;
			$this->table = $wpdb->prefix . 'alp_pickup_location';

			$locations = alp_pro_addon()->admin->get_available_locations_data();
			$session_id = WC()->session->get( 'pickup_location_id' );
			
			$location_id = !empty($session_id) ? $session_id : '';

			if ( count($locations) == 1 ) {
				$location_id = count($locations) == 1 ? min($locations)->id : '';
			}

			WC()->session->set( 'pickup_location_id', $location_id );
		}
		
		$redirect_to_cart = false;
		if ( 'yes' === get_option( 'woocommerce_cart_redirect_after_add' ) ) {
			$redirect_to_cart = true;
		}
		
		echo json_encode( array('success' => 'true', 'redirect_to_cart'=> $redirect_to_cart ) );
		die();

	}

	
	/**
	 * Set a cart item for session with pickup data
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function set_cart_item_handling() {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		//$locations = alp_pro_addon()->admin->get_data();
		$cart_item_key = isset($_POST['cart_item_key']) ? sanitize_text_field($_POST['cart_item_key']) : '';
		$enabled = isset($_POST['enabled']) ? sanitize_text_field($_POST['enabled']) : '';
		$location_id = isset($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';//get_option('location_defualt', min($locations)->id);

		if (  isset( $cart_item_key ) ) {
			
			$cart_item_key = $cart_item_key;
						
			if ( is_string( $cart_item_key ) && '' !== $cart_item_key ) {
				
				if ( ! empty( $enabled ) ) {
					$session_data['pickup_data'][$cart_item_key]['enabled'] = $enabled;
				}
				if ( ( !empty($location_id) ) ) {
					$session_data['pickup_data'][$cart_item_key]['location_id'] = $location_id;
				}
				
				WC()->session->set( $cart_item_key, serialize($session_data) );
				
			}
			
			if (!empty($location_id)) {
				$this->get_location_data_byid($location_id);
			} else {
				wp_send_json_success();	
			}
		}

		wp_send_json_error();
	}
	
	/**
	 * Set a cart item location for pickup item
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function set_cart_items_location_handling() {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		//$locations = alp_pro_addon()->admin->get_data();
		$location_id = isset($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';//get_option('location_defualt', min($locations)->id);
		
		$cart_item_key = isset($_POST['cart_item_key']) ? sanitize_text_field($_POST['cart_item_key']) : '';
		$date = isset($_POST['date']) ? sanitize_text_field($_POST['date']) : '';
		$time = isset($_POST['time']) ? sanitize_text_field($_POST['time']) : '';
		
		if (  isset( $location_id ) ) {
			
			if ( get_option('wclp_cart_checkout_layout', 'inline') == 'inline') {

				if ( !empty($cart_item_key) ) {

					//enabled pickup per item 
					if ( ( !empty($date) ) ) {
						
						$session_data = unserialize(WC()->session->get($cart_item_key));
						
						if ( !empty($time) ) {
							$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
							$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
							$session_data['pickup_data'][$cart_item_key]['date'] = gmdate('d-m-Y', $timestamp);
							$session_data['pickup_data'][$cart_item_key]['time'] = $time;
						} else {
							$date = !isset($_POST['time']) ? substr($date, 4, 11) : $date;
							$date = !isset($_POST['time']) ? gmdate(get_option('date_format'), strtotime($date)) : $date;
							$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
							$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
							$session_data['pickup_data'][$cart_item_key]['date'] = gmdate('d-m-Y', $timestamp);
						}
						WC()->session->set( $cart_item_key, serialize($session_data) );
						//WC()->session->set( 'appt_data', serialize($session_data) );
					}

				} else {

					//not enabled pickup per item
					WC()->session->set( 'pickup_location_id', $location_id );
				
					if ( ( !empty($date) && !empty($location_id) ) ) {
						
						$session_data['location_id'] = $location_id;

						if ( !empty($time) ) {

							$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
							$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
							$session_data['date'] = gmdate('d-m-Y', $timestamp);
							$session_data['time'] = $time;
						} else {
							$date = !isset($_POST['time']) ? substr($date, 4, 11) : $date;
							$date = !isset($_POST['time']) ? gmdate(get_option('date_format'), strtotime($date)) : $date;
							$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
							$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
							$session_data['date'] = gmdate('d-m-Y', $timestamp);
						}

						WC()->session->set( 'appt_data', serialize($session_data) );
					}
				}

			} else {

				if ( ( !empty($date) && !empty($location_id) ) ) {
					$session_data['location_id'] = $location_id;
					$date = substr($date, 4, 11);
					$date = gmdate(get_option('date_format'), strtotime($date));
					$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
					$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
					$session_data['date'] = gmdate('d-m-Y', $timestamp);
					
					if ( !empty($date) && empty($time) ) {
						$appt_session_data = unserialize(WC()->session->get('appt_data'));
						$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';
						$this->get_time_slot_html( $date, $time );
					}
					
					if ( !empty($time) ) {
						$session_data['time'] = $time;
					}
				}
			}
			
			if (!empty($location_id)) {
				$this->get_location_data_byid($location_id);
			} else {
				wp_send_json_success();	
			}
		}

		wp_send_json_error();
	}

	/**
	 * Set a cart item location for pickup item
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function set_location_handling_after_save() {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		//$locations = alp_pro_addon()->admin->get_data();
		$location_id = isset($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';//get_option('location_defualt', min($locations)->id);
		$date = isset($_POST['date']) ? sanitize_text_field($_POST['date']) : '';
		$time = isset($_POST['time']) ? sanitize_text_field($_POST['time']) : '';
		
		$appt_session_data = unserialize(WC()->session->get('appt_data'));

		if (  isset( $location_id ) ) {
			
			WC()->session->set( 'pickup_location_id', $location_id );

			if ( ( !empty($location_id) ) ) {
				
				$session_data['location_id'] = $location_id;
				$date = substr($date, 4, 11);
				$date = gmdate(get_option('date_format'), strtotime($date));
				$convertDate = DateTime::createFromFormat( get_option('date_format', 'd-m-Y'), $date );
				$timestamp = !empty($convertDate) ? $convertDate->getTimestamp() : '';
				$session_data['date'] = gmdate('d-m-Y', $timestamp);//gmdate(get_option('date_format'), strtotime($date));

				if ( !empty($date) && empty($time) ) {
					$appt_session_data = unserialize(WC()->session->get('appt_data'));
					$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';
					$this->get_time_slot_html( $date, $time );
				}
				
				if ( !empty($time) ) {
					$session_data['time'] = $time;
				}
				
				$location = alp_pro_addon()->admin->get_data_byid($location_id);
				if ( isset($location->store_enable_appt) && '1' == $location->store_enable_appt ) {
					WC()->session->set( 'appt_data', serialize($session_data) );
				} else {
					WC()->session->__unset( 'appt_data' );

				}
				
			}
			
			
			if (!empty($location_id)) {
				$this->get_location_data_byid($location_id);
			} else {
				wp_send_json_success();	
			}
		}

		wp_send_json_error();
	}
	
	/**
	 * Set a cart item location for pickup item
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function get_location_data_byid( $location_id ) {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}
		
		if (  isset( $location_id ) ) {
			
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$store_days = !empty($location->store_days) ? unserialize($location->store_days): get_option('wclp_store_days');
			$store_appt_days = !empty($location->store_appt_days) ? unserialize($location->store_appt_days): $store_days;
			
			$exclusive_appt_data = !empty($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();
			$days = array();
			foreach ($store_days as $day => $val) {
				if ( isset($store_appt_days[$day]['checked']) && '1' == $store_appt_days[$day]['checked'] ) {
					$days[] = (int) gmdate('w', strtotime($day));	
				}
			}
			
			if ( !empty($exclusive_appt_data) ) { 
				foreach ($exclusive_appt_data as $date => $val) {
					if ( isset($exclusive_appt_data[$date][key($val)]['checked']) && '1' == $exclusive_appt_data[$date][key($val)]['checked'] ) {
						$days[] = (int) gmdate('w', strtotime(key($val)));	
					}
				}
			}

			$date_format = 'dd-mm-yy';
			if ( get_option('date_format') === 'F j, Y' ) {
				$date_format = 'MM d, yy';
			}
			if ( get_option('date_format') === 'Y-m-d' ) {
				$date_format = 'yy-mm-d';
			}
			if ( get_option('date_format') === 'm/d/Y' ) {
				$date_format = 'mm/d/yy';
			}
			if ( get_option('date_format') === 'd/m/Y' ) {
				$date_format = 'd/mm/yy';
			}
			
			$appt_session_data = unserialize(WC()->session->get('appt_data'));
			$location->store_appt_exclusive_days = unserialize($location->store_appt_exclusive_days);
			$location->store_appt_days = unserialize($location->store_appt_days);

			echo json_encode( array('success' => 'true', 'location'=> $location, 'store_appt_days' => $days, 'date_format' => $date_format, 'appt_session_data' => $appt_session_data, 'start_of_week' => get_option('start_of_week') ) );
			die();
		} 

		wp_send_json_error();
	}
	
	/*
	* general settings form save for Setting tab
	*/
	public function wclp_setting_form_update_callback() {			
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		if ( !current_user_can( 'manage_options' ) ) {
			echo json_encode( array('permission' => 'false') );
			die();
		}
		
		if ( ! empty( $_POST ) && check_admin_referer( 'wclp_setting_form_action', 'wclp_setting_form_nonce_field' ) ) {
			$wclp_emails_additional_content = isset($_POST['wclp_emails_additional_content']) ? wp_kses_post($_POST['wclp_emails_additional_content']) : '';
			if (isset($wclp_emails_additional_content)) {
				update_option( 'wclp_emails_additional_content', $wclp_emails_additional_content );
			}
			
			$smswoo_pickup_reminder_sms_template = isset($_POST['smswoo_pickup_reminder_sms_template']) ? sanitize_text_field($_POST['smswoo_pickup_reminder_sms_template']) : '';
			if ( isset($smswoo_pickup_reminder_sms_template) && class_exists( 'SMS_for_WooCommerce' ) ) {
				update_option( 'smswoo_pickup_reminder_sms_template', $smswoo_pickup_reminder_sms_template );
			}
			
			$display_in_order_received_page = isset($_POST['wclp_show_pickup_instruction']['display_in_order_received_page']) ? sanitize_text_field($_POST['wclp_show_pickup_instruction']['display_in_order_received_page']) : '';
			$display_in_order_details_page = isset($_POST['wclp_show_pickup_instruction']['display_in_order_details_page']) ? sanitize_text_field($_POST['wclp_show_pickup_instruction']['display_in_order_details_page']) : '';
			$wclp_show_pickup_instruction_opt = array(
				'display_in_order_received_page' => $display_in_order_received_page,
				'display_in_order_details_page' => $display_in_order_details_page,
			);			
			update_option( 'wclp_show_pickup_instruction', $wclp_show_pickup_instruction_opt );
			
			$wclp_display_pickup_instruction_statuses = isset($_POST['wclp_display_pickup_instruction_statuses']) ? wc_clean($_POST['wclp_display_pickup_instruction_statuses']) : '';
			if ( isset($wclp_display_pickup_instruction_statuses) ) {
				update_option( 'wclp_display_pickup_instruction_statuses', $wclp_display_pickup_instruction_statuses );
			}
			
			$alp_order_display_in_fulfillment_dashboard = isset($_POST['alp_order_display_in_fulfillment_dashboard']) ? wc_clean($_POST['alp_order_display_in_fulfillment_dashboard']) : '';
			if ( isset($alp_order_display_in_fulfillment_dashboard) ) {
				update_option( 'alp_order_display_in_fulfillment_dashboard', $alp_order_display_in_fulfillment_dashboard );
			}
			
			$wclp_cart_checkout_layout = isset($_POST['wclp_cart_checkout_layout']) ? wc_clean($_POST['wclp_cart_checkout_layout']) : '';
			if ( isset($wclp_cart_checkout_layout) ) {
				update_option( 'wclp_cart_checkout_layout', $wclp_cart_checkout_layout );
			}

			$wclp_pickup_location_sort = isset($_POST['wclp_pickup_location_sort']) ? wc_clean($_POST['wclp_pickup_location_sort']) : '';
			if ( isset($wclp_pickup_location_sort) ) {
				update_option( 'wclp_pickup_location_sort', $wclp_pickup_location_sort );
			}

			$wclp_google_maps_apikey = isset($_POST['wclp_google_maps_apikey']) ? wc_clean($_POST['wclp_google_maps_apikey']) : '';
			if ( isset($wclp_google_maps_apikey) ) {
				update_option( 'wclp_google_maps_apikey', $wclp_google_maps_apikey );
			}

			$allow_force_date_selection = isset($_POST['allow_force_date_selection']) ? wc_clean($_POST['allow_force_date_selection']) : '';
			if ( isset($allow_force_date_selection) ) {
				update_option( 'allow_force_date_selection', $allow_force_date_selection );
			}

			$enable_processing_lp_automation = isset($_POST['enable_processing_lp_automation']) ? wc_clean($_POST['enable_processing_lp_automation']) : '';
			if ( isset($enable_processing_lp_automation) ) {
				update_option( 'enable_processing_lp_automation', $enable_processing_lp_automation );
			}

			$allow_mixed_orders = isset($_POST['wclp_local_pickup_controls']['allow_mixed_orders']) ? sanitize_text_field($_POST['wclp_local_pickup_controls']['allow_mixed_orders']) : '';
			$allow_pickup_per_item = isset($_POST['wclp_local_pickup_controls']['allow_pickup_per_item']) ? sanitize_text_field($_POST['wclp_local_pickup_controls']['allow_pickup_per_item']) : '';
			$display_location_address = isset($_POST['wclp_local_pickup_controls']['display_location_address']) ? sanitize_text_field($_POST['wclp_local_pickup_controls']['display_location_address']) : '';
			$wclp_local_pickup_controls_opt = array(
				'allow_mixed_orders' => $allow_mixed_orders,
				'allow_pickup_per_item' => $allow_pickup_per_item,
				'display_location_address' => $display_location_address,
			);			
			update_option( 'wclp_local_pickup_controls', $wclp_local_pickup_controls_opt );
			
			$display_message_product_page = isset($_POST['wclp_local_pickup_message_controls']['display_message_product_page']) ? sanitize_text_field($_POST['wclp_local_pickup_message_controls']['display_message_product_page']) : '';
			$wclp_local_pickup_message_opt = array(
				'display_message_product_page' => $display_message_product_page,
			);		
			update_option( 'wclp_local_pickup_message_controls', $wclp_local_pickup_message_opt );
			
			$wclp_local_pickup_message_position = isset($_POST['wclp_local_pickup_message_position']) ? sanitize_text_field($_POST['wclp_local_pickup_message_position']) : '';
			$wclp_local_pickup_message_content = isset($_POST['wclp_local_pickup_message_content']) ? sanitize_text_field($_POST['wclp_local_pickup_message_content']) : '';
			update_option( 'wclp_local_pickup_message_position', $wclp_local_pickup_message_position );
			update_option( 'wclp_local_pickup_message_content', $wclp_local_pickup_message_content );
			
			$wclp_status_processing_lp = isset($_POST['wclp_status_processing_lp']) ? sanitize_text_field($_POST['wclp_status_processing_lp']) : '';
			update_option( 'wclp_status_processing_lp', $wclp_status_processing_lp );
			$wclp_processing_lp_status_label_color = isset($_POST['wclp_processing_lp_status_label_color']) ? sanitize_text_field($_POST['wclp_processing_lp_status_label_color']) : '';
			update_option( 'wclp_processing_lp_status_label_color', $wclp_processing_lp_status_label_color );
			$wclp_processing_lp_status_label_font_color = isset($_POST['wclp_processing_lp_status_label_font_color']) ? sanitize_text_field($_POST['wclp_processing_lp_status_label_font_color']) : '';
			update_option( 'wclp_processing_lp_status_label_font_color', $wclp_processing_lp_status_label_font_color );
			$wclp_status_ready_pickup = isset($_POST['wclp_status_ready_pickup']) ? sanitize_text_field($_POST['wclp_status_ready_pickup']) : '';
			update_option( 'wclp_status_ready_pickup', $wclp_status_ready_pickup );
			$wclp_ready_pickup_status_label_color = isset($_POST['wclp_ready_pickup_status_label_color']) ? sanitize_text_field($_POST['wclp_ready_pickup_status_label_color']) : '';
			update_option( 'wclp_ready_pickup_status_label_color', $wclp_ready_pickup_status_label_color );
			$wclp_ready_pickup_status_label_font_color = isset($_POST['wclp_ready_pickup_status_label_font_color']) ? sanitize_text_field($_POST['wclp_ready_pickup_status_label_font_color']) : '';
			update_option( 'wclp_ready_pickup_status_label_font_color', $wclp_ready_pickup_status_label_font_color );
			$wclp_status_picked_up = isset($_POST['wclp_status_picked_up']) ? sanitize_text_field($_POST['wclp_status_picked_up']) : '';
			update_option( 'wclp_status_picked_up', $wclp_status_picked_up );
			$wclp_pickup_status_label_color = isset($_POST['wclp_pickup_status_label_color']) ? sanitize_text_field($_POST['wclp_pickup_status_label_color']) : '';
			update_option( 'wclp_pickup_status_label_color', $wclp_pickup_status_label_color );
			$wclp_pickup_status_label_font_color = isset($_POST['wclp_pickup_status_label_font_color']) ? sanitize_text_field($_POST['wclp_pickup_status_label_font_color']) : '';
			update_option( 'wclp_pickup_status_label_font_color', $wclp_pickup_status_label_font_color );			
			
			$processing_lp_email = get_option('woocommerce_customer_processing_lp_order_settings');
			$wclp_enable_processing_lp_email = isset($_POST['wclp_enable_processing_lp_email']) ? sanitize_text_field($_POST['wclp_enable_processing_lp_email']) : '';			
			if (1 == $wclp_enable_processing_lp_email) {
				update_option( 'customizer_processing_lp_order_settings_enabled', $wclp_enable_processing_lp_email );
				$enabled = 'yes';
			} else {
				update_option( 'customizer_processing_lp_order_settings_enabled', sanitize_text_field( '' ));	
				$enabled = 'no';
			}
			
			$opt = array(
				'enabled' => $enabled,
				'subject' => $processing_lp_email['subject'],
				'heading' => $processing_lp_email['heading'],
				'additional_content' => $processing_lp_email['additional_content'],
				'recipient' => $processing_lp_email['recipient'],
				'email_type' => $processing_lp_email['email_type'],
			);
			update_option( 'woocommerce_customer_processing_lp_order_settings', wc_clean( $opt ) );			

			$pickup_email = get_option('woocommerce_customer_pickup_order_settings');									
			$wclp_enable_pickup_email = isset($_POST['wclp_enable_pickup_email']) ? sanitize_text_field($_POST['wclp_enable_pickup_email']) : '';
			if (1 == $wclp_enable_pickup_email) {
				update_option( 'customizer_pickup_order_settings_enabled', $wclp_enable_pickup_email );
				$enabled = 'yes';
			} else {
				update_option( 'customizer_pickup_order_settings_enabled', sanitize_text_field( '' ));	
				$enabled = 'no';
			}
			
			$opt = array(
				'enabled' => $enabled,
				'subject' => $pickup_email['subject'],
				'heading' => $pickup_email['heading'],
				'additional_content' => $pickup_email['additional_content'],
				'recipient' => $pickup_email['recipient'],
				'email_type' => $pickup_email['email_type'],
			);
			update_option( 'woocommerce_customer_pickup_order_settings', wc_clean( $opt ) );
			
			$ready_pickup_email = get_option('woocommerce_customer_ready_pickup_order_settings');
			$wclp_enable_ready_pickup_email = isset($_POST['wclp_enable_ready_pickup_email']) ? sanitize_text_field($_POST['wclp_enable_ready_pickup_email']) : '';			
			if (1 == $wclp_enable_ready_pickup_email) {
				update_option( 'customizer_ready_pickup_order_settings_enabled', $wclp_enable_ready_pickup_email );
				$enabled = 'yes';
			} else {
				update_option( 'customizer_ready_pickup_order_settings_enabled', sanitize_text_field( '' ));	
				$enabled = 'no';
			}
			
			$opt = array(
				'enabled' => $enabled,
				'subject' => $ready_pickup_email['subject'],
				'heading' => $ready_pickup_email['heading'],
				'additional_content' => $ready_pickup_email['additional_content'],
				'recipient' => $ready_pickup_email['recipient'],
				'email_type' => $ready_pickup_email['email_type'],
			);
			update_option( 'woocommerce_customer_ready_pickup_order_settings', wc_clean( $opt ) );			
			
			
			echo json_encode( array('success' => 'true') );
			die();
	
		}
	}
	
	/*
	* settings form save for Setting tab
	*/
	public function wclp_location_edit_form_update_callback() {			
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		if ( !current_user_can( 'manage_options' ) ) {
			echo json_encode( array('permission' => 'false') );
			die();
		}
		
		if ( ! empty( $_POST ) && check_admin_referer( 'wclp_location_edit_form_action', 'wclp_location_edit_form_nonce_field' ) ) {
						
			global $wpdb;
			$this->table = $wpdb->prefix . 'alp_pickup_location';
			
			$id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';			
			
			$location = alp_pro_addon()->admin->get_data_byid($id);
			
			$wclp_store_enable = isset($location->store_enable) ? sanitize_text_field($location->store_enable) : 0;
			$wclp_store_name = isset($_POST['wclp_store_name']) ? sanitize_text_field($_POST['wclp_store_name']) : '';
			$wclp_store_address = isset($_POST['wclp_store_address']) ? sanitize_text_field($_POST['wclp_store_address']) : '';
			$wclp_store_address_2 = isset($_POST['wclp_store_address_2']) ? sanitize_text_field($_POST['wclp_store_address_2']) : '';
			$wclp_store_city = isset($_POST['wclp_store_city']) ? sanitize_text_field($_POST['wclp_store_city']) : '';
			$wclp_default_country = isset($_POST['wclp_default_country']) ? sanitize_text_field($_POST['wclp_default_country']) : '';
			$wclp_store_postcode = isset($_POST['wclp_store_postcode']) ? sanitize_text_field($_POST['wclp_store_postcode']) : '';
			$wclp_store_phone = isset($_POST['wclp_store_phone']) ? sanitize_text_field($_POST['wclp_store_phone']) : '';
			$wclp_default_time_format = isset($_POST['wclp_default_time_format']) ? sanitize_text_field($_POST['wclp_default_time_format']) : '';
			$wclp_store_days = isset($_POST['wclp_store_days']) ? serialize(wc_clean($_POST['wclp_store_days'])) : get_option('wclp_store_days');
			$wclp_store_instruction = isset($_POST['wclp_store_instruction']) ? sanitize_text_field($_POST['wclp_store_instruction']) : '';
			
			
			if ('0' == $id) {				
				$data = array(
					'store_enable' => $wclp_store_enable,
					'store_name' => $wclp_store_name,
				);
				$wpdb->insert( $this->table, $data );
				$id = $wpdb->insert_id;
			}
			
			//get form field
			$data = array(
				'store_enable' => $wclp_store_enable,
				'store_name' => $wclp_store_name,
				'store_address' => $wclp_store_address,
				'store_address_2' => $wclp_store_address_2,
				'store_city' => $wclp_store_city,
				'store_country' => $wclp_default_country,
				'store_postcode' => $wclp_store_postcode,
				'store_phone' => $wclp_store_phone,
				'store_time_format' => $wclp_default_time_format,
				'store_days' => $wclp_store_days,
				'store_instruction' => $wclp_store_instruction,
			);
			
			$data['store_display_country'] = isset($_POST['wclp_display_country']) ? sanitize_text_field($_POST['wclp_display_country']) : '';
			$data['store_holiday_message'] = isset($_POST['wclp_store_holiday_message']) ? sanitize_text_field( $_POST['wclp_store_holiday_message'] ) : '';		
			$data['store_selected_products'] = !empty($_POST['wclp_selected_products']) ? serialize(wc_clean($_POST['wclp_selected_products'])) : '';
			$data['store_excluded_products'] = !empty($_POST['wclp_excluded_products']) ? serialize(wc_clean($_POST['wclp_excluded_products'])) : '';
			$data['store_selected_categories'] = !empty($_POST['wclp_selected_categories']) ? serialize(wc_clean($_POST['wclp_selected_categories'])) : '';
			$data['store_excluded_categories'] = !empty($_POST['wclp_excluded_categories']) ? serialize(wc_clean($_POST['wclp_excluded_categories'])) : '';
			$data['store_price_adjustment'] = isset($_POST['wclp_price_adjustment']) ? sanitize_text_field( $_POST['wclp_price_adjustment'] ) : '';
			$data['store_price_amount'] = isset($_POST['wclp_price_amount']) ? sanitize_text_field( $_POST['wclp_price_amount'] ) : '';
			$data['store_apply_cart_adjustment_price'] = isset($_POST['wclp_apply_cart_adjustment_price']) ? sanitize_text_field( $_POST['wclp_apply_cart_adjustment_price'] ) : '';
			$data['store_recipients'] = isset($_POST['wclp_store_recipients']) ? sanitize_text_field( $_POST['wclp_store_recipients'] ) : '';
			$data['store_enable_appt'] = isset($_POST['wclp_enable_appt']) ? sanitize_text_field( $_POST['wclp_enable_appt'] ) : '';
			$data['store_appt_start_date'] = isset($_POST['wclp_appt_start_date']) ? sanitize_text_field( $_POST['wclp_appt_start_date'] ) : '';
			$data['store_appt_first_date'] = isset($_POST['wclp_appt_first_date']) ? sanitize_text_field( $_POST['wclp_appt_first_date'] ) : '';
			$data['store_appt_time_range'] = isset($_POST['wclp_appt_time_range']) ? sanitize_text_field( $_POST['wclp_appt_time_range'] ) : '';
			$data['store_appt_hour_same_day'] = isset($_POST['wclp_appt_hour_same_day']) ? sanitize_text_field( $_POST['wclp_appt_hour_same_day'] ) : '';
			$data['store_appt_pickup_increment'] = !empty($_POST['wclp_appt_pickup_increment']) ? serialize(wc_clean($_POST['wclp_appt_pickup_increment'])) : '';
			$data['store_appt_time_slot_limit'] = isset($_POST['wclp_appt_time_slot_limit']) ? sanitize_text_field( $_POST['wclp_appt_time_slot_limit'] ) : '';
			$data['store_enable_pickup_reminder'] = isset($_POST['wclp_enable_pickup_reminder']) ? sanitize_text_field( $_POST['wclp_enable_pickup_reminder'] ) : '';
			$data['store_pickup_reminder_time'] = !empty($_POST['wclp_pickup_reminder_time']) ? serialize(wc_clean($_POST['wclp_pickup_reminder_time'])) : '';
			$data['store_enable_pickup_reminder_SMS'] = isset($_POST['wclp_enable_pickup_reminder_SMS']) ? sanitize_text_field( $_POST['wclp_enable_pickup_reminder_SMS'] ) : '';
			$data['store_pickup_reminder_SMS_template'] = isset($_POST['wclp_pickup_reminder_SMS_template']) ? sanitize_text_field( $_POST['wclp_pickup_reminder_SMS_template'] ) : '';
			$data['store_enable_automation'] = isset($_POST['wclp_enable_automation']) ? sanitize_text_field( $_POST['wclp_enable_automation'] ) : '';
			$data['store_nonAppt_pickup_days'] = isset($_POST['wclp_nonAppt_pickup_days']) ? sanitize_text_field( $_POST['wclp_nonAppt_pickup_days'] ) : 0;
			$data['store_2nd_nonAppt_pickup_days'] = isset($_POST['wclp_2nd_nonAppt_pickup_days']) ? sanitize_text_field( $_POST['wclp_2nd_nonAppt_pickup_days'] ) : 0;
			$data['store_excluded_shippings'] = !empty($_POST['wclp_excluded_shippings']) ? serialize(wc_clean($_POST['wclp_excluded_shippings'])) : '';
			$data['store_excluded_payments'] = !empty($_POST['wclp_excluded_payments']) ? serialize(wc_clean($_POST['wclp_excluded_payments'])) : '';
			$data['store_public_holidays'] = !empty($_POST['wclp_store_public_holidays']) ? sanitize_text_field( $_POST['wclp_store_public_holidays'] ) : '';
			
			$locations = alp_pro_addon()->admin->get_data();
			$location = alp_pro_addon()->admin->get_data_byid($id);			
			$data['position'] = isset($location->position) ? $location->position : count($locations);
			$store_days = isset($_POST['wclp_store_days']) ? wc_clean($_POST['wclp_store_days']) : get_option('wclp_store_days');
			
			$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : array();
			if ( !empty($store_appt_days) ) {
				//set days from store_days if not set day in store_appt_days
				foreach ( $store_days as $day => $array ) {
					if ( !array_key_exists( $day, $store_appt_days) ) {
						$store_appt_days[$day] = $array;
					}
				}
				
				//unset days in store_appt_days if not set day in store_days
				foreach ( $store_appt_days as $day => $array ) {
					if ( !array_key_exists( $day, $store_days) ) {
						unset($store_appt_days[$day]);
					}
				}
				
				$exclusive_appt_data = !empty($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();
				//unset days in exclusive_appt_data if not set day in store_appt_days
				if ( !empty($exclusive_appt_data) ) {
					foreach ( $exclusive_appt_data as $date => $array ) {
						if ( !array_key_exists( key($array), $store_appt_days) ) {
							unset( $exclusive_appt_data[$date] );
						}	
					}
				}
				
				$data['store_appt_exclusive_days'] = serialize(wc_clean($exclusive_appt_data));	
				$data['store_appt_days'] = serialize(wc_clean($store_appt_days));
			
			} else {
			
				$data['store_appt_exclusive_days'] = !empty($location->store_appt_exclusive_days) ? $location->store_appt_exclusive_days : array();
				$data['store_appt_days'] = serialize(wc_clean($store_days));
			
			}
			
			//check column exist
			$tabledata = $wpdb->get_row( $wpdb->prepare('SELECT * FROM %1s LIMIT 1', $this->table) );

			foreach ( (array) $data as $key1 => $val1  ) {
				if ( 'store_name' == $key1 ) {
					continue;
				}
				
				if (!isset($tabledata->store_enable)) {
					$wpdb->query( $wpdb->prepare( 'ALTER TABLE %1s ADD store_enable text NOT NULL AFTER id', $this->table ) );
				}
				
				if (!isset($tabledata->$key1)) {
					$wpdb->query( $wpdb->prepare( 'ALTER TABLE %1s ADD %2s text NOT NULL', $this->table, $key1 ) );
				}
			}
			
			$where = array(
				'id' => $id,
			);
			
			$result = $wpdb->update( $this->table, $data, $where );	

			//WPML string registed
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $wclp_store_name, $wclp_store_name );
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $wclp_store_instruction, $wclp_store_instruction );
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $wclp_store_address, $wclp_store_address );
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $wclp_store_address_2, $wclp_store_address_2 );
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $wclp_store_city, $wclp_store_city );
			do_action( 'wpml_register_single_string', 'advanced-local-pickup-pro', $data['store_holiday_message'], $data['store_holiday_message'] );

			$array = array('success' => 'true', 'id' => $id) ;
			
			echo json_encode( $array );
			die();
		} 
	}
	
	/*
	* general settings form save for Setting tab
	*/
	public function wclp_location_duplicate_callback() {			
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		if ( !current_user_can( 'manage_options' ) ) {
			echo json_encode( array('permission' => 'false') );
			die();
		}
		$id = isset($_POST['id']) ? wc_clean($_POST['id']) : '';	
		if ( ! empty( $id ) ) {
			
			global $wpdb;
			$this->table = $wpdb->prefix . 'alp_pickup_location';
			$locations = alp_pro_addon()->admin->get_data();
			$location = alp_pro_addon()->admin->get_data_byid($id);
			$location = (array) $location;
			unset($location['id']);
			$location['store_name'] = $location['store_name'] . ' - copy';
			$location['position'] = count($locations);
			
			$wpdb->insert( $this->table, $location );
			
			echo json_encode( array('success' => 'true') );
			die();
	
		}
	}
	
	/*
	*  multiple location sorting and save ajaxcall
	*/
	public function wclp_choose_default_location_form_callback() {			
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$sorting_by = get_option( 'wclp_pickup_location_sort', 'manual' );

		if ( isset($sorting_by) && 'distance' == $sorting_by ) {
			echo json_encode( array('success' => 'false') );
			die();
		}

		global $wpdb;
		
		$this->table = $wpdb->prefix . 'alp_pickup_location';
		
		$ids = isset($_POST['id']) ? wc_clean($_POST['id']) : '';

		$tabledata = $wpdb->get_row( $wpdb->prepare('SELECT * FROM %1s LIMIT 1', $this->table) );

		if (!isset($tabledata->position)) {
			$wpdb->query( $wpdb->prepare( 'ALTER TABLE %1s ADD position int NOT NULL', $this->table) );
		}
		
		foreach ($ids as $key => $id) {
			if (0 == $key) {
				update_option( 'location_defualt', wc_clean( $id ) );
			}
			$position = array( 'position' => $key );
			$wpdb->update( $this->table, $position, array('id' => wc_clean($id)) );
		}			
		
		echo json_encode( array('success' => 'true') );
		die();
	}
	
	/*
	* location enable/disable ajax call
	*/
	public function wclp_location_enable_callback() {			
		
		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$location_id = isset($_POST['id']) ? wc_clean($_POST['id']) : '';
		$location_enable = isset($_POST['check']) && 'true' == $_POST['check'] ? 1 : 0;
		
		$location = (array) alp_pro_addon()->admin->get_data_byid($location_id);
		
		$tabledata = $wpdb->get_row( $wpdb->prepare('SELECT * FROM %1s LIMIT 1', $this->table) );
		if (!isset($tabledata->store_enable)) {
			$wpdb->query( $wpdb->prepare( 'ALTER TABLE %1s ADD store_enable int NOT NULL AFTER id', $this->table) );
		}
		
		$location['store_enable'] = $location_enable;
		
		$wpdb->update( $this->table, $location, array('id' => wc_clean($location_id)) );
		
		echo json_encode( array('success' => 'true') );
		die();
	}
	
	/*
	* location delete ajax call
	*/
	public function wclp_location_delete_callback() {			
		
		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$location_id = isset($_POST['id']) ? wc_clean($_POST['id']) : '';
		
		$locations = alp_pro_addon()->admin->get_data();
		
		$session_data = WC()->session->get( 'pickup_location_id' );
		if ( isset($session_data) && $session_data == $location_id ) {
			WC()->session->set( 'pickup_location_id', min($locations)->id );
		}
		
		$wpdb->delete( $this->table, array( 'id' => $location_id ) ); 
		
		if (get_option('location_defualt') == $location_id) {
			update_option( 'location_defualt', min($locations)->id );
		}
		
		echo json_encode( array('success' => 'true') );
		die();
	}
	
	public function wclp_update_state_dropdown_fun() {	
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}
		
		$country = isset($_POST['country']) ? wc_clean($_POST['country']) : '';
		$countries_obj   = new WC_Countries();
		$default_county_states = $countries_obj->get_states( $country );
		if (empty($default_county_states)) {
			echo json_encode( array('state' => 'empty') );
			die();
		} else {
			ob_start();
			?>
			<option value="<?php echo esc_html($key); ?>"><?php esc_html_e('Select', 'woocommerce'); ?></option>
			<?php foreach ( (array) $default_county_states as $key => $val ) { ?>																
				<option value="<?php echo esc_html($key); ?>"><?php echo esc_html($val); ?></option>
			<?php 
			}
			$html = ob_get_clean();			
			echo json_encode( array('state' => $html) );
			die();
		}	
		echo json_encode( array('state' => 'empty') );
		die();		
	}
	
	public function wclp_update_edit_location_form_fun() {
		
		//$data = alp_pro_addon()->admin->get_data();
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$location_id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		
		ob_start();
		include('views/wclp-edit-location-form.php');
		$html = ob_get_clean();			
		echo json_encode( array('edit_location_form' => $html) );
		die();
	}
	
	public function wclp_apply_work_hours_fun() {

		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		/*if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			//die();
		}*/

		check_ajax_referer( 'wclp_apply_work_hours_nonce', 'security' );

		$location_id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
		$days = isset($_POST['days']) ? wc_clean($_POST['days']) : '';

		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$store_days = unserialize($location->store_days);
		foreach ($days as $key) {
			$store_days[$key]['checked'] = '1';
			$wclp_store_hour = isset($_POST['wclp_store_hour']) ? sanitize_text_field($_POST['wclp_store_hour']) : '';
			$wclp_store_hour_end = isset($_POST['wclp_store_hour_end']) ? sanitize_text_field($_POST['wclp_store_hour_end']) : '';
			$wclp_store_hour2 = isset($_POST['wclp_store_hour2']) ? sanitize_text_field($_POST['wclp_store_hour2']) : '';
			$wclp_store_hour_end2 = isset($_POST['wclp_store_hour_end2']) ? sanitize_text_field($_POST['wclp_store_hour_end2']) : '';
			
			if (isset($wclp_store_hour) && isset($wclp_store_hour_end)) {
				$store_days[$key]['wclp_store_hour'] = sanitize_text_field($wclp_store_hour);
				$store_days[$key]['wclp_store_hour_end'] = sanitize_text_field($wclp_store_hour_end);
			}
			if (isset($wclp_store_hour2) && isset($wclp_store_hour_end2)) {
				$store_days[$key]['wclp_store_hour2'] = sanitize_text_field($wclp_store_hour2);
				$store_days[$key]['wclp_store_hour_end2'] = sanitize_text_field($wclp_store_hour_end2);
			}
		}
		
		$location = array( 'store_days' => serialize($store_days) ); 				
		$wpdb->update( $this->table, $location, array('id' => wc_clean($location_id)) );
		
		$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : array();
		//set days from store_days if not set day in store_appt_days
		foreach ( $store_days as $day => $array ) {
			if ( !array_key_exists( $day, $store_appt_days) ) {
				$store_appt_days[$day] = $array;
			}
		}
		
		//unset days in store_appt_days if not set day in store_days
		foreach ( $store_appt_days as $day => $array ) {
			if ( !array_key_exists( $day, $store_days) ) {
				unset($store_appt_days[$day]);
			}
		}
		
		$location = array( 'store_appt_days' => serialize($store_appt_days) );				
		$wpdb->update( $this->table, $location, array('id' => wc_clean($location_id)) );
		
		ob_start();
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		include('views/html/business-hours-options.php');
		$html = ob_get_clean();			
		echo json_encode( array('business_hours_options' => $html) );
		die();

	}
	
	public function wclp_apply_appt_hours_fun() {

		global $wpdb;
		$this->table = $wpdb->prefix . 'alp_pickup_location';
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$location_id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
		$day = isset($_POST['day']) ? wc_clean($_POST['day']) : '';
		$date = isset($_POST['date']) ? wc_clean($_POST['date']) : '';

		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		
		if ( !empty($date) ) {
			
			$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
			$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
			$exclusive_appt_data = !empty( unserialize($location->store_appt_exclusive_days) ) ? unserialize($location->store_appt_exclusive_days) : array();

			$exclusive_day['checked'] = '1';
			$wclp_store_hour = isset($_POST['wclp_store_hour']) ? sanitize_text_field($_POST['wclp_store_hour']) : '';
			$wclp_store_hour_end = isset($_POST['wclp_store_hour_end']) ? sanitize_text_field($_POST['wclp_store_hour_end']) : '';
			$wclp_store_hour2 = isset($_POST['wclp_store_hour2']) ? sanitize_text_field($_POST['wclp_store_hour2']) : '';
			$wclp_store_hour_end2 = isset($_POST['wclp_store_hour_end2']) ? sanitize_text_field($_POST['wclp_store_hour_end2']) : '';
			
			if (isset($wclp_store_hour) && isset($wclp_store_hour_end)) {
				$exclusive_day['wclp_store_hour'] = sanitize_text_field($wclp_store_hour);
				$exclusive_day['wclp_store_hour_end'] = sanitize_text_field($wclp_store_hour_end);
			}
			if (isset($wclp_store_hour2) && isset($wclp_store_hour_end2)) {
				$exclusive_day['wclp_store_hour2'] = sanitize_text_field($wclp_store_hour2);
				$exclusive_day['wclp_store_hour_end2'] = sanitize_text_field($wclp_store_hour_end2);
			}
			
			$appt_day = isset($store_appt_days[$day]) ? $store_appt_days[$day] : ''; 
			$exclusive_appt_data[$date][$day] = $exclusive_day;

			$data = array( 'store_appt_exclusive_days' => serialize($exclusive_appt_data) );
	
			$wpdb->update( $this->table, $data, array('id' => wc_clean($location_id)) );
		
		} else {
		
			$store_appt_days = !empty($location->store_appt_days) ? unserialize($location->store_appt_days) : array();
			$exclusive_appt_data = !empty( $location->store_appt_exclusive_days ) ? unserialize($location->store_appt_exclusive_days) : array();
			
			$exclusive_day['checked'] = '1';
			$wclp_store_hour = isset($_POST['wclp_store_hour']) ? sanitize_text_field($_POST['wclp_store_hour']) : '';
			$wclp_store_hour_end = isset($_POST['wclp_store_hour_end']) ? sanitize_text_field($_POST['wclp_store_hour_end']) : '';
			$wclp_store_hour2 = isset($_POST['wclp_store_hour2']) ? sanitize_text_field($_POST['wclp_store_hour2']) : '';
			$wclp_store_hour_end2 = isset($_POST['wclp_store_hour_end2']) ? sanitize_text_field($_POST['wclp_store_hour_end2']) : '';
			
			if (isset($wclp_store_hour) && isset($wclp_store_hour_end)) {
				$exclusive_day['wclp_store_hour'] = sanitize_text_field($wclp_store_hour);
				$exclusive_day['wclp_store_hour_end'] = sanitize_text_field($wclp_store_hour_end);
			}
			if (isset($wclp_store_hour2) && isset($wclp_store_hour_end2)) {
				$exclusive_day['wclp_store_hour2'] = sanitize_text_field($wclp_store_hour2);
				$exclusive_day['wclp_store_hour_end2'] = sanitize_text_field($wclp_store_hour_end2);
			}
			
			
			$store_appt_days[$day] = $exclusive_day;
			
			//appt data
			$data = array( 'store_appt_days' => serialize($store_appt_days) );
			$wpdb->update( $this->table, $data, array('id' => wc_clean($location_id)) );
			
			
			foreach ( $exclusive_appt_data as $date => $array ) {
				if ( isset($exclusive_appt_data[$date][$day]) ) {
					unset( $exclusive_appt_data[$date] );
				}	
			}
			
			//exclusive data
			$data2 = array( 'store_appt_exclusive_days' => serialize($exclusive_appt_data) );
			$wpdb->update( $this->table, $data2, array('id' => wc_clean($location_id)) );
			
		}
		
		ob_start();
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		include('views/html/appointments-options.php');
		$html = ob_get_clean();			
		echo json_encode( array('appointments_options' => $html) );
		die();
	}
	
	public function wclp_appt_hours_popup_html() {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$date = isset($_POST['date']) ? wc_clean($_POST['date']) : '';
		$dayName = isset($_POST['dayName']) ? wc_clean($_POST['dayName']) : '';
		$location_id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
		
		//$data = alp_pro_addon()->admin->get_data();
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		
		$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
		$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
		$exclusive_appt_data = isset( $location->store_appt_exclusive_days ) ? unserialize($location->store_appt_exclusive_days) : array();
				
		if ( isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date]) ) {
			$appt_data = $exclusive_appt_data[$date];
		} else {
			$appt_data = $store_appt_days;	
		}
		
		$send_time_array = array();										
		for ( $hour = 0; $hour < 24; $hour++ ) {
			for ( $min = 0; $min < 60; $min = $min + apply_filters('alp_work_hours_slots', $default = '30') ) {
				$this_time = gmdate( 'H:i', strtotime( "$hour:$min" ) );
				$send_time_array[ $this_time ] = $this_time;
			}	
		} 
		
		ob_start();
		?>
		<div id="appt_hours_popup_html" class="popupwrapper alp-hours-popup">
			<div class="popuprow">
				<span class="dashicons dashicons-no-alt popup_close_icon"></span>
				<div class="alp-hours-popup">
					<div id="header-text">
					  <span style=""><?php esc_html_e( 'From', 'advanced-local-pickup-pro' ); ?></span>
					  <span><?php esc_html_e( ' To', 'advanced-local-pickup-pro' ); ?></span>
					</div>
					<span class="morning-time"><select class="select <?php echo esc_html($dayName); ?> wclp_pickup_time_select start" name="wclp_store_appt_days[<?php echo esc_html($date); ?>][<?php echo esc_html($dayName); ?>][wclp_store_hour]"> <option value="" ><?php esc_html_e( 'Select', 'woocommerce' ); ?></option>
						<?php foreach ((array) $send_time_array as $key1 => $val1 ) { ?>
						<option value="<?php echo esc_html($key1); ?>" <?php echo ( isset($appt_data[$dayName]['wclp_store_hour']) && $appt_data[$dayName]['wclp_store_hour'] == $key1 ) ? 'selected' : ''; ?>><?php echo esc_html($val1); ?></option>
						<?php } ?>
					</select>
					<select class="select <?php echo esc_html($dayName); ?> wclp_pickup_time_select end" name="wclp_store_appt_days[<?php echo esc_html($date); ?>][<?php echo esc_html($dayName); ?>][wclp_store_hour_end]"><option value=""><?php esc_html_e( 'Select', 'woocommerce' ); ?></option>
						<?php foreach ((array) $send_time_array as $key2 => $val2 ) { ?>			
							<option value="<?php echo esc_html($key2); ?>" <?php echo ( isset($appt_data[$dayName]['wclp_store_hour_end']) && $appt_data[$dayName]['wclp_store_hour_end'] == $key2 ) ? 'selected' : ''; ?>><?php echo esc_html($val2); ?></option>
						<?php } ?>
					</select>
					<span class="dashicons dashicons-trash" ></span>
					</span>
					<span class="afternoon-time <?php echo ( !isset($appt_data[$dayName]['wclp_store_hour2']) || '' == $appt_data[$dayName]['wclp_store_hour2'] ) ? 'hide-select-box' : ''; ?>">
						<select class="select <?php echo esc_html($dayName); ?> wclp_pickup_time_select start2" name="wclp_store_appt_days[<?php echo esc_html($date); ?>][<?php echo esc_html($dayName); ?>][wclp_store_hour2]"><option value=""><?php esc_html_e( 'Select', 'woocommerce' ); ?></option>
							<?php foreach ((array) $send_time_array as $key1 => $val1 ) { ?>
							<option value="<?php echo esc_html($key1); ?>" <?php echo ( isset($appt_data[$dayName]['wclp_store_hour2']) && $appt_data[$dayName]['wclp_store_hour2'] == $key1 ) ? 'selected' : ''; ?>><?php echo esc_html($val1); ?></option>
							<?php } ?>
						</select>
						<select class="select <?php echo esc_html($dayName); ?> wclp_pickup_time_select end2" name="wclp_store_appt_days[<?php echo esc_html($date); ?>][<?php echo esc_html($dayName); ?>][wclp_store_hour_end2]"><option value=""><?php esc_html_e( 'Select', 'woocommerce' ); ?></option>
							<?php foreach ((array) $send_time_array as $key2 => $val2 ) { ?>			
								<option value="<?php echo esc_html($key2); ?>" <?php echo ( isset($appt_data[$dayName]['wclp_store_hour_end2']) && $appt_data[$dayName]['wclp_store_hour_end2'] == $key2 ) ? 'selected' : ''; ?>><?php echo esc_html($val2); ?></option>
							<?php } ?>
						</select>
						<span class="dashicons dashicons-trash"></span>
					</span>
					<p class="add-interval" <?php echo ( isset($appt_data[$dayName]['wclp_store_hour_end2']) && '' != $appt_data[$dayName]['wclp_store_hour_end2'] ) ? 'style="display:none"' : ''; ?>>+ Add Interval</p>
				</div>
				<button type="button" class="wclp-appt-apply button-primary" data-date="<?php echo esc_html($date); ?>" value="<?php echo esc_html($dayName); ?>"><?php esc_html_e( 'Apply To ' . ucfirst($dayName) . ' ' . gmdate('j/n/Y', strtotime($date)), 'advanced-local-pickup-pro'); ?></button>
				<button type="button" class="wclp-appt-days-apply button-primary" value="<?php echo esc_html($dayName); ?>"><?php esc_html_e( 'Apply To All ' . ucfirst($dayName) . 's', ''); ?></button>
			</div>
			<div class="popupclose"></div>
		</div>
		<?php
		$html = ob_get_clean();	
		echo json_encode( array('appt_hours_popup_html' => $html) );
		die();
	}
	
	/**
	 * Set a cart item for session with pickup data for force pickup item
	 *
	 * @internal
	 *
	 * @since 2.0.0
	 */
	public function alp_reschadule_pickup_form_update_callback() {
		
		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		if ( ! empty( $_POST ) ) {
			
			$order_id = isset($_POST['order_id']) ? sanitize_text_field($_POST['order_id']) : '';
			$pickup_items = isset($_POST['pickup_items']) ? sanitize_text_field($_POST['pickup_items']) : '';
			$pickup_items = explode( ',', $pickup_items);
			if ( !empty($order_id) ) {
				$order = wc_get_order( $order_id );
				$location_id = isset($_POST['reschadule_location']) ? sanitize_text_field($_POST['reschadule_location']) : '';
				if ( !empty($pickup_items) ) {
					$location_ids = $order->get_meta( 'alp_location_ids', true );
					foreach ( $pickup_items as $product_id ) {
						$location_ids[$product_id] = $location_id;
					}
					$order->update_meta_data( 'alp_location_ids', $location_ids );
					$order->save();
				}
				if ( !empty($location_id) ) {
					$appt_data = $order->get_meta( 'alp_appt_data', true );
					$date = isset($_POST['appt_date_option']) && !empty($_POST['appt_date_option']) ? sanitize_text_field($_POST['appt_date_option']) : '';
					$time = isset($_POST['appt_time_option']) && !empty($_POST['appt_time_option']) ? sanitize_text_field($_POST['appt_time_option']) : '';
					if ( !empty($date) && !empty($time) ) {
						$appt_data[$order_id]['location_id'] = $location_id;
						$appt_data[$order_id]['pickup_date'] = gmdate('d-m-Y', strtotime($date));
						$appt_data[$order_id]['pickup_time'] = $time;
						$order->update_meta_data( 'alp_appt_data', $appt_data );
						$order->save();
					} else {
						echo json_encode( array('success' => 'false' ) );
						die();
					}
					
				}
				
			}
			
			alp_pro_addon()->email_trigger_ready_pickup($order_id);
			
		}
		
		echo json_encode( array('success' => 'true' ) );
		die();

	}
	
	public function get_time_slot_html( $date, $time) {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$date = isset($_POST['date']) && !empty($_POST['date']) ? sanitize_text_field($_POST['date']) : $date;
		$time = isset($_POST['time']) && !empty($_POST['time']) ? sanitize_text_field($_POST['time']) : $time;
		$location_id = isset($_POST['location_id']) && !empty($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		
		$send_time_array = array();	
		
		if ( get_option('wclp_cart_checkout_layout', 'inline') == 'popup') {
			$date = substr($date, 4, 11);
		}

		$date = gmdate('j-n-Y', strtotime($date));
					
		//get full name of day
		$dayofweek = gmdate('l', strtotime($date));
		
		$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
		$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
		$exclusive_appt_data = isset( $location->store_appt_exclusive_days ) ? unserialize($location->store_appt_exclusive_days) : array();
			
		if ( isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date]) ) {
			$appt_data = $exclusive_appt_data[$date];
		} else {
			$appt_data = $store_appt_days;	
		}

		if (isset($appt_data[strtolower($dayofweek)])) {
			$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
			$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
			$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
			$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
		}

		if ( isset($start) && !empty($start) ) {
			$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
			$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
			$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
			$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
			$slot = 'hour' == $unit ? $Time*60 : $Time;

			$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
			$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
			$time_slots = array_merge($time_slot1, $time_slot2);
			ob_start();
			
			if ( current_action() == 'wp_ajax_appt_reschadule_time_slot_html' ) {
				$class = 'alp_location--reschadule_time';
				$style = 'style="margin: 5px 5px 0 0;"';
			} else {
				$class = 'appt_time--items';
				$style = '';
			}

			?>
			<select class="select <?php esc_attr_e($class); ?>" name="appt_time_option" <?php echo esc_attr($style); ?> > 
				<option value=""><?php esc_html_e( 'Select time', 'woocommerce' ); ?></option>
				<?php 
				foreach ( (array) $time_slots as $key1 => $val1 ) {
					if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
						if ( '12' == $time_format ) {
							$last_digit = explode(':', $val1);
							if ('00' == end($last_digit)) {
								$val1 = gmdate('g:ia', strtotime($val1));
								$preVal = gmdate('g:ia', strtotime($preVal));
							} else {
								$val1 = gmdate('g:ia', strtotime($val1));
								$preVal = gmdate('g:ia', strtotime($preVal));
							}	
						}
						if ( alp_pro_addon()->common->is_available_time_slot( $preVal, $val1, $date, $location_id ) ) { 
							?>
							<option value="<?php echo esc_html($preVal . '-' . $val1); ?>" <?php echo $preVal . '-' . $val1 == $time ? 'selected' : ''; ?>><?php echo esc_html($preVal . ' - ' . $val1); ?></option>
						<?php 
						}
					}
				$preVal = $val1;
				} 
				?>
			</select>
		<?php 
		}
		$html = ob_get_clean();	
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$store_days = !empty($location->store_days) ? unserialize($location->store_days): get_option('wclp_store_days');
		$store_appt_days = !empty($location->store_appt_days) ? unserialize($location->store_appt_days): $store_days;
		
		$days = array();
		foreach ($store_days as $day => $val) {
			if ( isset($store_appt_days[$day]['checked']) && '1' == $store_appt_days[$day]['checked'] ) {
				$days[] = (int) gmdate('w', strtotime($day));	
			}
		}
		
		$date_format = 'dd-mm-yy';
		if ( get_option('date_format') === 'F j, Y' ) {
			$date_format = 'MM d, yy';
		}
		if ( get_option('date_format') === 'Y-m-d' ) {
			$date_format = 'yy-mm-d';
		}
		if ( get_option('date_format') === 'm/d/Y' ) {
			$date_format = 'mm/d/yy';
		}
		if ( get_option('date_format') === 'd/m/Y' ) {
			$date_format = 'mm/d/yy';
		}
		
		echo json_encode( array('success' => 'true', 'get_time_slot' => $html, 'location'=> $location, 'store_appt_days' => $days, 'date_format' => $date_format) );
		exit;
	}

	public function get_reschadule_time_slot_html() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$date = isset($_POST['date']) && !empty($_POST['date']) ? sanitize_text_field($_POST['date']) : '';
		$time = isset($_POST['time']) && !empty($_POST['time']) ? sanitize_text_field($_POST['time']) : '';
		$location_id = isset($_POST['location_id']) && !empty($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		
		$send_time_array = array();	
		
		if ( 'popup' == get_option('wclp_cart_checkout_layout', 'inline')) {
			$date = substr($date, 4, 11);
		}

		$date = gmdate('j-n-Y', strtotime($date));
					
		//get full name of day
		$dayofweek = gmdate('l', strtotime($date));
		
		$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
		$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
		$exclusive_appt_data = isset( $location->store_appt_exclusive_days ) ? unserialize($location->store_appt_exclusive_days) : array();
			
		if ( isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date]) ) {
			$appt_data = $exclusive_appt_data[$date];
		} else {
			$appt_data = $store_appt_days;	
		}

		if (isset($appt_data[strtolower($dayofweek)])) {
			$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
			$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
			$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
			$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
		}

		if ( isset($start) && !empty($start) ) {
			$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
			$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
			$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
			$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
			$slot = 'hour' == $unit ? $Time*60 : $Time;

			$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
			$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
			$time_slots = array_merge($time_slot1, $time_slot2);
			ob_start();
			
			if ( current_action() == 'wp_ajax_appt_reschadule_time_slot_html' ) {
				$class = 'alp_location--reschadule_time';
				$style = 'style="margin: 5px 5px 0 0;"';
			} else {
				$class = 'appt_time--items';
				$style = '';
			}

			?>
			<select class="select <?php esc_attr_e($class); ?>" name="appt_time_option" <?php echo esc_attr($style); ?> > 
				<option value=""><?php esc_html_e( 'Select time', 'woocommerce' ); ?></option>
				<?php 
				foreach ( (array) $time_slots as $key1 => $val1 ) {
					if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
						if ( '12' == $time_format ) {
							$last_digit = explode(':', $val1);
							if ('00' == end($last_digit)) {
								$val1 = gmdate('g:ia', strtotime($val1));
								$preVal = gmdate('g:ia', strtotime($preVal));
							} else {
								$val1 = gmdate('g:ia', strtotime($val1));
								$preVal = gmdate('g:ia', strtotime($preVal));
							}	
						}
						if ( alp_pro_addon()->common->is_available_time_slot( $preVal, $val1, $date, $location_id ) ) { 
							?>
							<option value="<?php echo esc_html($preVal . '-' . $val1); ?>" <?php echo $preVal . '-' . $val1 == $time ? 'selected' : ''; ?>><?php echo esc_html($preVal . ' - ' . $val1); ?></option>
						<?php 
						}
					}
				$preVal = $val1;
				} 
				?>
			</select>
		<?php 
		}
		$html = ob_get_clean();	
		
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$store_days = !empty($location->store_days) ? unserialize($location->store_days): get_option('wclp_store_days');
		$store_appt_days = !empty($location->store_appt_days) ? unserialize($location->store_appt_days): $store_days;
		
		$days = array();
		foreach ($store_days as $day => $val) {
			if ( isset($store_appt_days[$day]['checked']) && '1' == $store_appt_days[$day]['checked'] ) {
				$days[] = (int) gmdate('w', strtotime($day));	
			}
		}
		
		$date_format = 'dd-mm-yy';
		if ( get_option('date_format') === 'F j, Y' ) {
			$date_format = 'MM d, yy';
		}
		if ( get_option('date_format') === 'Y-m-d' ) {
			$date_format = 'yy-mm-d';
		}
		if ( get_option('date_format') === 'm/d/Y' ) {
			$date_format = 'mm/d/yy';
		}
		if ( get_option('date_format') === 'd/m/Y' ) {
			$date_format = 'mm/d/yy';
		}
		
		echo json_encode( array('success' => 'true', 'get_time_slot' => $html, 'location'=> $location, 'store_appt_days' => $days, 'date_format' => $date_format) );
		exit;
	}
	
	public function reschadule_datepicker_html() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field($_POST['nonce']) : '';
		if ( ! wp_verify_nonce( $nonce, 'alp-ajax-nonce' ) ) {
			die();
		}

		$location_id = isset($_POST['location_id']) && !empty($_POST['location_id']) ? sanitize_text_field($_POST['location_id']) : '';
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$store_enable_appt = isset($location->store_enable_appt) ? $location->store_enable_appt : '';
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		$allow_pickup_per_item = isset($wclp_local_pickup_controls['allow_pickup_per_item']) ? $wclp_local_pickup_controls['allow_pickup_per_item'] : '';
		
		for ( $i = 1; $i < 8; $i++ ) {
			$defualt_date = strtotime('+' . $i . ' day');
			$new_format = gmdate('j-n-Y', $defualt_date);
			$dayofweek = gmdate('l', strtotime($new_format));
			if ( isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
				$new_format = gmdate('d-m-Y', $defualt_date); 
				break;
			} 
		}
		$date = $new_format;
		ob_start();
		
		?>
		<input type="text" name ="appt_date_option" class="datepicker alp_location--reschadule_date" value="<?php esc_html_e( 'Select Date', 'advanced-local-pickup-pro' ); ?>" style="width: auto;min-width: 250px;margin: 5px 5px 0 0;" readonly>				
		<?php
		$html = ob_get_clean();	
		
		echo json_encode( array('success' => 'true', 'reschadule_datepicker' => $html, 'store_enable_appt' => $store_enable_appt, 'allow_pickup_per_item' => $allow_pickup_per_item ) );
		exit;
	}
	
}
