<?php
/**
 * Alp pro common 
 *
 * @class   Advanced_Local_Pickup_Common_Functions
 * @package WooCommerce/Classes
 */


if (!defined('ABSPATH')) {
	exit;
}

/**
 * Advanced_Local_Pickup_Common_Functions class.
 */
class Advanced_Local_Pickup_Common_Functions {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return alp_pro_common
	 */
	public static function get_instance() {

		if (null === self::$instance) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	 */
	private static $instance;

	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	 */
	public function __construct() {
		$this->init();
	}

	/*
	 * init function
	 *
	 * @since  1.0
	 */
	public function init() {
		//callback for disable payment gatway for restricted country
		add_filter( 'woocommerce_available_payment_gateways', array( $this, 'is_payment_method_exclude_by_location' ), 10, 1 );
	}

	/**
	 * Check defualt available location id and return it
	 */
	public function get_defualt_location_id( $product_id ) {

		if (is_cart() || is_checkout()) {

			$locations = alp_pro_addon()->admin->get_data();

			foreach ((array) $locations as $key => $location) {
				if ($this->is_local_pickup_item_by_location($product_id, $location)) {
					if (get_option('location_defualt') == $location->id) {
						return get_option('location_defualt');
					} else {
						return $location->id;
					}
				}
			}

		}

	}

	/**
	 * Check item is_pickup OR not? by single location
	 */
	public function is_local_pickup_item_by_location( $product_id, $location ) {

		if (!$product_id) {
			return;
		}

		if (!empty($location->store_selected_products)
		&& in_array($product_id, (array) unserialize($location->store_selected_products))) {
			return true;
		}

		if (!empty($location->store_excluded_products)
		&& in_array($product_id, (array) unserialize($location->store_excluded_products))) {
			return false;
		}

		$terms = get_the_terms($product_id, 'product_cat');

		foreach ($terms as $term) {
			$cat_id = $term->term_id;
			if (!empty($location->store_selected_categories)
			&& in_array($cat_id, (array) unserialize($location->store_selected_categories))) {
				return true;
			}
			if (!empty($location->store_excluded_categories)
			&& in_array($cat_id, (array) unserialize($location->store_excluded_categories))) {
				return false;
			}
		}

		return true;

	}

	/**
	 * Check item is_pickup OR not? by multiple location
	 */
	public function is_local_pickup_item( $product_id ) {

		if (!$product_id) {
			return;
		}

		$pickup_available = false;
		$pickup_not_available = true;

		$locations = alp_pro_addon()->admin->get_available_locations_data();
		

		$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);

		if ('yes' == $must_be_pickedup) {
			return true;
		}

		foreach ((array) $locations as $key => $location) {

			if (empty($location->store_selected_products) || !empty($location->store_selected_products) && in_array($product_id, (array) unserialize($location->store_selected_products))) {
				$pickup_available = true;
			}

			if (!empty($location->store_excluded_products)
			&& in_array($product_id, (array) unserialize($location->store_excluded_products))) {
				$pickup_available = false;
				$pickup_not_available = false;
			}

			if ($pickup_not_available) {
				$terms = get_the_terms($product_id, 'product_cat');

				foreach ($terms as $term) {
					$cat_id = $term->term_id;

					if (empty($location->store_selected_categories) || !empty($location->store_selected_categories)
					&& in_array($cat_id, (array) unserialize($location->store_selected_categories))) {
						$pickup_available = true;
						
					}
					if (!empty($location->store_excluded_categories)
					&& in_array($cat_id, (array) unserialize($location->store_excluded_categories))) {
						$pickup_available = false;
					}
				}
			}
		}

		return $pickup_available;

	}

	/**
	 * Check item is_not_pickup_item_for_all_location? by all locations
	 */
	public function is_not_pickup_item_for_all_location( $product_id ) {

		if (!$product_id) {
			return false;
		}

		$locations = alp_pro_addon()->admin->get_available_locations_data();
		foreach ((array) $locations as $key => $location) {
			if ($this->is_local_pickup_item_by_location($product_id, $location)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Check item is excluded from any location?
	 */
	public function is_pickup_location_exclude( $location ) {

		foreach (WC()->cart->get_cart() as $item_key => $item) {

			$product_id = $item['product_id'];

			if (!empty($location->store_selected_products) && !in_array($product_id, (array) unserialize($location->store_selected_products))) {
				return false;
			}

			if (!empty($location->store_excluded_products)
			&& in_array($product_id, (array) unserialize($location->store_excluded_products))) {
				return false;
			}

			$terms = get_the_terms($product_id, 'product_cat');

			foreach ($terms as $term) {
				$cat_id = $term->term_id;

				if (!empty($location->store_selected_categories)
				&& !in_array($cat_id, (array) unserialize($location->store_selected_categories))) {
					return false;
				}
				if (!empty($location->store_excluded_categories)
				&& in_array($cat_id, (array) unserialize($location->store_excluded_categories))) {
					return false;
				}

			}

		}
		return true;
	}

	/**
	 * Check time slot available and return bool
	 */
	public function is_available_time_slot( $preVal, $val1, $date, $location_id ) {

		$start_time = gmdate('H:i', strtotime($preVal));
		$end_time = gmdate('H:i', strtotime($val1));

		$orders = wc_get_orders(array(
			'limit' => -1,
			'meta_key' => 'alp_appt_data', // The postmeta key field
			'meta_compare' => 'EXISTS', // The comparison argument
			'return' => 'ids',
		));

		$i = 0;
		foreach ($orders as $order_id) {
			$order = wc_get_order( $order_id );
			$alp_appt_data = $order->get_meta( 'alp_appt_data', true );
			//$alp_appt_data = get_post_meta($order_id, 'alp_appt_data', true);
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			if (isset($alp_appt_data[$order_id]['location_id']) && $location_id == $alp_appt_data[$order_id]['location_id']) {
				if (isset($alp_appt_data[$order_id]['pickup_date']) && gmdate('j-n-Y', strtotime($alp_appt_data[$order_id]['pickup_date'])) == $date) {
					$i = ++$i;
					$arr = explode('-', $alp_appt_data[$order_id]['pickup_time']);
					$start = isset($arr[1]) ? gmdate('H:i', strtotime($arr[0])) : '';
					$end = isset($arr[1]) ? gmdate('H:i', strtotime($arr[1])) : '';

					$over_slot[$alp_appt_data[$order_id]['pickup_time']] = $i;

					$limit_slot = isset($location->store_appt_time_slot_limit) ? $location->store_appt_time_slot_limit : '1';

					if ('no-limit' != $limit_slot && $start_time == $start && $end_time == $end && $over_slot[$alp_appt_data[$order_id]['pickup_time']] >= $limit_slot) {
						return false;
					}
				}
			}
		}
		return true;
	}

	/**
	 * Return cart checkout popup design html
	 */
	public function get_local_pickup_cart_checkout_html( $location_id, $location, $locations ) {
		
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		?>
		<div class="popup">
			<h3 class="the_title"><?php esc_html_e('Local Pickup', 'advanced-local-pickup-pro'); ?></h3>
			<div class="locatios-block cfw-input-wrap cfw-select-input cfw-floating-label">
				<label class="the_heading">
					<?php
					if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && 1 != count($locations)) {
						esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
					} else if (1 == count($locations)) {
						esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
							esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
						}
					} else {
						esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
					}
					?>
				</label>
				<?php if (1 != count($locations)) { ?>
					<select class="select selected_pickup_location" name="selected_pickup_location" style="padding-right: 25px;">
						<option value="" data-address="Please select a location for pickup items">
							<?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
						<?php
						foreach ((array) $locations as $key => $location_data) {
							if (isset($location_data->store_enable) && 1 == $location_data->store_enable && $this->is_pickup_location_exclude($location_data)) {
								$address = alp_pro_addon()->admin->get_store_address_by_id($location_data->id);
								?>
						<option value="<?php echo esc_html($location_data->id); ?>" <?php $location_data->id == $location_id ? esc_html_e('selected') : ''; ?> data-address="<?php echo esc_html($address); ?>">
							<?php echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location_data->store_name)); ?></option>
						<?php
							}
						}
						?>
					</select>
				<?php
				} else { 
					?>
					<input type="hidden" class="selected_pickup_location" name="selected_pickup_location"
					value="<?php echo esc_html( get_option('location_defualt', min($locations)->id) ); ?>">
					<?php
					$address = alp_pro_addon()->admin->get_store_address_by_id( get_option('location_defualt', min($locations)->id) );
					echo '<p class="pickup-location-details">' . esc_html(alp_pro_addon()->admin->get_slaches_data_byid( min($locations)->store_name ) . $address) . '</p>';
				}
				?>
			</div>
			<div class="calender-block" style="display:none;">
				<label class="the_heading calender-heading"><?php esc_html_e('When would you like to Pickup:', 'advanced-local-pickup-pro'); ?></label>
				<?php
				$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
				for ($i = 1; $i < 8; $i++) {
					$defualt_date = strtotime('+' . $i . ' day');
					$new_format = gmdate('j-n-Y', $defualt_date);
					$dayofweek = gmdate('l', strtotime($new_format));
					if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
						$new_format = gmdate('d-m-Y', $defualt_date);
						break;
					}
				}

				$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
				$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

				$defualt_date = strtotime('+' . $days . ' day');
				$new_format = gmdate('d-m-Y', $defualt_date);

				$appt_session_data = isset(WC()->session) ? unserialize(WC()->session->get('appt_data')) : array();

				$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : $new_format;
				$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';

				?>
				<div class="datepicker appt_date--items"></div>
			</div>

			<div class="time-slot-block cfw-input-wrap cfw-select-input cfw-floating-label" style="display:none;">
				<label class="the_heading time-slot-heading"><?php esc_html_e('What time would you like to Pickup?', 'advanced-local-pickup-pro'); ?></label>
				<select class="select appt_time--items" name="appt_time_option" style="">
					<option value=""><?php esc_html_e('Select time', 'woocommerce'); ?></option>
					<?php
					$date = gmdate('j-n-Y', strtotime($date));

					//get full name of day
					$dayofweek = gmdate('l', strtotime($date));

					$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
					$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
					$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

					if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
						$appt_data = $exclusive_appt_data[$date];
					} else {
						$appt_data = $store_appt_days;
					}

					if (isset($appt_data[strtolower($dayofweek)])) {
						$start = isset($appt_data[strtolower($dayofweek)]['wclp_store_hour']) ? $appt_data[strtolower($dayofweek)]['wclp_store_hour'] : '';
						$end = isset($appt_data[strtolower($dayofweek)]['wclp_store_hour_end']) ? $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'] : '';
						$start2 = isset($appt_data[strtolower($dayofweek)]['wclp_store_hour2']) ? $appt_data[strtolower($dayofweek)]['wclp_store_hour2'] : '';
						$end2 = isset($appt_data[strtolower($dayofweek)]['wclp_store_hour_end2']) ? $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'] : '';
					}

					if (isset($start)) {
						$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
						$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
						$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
						$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
						$slot = 'hour' == $unit ? $Time * 60 : $Time;

						$time_slot1 = $this->getTimeSlots($slot, $start, $end);
						$time_slot2 = $this->getTimeSlots($slot, $start2, $end2);
						$time_slots = array_merge($time_slot1, $time_slot2);

						foreach ((array) $time_slots as $key1 => $val1) {
							if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
								if ( '12' == $time_format ) {
									$last_digit = explode( ':', $val1 );
									if ( '00' == end( $last_digit ) ) {
										$val1 = gmdate('g:ia', strtotime($val1));
										$preVal = gmdate('g:ia', strtotime($preVal));
									} else {
										$val1 = gmdate('g:ia', strtotime($val1));
										$preVal = gmdate('g:ia', strtotime($preVal));
									}
								}
								if ( $this->is_available_time_slot( $preVal, $val1, $date, $location_id ) ) { 
									?>
									<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>"<?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html($preVal . ' - ' . $val1); ?></option>
									<?php
								}
							}
							$preVal = $val1;
						}
					} 
					?>
				</select>
			</div>
			<button type="button" class="save-pickup-schedule-btn cfw-primary-btn">Save Pickup Schedule</button>
		</div>
		<?php
	}

	/**
	 * Get time array by slot(duration)
	 */
	public function getTimeSlots( $duration, $start, $end ) {

		set_time_limit(600);

		$time = array();
		if (empty($start) || empty($end) || empty($duration)) {
			return $time;
		}

		$start_time = $start;
		$end_time = $end;

		$minutes = round(abs(strtotime($end) - strtotime($start)) / 60, 2);

		if ($minutes <= $duration) {

			$time[$start] = $start;
			$time[$end] = $end;

		} else {

			$interval = $duration * 60;
			for ($currentTime = strtotime($start_time); $currentTime <= strtotime($end_time); $currentTime += $interval) {
				$formattedTime = gmdate('H:i', $currentTime);
				$time[$formattedTime] = $formattedTime;
			}

		}

		return $time;
	}

	/*
	* Return lat and long from the location id
	*/
	public function get_lat_long( $location_id ) {
		
		$array = array();
		$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
		if ( empty($address) ) {
			return $array;
		}
		
		$apikey = get_option('wclp_google_maps_apikey');

		if ( empty($apikey) ) {
			return $array;
		}

		$response  = wp_remote_get('https://maps.googleapis.com/maps/api/geocode/json?address=' . urlencode($address) . '&sensor=false&key=' . $apikey);
		
		if ( ( !is_wp_error($response) ) && ( 200 === wp_remote_retrieve_response_code( $response ) ) ) {
			
			// We convert the JSON to an array
			$geo = json_decode($response['body'], true);

			// If everything is cool
			if ('OK' == $geo['status']) {
			  $latitude = $geo['results'][0]['geometry']['location']['lat'];
			  $longitude = $geo['results'][0]['geometry']['location']['lng'];
			  $array = array('lat'=> $latitude ,'lng'=>$longitude);
			}
		}
		
		return $array;
	}

	/*
	* Return distance from the location id
	*/
	public function distance( $location_id ) {

		$ip = WC_Geolocation::get_ip_address();

		$response  = wp_remote_get('http://www.geoplugin.net/php.gp?ip=' . $ip);
		if ( ( !is_wp_error($response) ) && ( 200 === wp_remote_retrieve_response_code( $response ) ) ) {
			$loc = isset($response['body']) ? unserialize($response['body']) : '';
			$lat1 = $loc['geoplugin_latitude'];
			$lon1 = $loc['geoplugin_longitude'];
			
			$geo = $this->get_lat_long($location_id);
			$lat = isset($geo['lat']) && !empty($geo['lat']) ? $geo['lat'] : '';
			$lng = isset($geo['lng']) && !empty($geo['lng']) ? $geo['lng'] : '';
			$lat2 = $lat;
			$lon2 = $lng;
			
			$unit = 'K';
		
			if (( $lat1 == $lat2 ) && ( $lon1 == $lon2 )) {
				return 'zero';
			} else {
				if ( !$lon2 ) {
					return 'zero';
				}
				$theta = $lon1 - $lon2;
				$dist = sin(deg2rad($lat1)) * sin(deg2rad($lat2)) +  cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * cos(deg2rad($theta));
				$dist = acos($dist);
				$dist = rad2deg($dist);
				$miles = $dist * 60 * 1.1515;
				$unit = strtoupper($unit);

				if ( 'K' == $unit ) {
					return ( $miles * 1.609344 );
				} else if ( 'N' == $unit ) {
					return ( $miles * 0.8684 );
				} else {
					return $miles;
				}
			}
		}
		
		return 'zero';
	}

	/*
	* Return locations sorting array by distance
	*/
	public function get_sorting_array() {
		
		$locations = alp_pro_addon()->admin->get_available_locations_data();

		$array = array();
		foreach ((array) $locations as $location ) {
			$bool = $this->is_pickup_location_exclude_by_shippingMethod($location);
			if ( !$bool ) {
				continue;
			}
			$array[$location->id] = $this->distance($location->id);
			
		}

		$sorting_by = get_option( 'wclp_pickup_location_sort', 'manual' );
		if ( isset($sorting_by) && 'distance' == $sorting_by ) {
			asort($array);
		}
		
		foreach ( $array as $location_id => $distance ) {
			$array[$location_id] = alp_pro_addon()->admin->get_data_byid($location_id);
		}
		
		return $array;
	}

	/**
	 * Check pickup location is excluded from any shipping method?
	 */
	public function is_pickup_location_exclude_by_shippingMethod( $location ) {
		
		if ( is_checkout() || is_cart() ) {
			$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
			$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
			if (!empty($location->store_excluded_shippings)
			&& in_array($get_shipping[1], (array) unserialize($location->store_excluded_shippings))) {
				return false;
			}
		}

		return true;
	}

	/**
	 * Check payment method is excluded by location?
	 */
	public function is_payment_method_exclude_by_location( $available_gateways ) {
		
		if ( !is_checkout()  ) {
			return $available_gateways;
		}

		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';

		if ( isset($get_shipping[0]) && 'local_pickup' != $get_shipping[0]) {
			return $available_gateways;
		}

		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 == $wclp_local_pickup_controls['allow_pickup_per_item']) { 
			if ( !WC()->cart->is_empty() ) {
				foreach ( WC()->cart->get_cart() as $hash => $value ) {
					if ( ! $value['data']->needs_shipping() ) {
						continue;	
					}
					
					$session_data = unserialize(WC()->session->get($hash));
	
					if (isset($session_data['pickup_data'][$hash]['enabled']) && 'yes' == $session_data['pickup_data'][$hash]['enabled']) {
	
						$location_id = isset($session_data['pickup_data'][$hash]['location_id']) ? $session_data['pickup_data'][$hash]['location_id'] : '';
	
					}
					
					if (!isset($location_id)) {
						continue;
					}
	
					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					foreach ( $available_gateways as $id => $mathod  ) { 
						if (!empty($location->store_excluded_payments) && in_array($id, (array) unserialize($location->store_excluded_payments))) {
							unset( $available_gateways[$id] );
						}
					}
	
				}
			}
		
		} else {

			$session_data = WC()->session->get('pickup_location_id');
			$location_id = !empty($session_data) ? $session_data : '';
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			foreach ( $available_gateways as $id => $mathod  ) {
				if (!empty($location->store_excluded_payments) && in_array($id, (array) unserialize($location->store_excluded_payments))) {
					unset( $available_gateways[$id] );
				}
			}

		}

		return $available_gateways;
	}

	/*
	* Return grouping array of appt data array
	*/
	public function get_grouping_array_of_appt_data( $inputArray ) {
		
		$outputArray = [];

		foreach ( (array) $inputArray as $key => $value) {
			
			$id = $key;
			$key = $value['location_id'] . '-' . $value['date'] . '-' . $value['time'];

			if (!isset($outputArray[$key])) {
				$outputArray[$key] = $value;
				$outputArray[$key]['ids'][] = $id; 
			} else {
				// Merge the 'product' values when keys match
				if ( isset($value['product']) ) {
					$outputArray[$key]['product'] .= isset($value['product']) ? ', ' . $value['product'] : '';
				}
				$outputArray[$key]['ids'][] = $id;
			}
		}

		// Reset keys to start from 0
		$outputArray = array_values($outputArray);

		return $outputArray;

	}

}
