<?php
/**
 * Alp pro email 
 *
 * @class   Advanced_Local_Pickup_Email
 * @package WooCommerce/Classes
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Advanced_Local_Pickup_Email class.
 */
class Advanced_Local_Pickup_Email {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return Advanced_Local_Pickup_Email
	*/
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	*/
	private static $instance;
		
	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	*/
	public function __construct() {
		$this->init();

	}
	
	/*
	 * init function
	 *
	 * @since  1.0
	*/
	public function init() {
		
		add_action( 'woocommerce_after_register_post_type', array( $this, 'get_order_after_created_order' ), 100, 1 );

		add_action( 'woocommerce_order_status_pending_to_processing-lp', array( $this, 'email_trigger_new_order_email' ), 10, 2 );
		
	}

	public function get_order_after_created_order() {
		
		add_action( 'woocommerce_order_details_before_order_table', array( $this, 'add_location_address_detail_order' ), 10, 1 );
		add_action( 'woocommerce_order_details_before_order_table', array( $this, 'add_location_address_detail_order_received' ), 10, 1 );
		add_action( 'cfw_thank_you_content', array( $this, 'add_location_address_detail_order_received' ), 60, 1 );

		//adding hooks
		add_filter( 'woocommerce_email_before_order_table', array( $this, 'add_location_address_detail_emails' ), 2, 4 );
		
		//Reminder Cron Hooks
		add_action( 'alp_pickup_reminder_cron', array( $this, 'send_pickup_reminder_email_func' ), 10, 3 );	
		add_action( 'alp_nonAppt_pickup_reminder_cron', array( $this, 'send_pickup_reminder_email_func' ), 10, 3 );
		add_action( 'alp_nonAppt_pickup_reminder_2nd_cron', array( $this, 'send_pickup_reminder_email_func' ), 10, 3 );
		
		add_action('woocommerce_thankyou', array( $this, 'send_store_notification_email_func' ), 10 , 1 ); 
		
		add_action( 'woocommerce_order_status_changed', array( $this, 'action_woocommerce_order_status_changed' ), 10, 4 ); 
		
		//add pickup info in package slips
		add_action( 'wpo_wcpdf_before_order_details', array( $this, 'add_pick_info_packing_slip' ), 10, 2 ); 
		
	}

	public function email_trigger_new_order_email( $order_id, $order = false ) {
		WC()->mailer()->emails['WC_Email_New_Order']->trigger( $order_id, $order );
	}
	
	/*
	* get pickup location address in emails
	*/
	public function add_location_address_detail_emails( $order, $sent_to_admin, $plain_text, $email ) {		
		
		$wclp_display_pickup_instruction_statuses = get_option('wclp_display_pickup_instruction_statuses', array());
		
		if ( empty($wclp_display_pickup_instruction_statuses) ) {
			$wclp_display_pickup_instruction_statuses = array();
		}
		
		$wclp_display_pickup_instruction_statuses[] = 'wc-ready-pickup';
		$wclp_display_pickup_instruction_statuses[] = 'wc-processing-lp';		
				
		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
		
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
			return;		
		}

		if ( 'new_order' == $email->id ) {
			return;
		}
		
		if ( 'customer_invoice' == $email->id && !in_array( 'customer_invoice', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}	
		
		if ( 'customer_note' == $email->id && !in_array( 'customer_note', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'customer_refunded_order' == $email->id && !in_array( 'wc-refunded', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'cancelled_order' == $email->id && !in_array( 'wc-cancelled', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'failed_order' == $email->id && !in_array( 'wc-failed', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'customer_completed_order' == $email->id && !in_array( 'wc-completed', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'customer_processing_order' == $email->id && !in_array( 'wc-processing', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'customer_processing_lp_order' == $email->id && !in_array( 'wc-processing-lp', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}
		
		if ( 'customer_on_hold_order' == $email->id && !in_array( 'wc-on-hold', (array) $wclp_display_pickup_instruction_statuses) ) {
			return;
		}

		// add additional content in email
		$settings = alp_pro_addon()->admin->wclp_general_setting_fields_func();		
		$addional_content = get_option('wclp_emails_additional_content', $settings['wclp_emails_additional_content']['default']);
		echo '<p>' . wp_kses_post(stripslashes($addional_content), 'advanced-local-pickup-pro') . '</p>';
		
		$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-instruction.php';
				
		if ( file_exists( $local_template ) && is_writable( $local_template )) {	
			wc_get_template( 'emails/pickup-instruction.php', array( 'order_id' => $order->get_id(), 'email_id' => $email->id ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
		} else {
			wc_get_template( 'emails/pickup-instruction.php', array( 'order_id' => $order->get_id(), 'email_id' => $email->id ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
		}		
		
	}
	
	/*
	* Get pickup location address in order received page
	*/
	public function add_location_address_detail_order_received( $order ) {		
		
		$wclp_show_pickup_instruction = get_option('wclp_show_pickup_instruction');
		
		////IF display location details not enabel then @return;
		if (!is_order_received_page()) {
			return;
		}
		
		if (!isset($wclp_show_pickup_instruction['display_in_order_received_page'])) {
			return;
		}
		if ( '1' != $wclp_show_pickup_instruction['display_in_order_received_page'] ) {
			return;		
		}
				
		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
		
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method  ) {
			return;		
		}
		
		$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';
		if ( empty($location_ids)  ) {
			return;		
		}
		
		$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-instruction.php';
		echo '<section>';
		if ( file_exists( $local_template ) && is_writable( $local_template )) {	
			wc_get_template( 'myaccount/pickup-instruction.php', array( 'order_id' => $order->get_id() ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
		} else {
			wc_get_template( 'myaccount/pickup-instruction.php', array( 'order_id' => $order->get_id() ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
		}
		echo '</section>';
	}
	
	/*
	* Get pickup location address in view order page
	*/
	public function add_location_address_detail_order( $order_id ) {		

		$wclp_show_pickup_instruction = get_option('wclp_show_pickup_instruction');
		
		////IF display location details not enabel then @return;		
		if (!is_view_order_page()) {
			return;
		}

		if (!isset($wclp_show_pickup_instruction['display_in_order_details_page'])) {
			return;
		}
		if ( '1' != $wclp_show_pickup_instruction['display_in_order_details_page'] ) {
			return; 	
		}
		
		$order = wc_get_order($order_id);
		
		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
		
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
			return;		
		}

		$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';
		if ( empty($location_ids)  ) {
			return;		
		}
		
		$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-instruction.php';
		
		if ( file_exists( $local_template ) && is_writable( $local_template )) {	
			wc_get_template( 'myaccount/pickup-instruction.php', array( 'order_id' => $order_id ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
		} else {
			wc_get_template( 'myaccount/pickup-instruction.php', array( 'order_id' => $order_id ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
		}	
	}

	/**
	 * Send store mail.
	 * This method will create a object and call trigger method.
	 *
	 * @since  1.0.0
	*/
	public function send_store_notification_email_func( $order_id ) {
		
		$order = wc_get_order($order_id);
		
		$order_status  = $order->get_status();

		if ( 'processing' == $order_status || 'on-hold' == $order_status || 'processing-lp' == $order_status ) {
			// Iterating through order shipping items
			foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
				$shipping_method = $shipping_item_obj->get_method_id();						
			}
			
			//IF  dshipping method is not local pickup then @return;
			if ( !isset($shipping_method ) ) {
				return;
			}
			if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
				return;	
			}
			
			$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';
			
			if (empty($location_ids)) {
				return;
			}

			$alp_trigger_email_notification = $order ? $order->get_meta( 'alp_trigger_email_notification', true ) : '';
			if ( $alp_trigger_email_notification ) {
				return;
			}
			
			$ids = array();
			$appt_data = $order ? $order->get_meta( 'alp_appt_data', true ) : '';
			foreach ( $location_ids as $product_id => $location_id) { 
				
				if ( isset($appt_data) && !empty($appt_data) ) {
					if ( isset($appt_data[$order_id][$product_id]) ) {
						$val = $appt_data[$order_id][$product_id];
						$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
						$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
					} else {
						$val = $appt_data[$order_id];
						$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
						$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
					}
				}

				$new_product_data[$product_id] = array(
					'location_id' => $location_id,
					'date'	=> $date,
					'time' => $time,
				);
				
				$ids[$location_id][] = $product_id;
			}
			
			$outputArray = alp_pro_addon()->common->get_grouping_array_of_appt_data($new_product_data);

			if ( !empty($outputArray) ) {

				foreach ( $outputArray as $key => $val ) {
					
					$location_id = isset( $val[ 'location_id' ] ) ? $val[ 'location_id' ] : '';
					$product_ids = isset( $val[ 'ids' ] ) ? $val[ 'ids' ] : '';
					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					if ( isset( $location->store_enable_pickup_reminder ) && '1' == $location->store_enable_pickup_reminder ) {
						$reminderTime = !empty($location->store_pickup_reminder_time) && isset($location->store_pickup_reminder_time) ? unserialize($location->store_pickup_reminder_time) : array();
						$Time = !empty($reminderTime['time']) ? $reminderTime['time'] : '15';
						$unit = !empty($reminderTime['unit']) ? $reminderTime['unit'] : 'min';
						$Unit = 'min' == $unit ? 'minute' : $unit;
						$date = isset( $val[ 'date' ] ) ? $val[ 'date' ] : '';
						$time = isset( $val[ 'time' ] ) ? $val[ 'time' ] : '';
						$arr = explode('-', $time, 2);
						if ( isset($arr[0]) ) {
							$firstTime = $arr[0];
							$first_cron = new DateTime( gmdate('d-m-Y', strtotime($date)) . $firstTime, new DateTimeZone( wc_timezone_string() ) ); 
							$first_cron->modify( '-' . $Time . ' ' . $Unit );
						}
					}

					if ( isset($first_cron) && !empty($first_cron) ) {
						wp_schedule_event( $first_cron->getTimestamp(), 'daily', 'alp_pickup_reminder_cron', array( $order_id, $location_id, $product_ids ) );
					}
				}
			}
			
			foreach ( $outputArray as $data ) {

				$location = alp_pro_addon()->admin->get_data_byid($data['location_id']);
				
				$wc_emails      = WC_Emails::instance();
				$emails         = $wc_emails->get_emails();	
				$mailer 		= WC()->mailer();
				$sent_to_admin 	= false;
				$plain_text 	= false;
				$message 		= $this->email_content( $order_id, $data['ids'], $data, $location );
				$email_heading	= esc_html( 'Pickup Order from ' . $location->store_name, 'advanced-local-pickup-pro' );
				$subject 		= esc_html( 'Pickup Order from ' . $location->store_name, 'advanced-local-pickup-pro' );
				
				// create a new email
				$email = new WC_Email();
				$message = apply_filters( 'woocommerce_mail_content', $email->style_inline( $mailer->wrap_message( $email_heading, $message ) ) );
				$headers = "Content-Type: text/html\r\n";
				add_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
				add_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );
		
				$recipients = !empty($location->store_recipients) ? $location->store_recipients : '';
				$recipients = explode(',', $recipients);
				
				$logger = wc_get_logger();
				if ($recipients) {
					foreach ($recipients as $recipient) {
						$bool = wp_mail( $recipient, $subject, $message, $email->get_headers() );
					}
				}
				$order->update_meta_data( 'alp_trigger_email_notification', true );
				$order->save();
				
			}
		}
	}
	
	/**
	 * Send pickup reminder mail.
	 * This method will create a object and call trigger method.
	 *
	 * @since  1.0.0
	*/
	public function send_pickup_reminder_email_func( $order_id, $location_id = null, $product_ids = null ) {
		
		$order = wc_get_order($order_id);

		$wc_emails      = WC_Emails::instance();
		$emails         = $wc_emails->get_emails();	
		$mailer 		= WC()->mailer();
		$sent_to_admin 	= false;
		$plain_text 	= false;
		$email = new WC_Email();
		$message 		= $this->reminder_email_content( $order, $location_id, $product_ids, $sent_to_admin, $plain_text, $email );

		$alp = alp_pro_addon()->admin;
		
		$appt_data = $order ? $order->get_meta( 'alp_appt_data', true ) : '';
		if ( isset($appt_data) && empty($appt_data) ) {
			$email_heading	= $alp->get_option_value_from_array('woocommerce_customer_pickup_reminder_order_settings', 'non_appointment_heading', esc_html__( 'Non-appointment Pickup Reminder', 'advanced-local-pickup-pro' ));
			$subject 		= $alp->get_option_value_from_array('woocommerce_customer_pickup_reminder_order_settings', 'non_appointment_subject', esc_html__( 'Non-appointment Pickup Remi nder for your order from  {site_title}', 'advanced-local-pickup-pro' ));
		} else {
			$email_heading	= $alp->get_option_value_from_array('woocommerce_customer_pickup_reminder_order_settings', 'heading', esc_html__( 'Pickup Reminder', 'advanced-local-pickup-pro' ));
			$subject 		= $alp->get_option_value_from_array('woocommerce_customer_pickup_reminder_order_settings', 'subject', esc_html__( 'Pickup Reminder for your order from  {site_title}', 'advanced-local-pickup-pro' ));
		}

		$email_heading = str_replace(array('{site_title}', '{order_number}' ), array( get_bloginfo( 'name' ), $order->get_order_number()), $email_heading);
		$subject = str_replace(array('{site_title}', '{order_number}' ), array( get_bloginfo( 'name' ), $order->get_order_number()), $subject);
		
		// create a new email
		$email = new WC_Email();
		$message = apply_filters( 'woocommerce_mail_content', $email->style_inline( $mailer->wrap_message( $email_heading, $message ) ) );
		$headers = "Content-Type: text/html\r\n";
		add_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
		add_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );

		$recipient = $order->get_billing_email();
		$logger = wc_get_logger();
		if ($recipient) {
			$bool = wp_mail( $recipient, $subject, $message, $email->get_headers() );
		}
		
		if ( empty($appt_data) ) {
			$this->set_second_pickup_reminder_cron_func( current_action(), $order_id );
		}

		wp_clear_scheduled_hook( current_action(), array( $order_id, $location_id, $product_ids ) );
		wp_clear_scheduled_hook( current_action(), array( $order_id ) );

	}

	public function set_second_pickup_reminder_cron_func( $current_action, $order_id ) {

		$order = wc_get_order($order_id);
		$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';

		if (empty($location_ids)) {
			return;
		}
		
		$ids = array();
		foreach ( $location_ids as $product_id => $location_id) { 
			$ids[$location_id][] = $product_id;
		}
		
		
		foreach ( $ids as $location_id => $product_ids ) {
			
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			if ( isset( $location->store_enable_pickup_reminder ) && '1' == $location->store_enable_pickup_reminder ) {
				$days = isset( $location->store_2nd_nonAppt_pickup_days ) ? $location->store_2nd_nonAppt_pickup_days : 0;
				if ( isset( $location->store_enable_appt ) && '1' != $location->store_enable_appt && $days > 0 ) {
					$second_cron = new DateTime( gmdate('d-m-Y'), new DateTimeZone( wc_timezone_string() ) ); 
					$second_cron->modify( '+' . $days . ' days' );
					if ( isset($second_cron) && !empty($second_cron) && 'alp_nonAppt_pickup_reminder_cron' == $current_action ) {
						wp_schedule_event( $second_cron->getTimestamp(), 'daily', 'alp_nonAppt_pickup_reminder_2nd_cron', array( $order_id ) );
					}
				}
			
			}
		}

	}
	
	/*
	* Get email content data for store owner
	*/
	public function reminder_email_content( $order, $location_id, $product_ids, $sent_to_admin, $plain_text, $email ) {
		
		ob_start();
		$local_template = get_stylesheet_directory() . '/woocommerce/emails/pickup-reminder.php';
		if ( file_exists( $local_template ) && is_writable( $local_template )) {
			wc_get_template(
				'pickup-reminder.php',
				array(
					'order' => $order,
					'locationID' => $location_id,
					'product_ids' => $product_ids,
					'sent_to_admin' => $sent_to_admin,
					'plain_text' => $plain_text,
					'email' => $email,
				),
				'advanced-local-pickup-pro/',
				get_stylesheet_directory() . '/woocommerce/emails/' 
			);
		} else {
			wc_get_template(
				'emails/pickup-reminder.php',
				array(
					'order' => $order,
					'locationID' => $location_id,
					'product_ids' => $product_ids,
					'sent_to_admin' => $sent_to_admin,
					'plain_text' => $plain_text,
					'email' => $email,
				),
				'advanced-local-pickup-pro/',
				alp_pro_addon()->get_plugin_path() . '/templates/'
			);
		}

		$message = ob_get_clean();
		return $message;
		
	}
	
	/*
	* get email content data for store owner
	*/
	public function email_content( $order_id, $product_ids, $appt_data, $location ) {
		
		ob_start();

		$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-notification.php';
		if ( file_exists( $local_template ) && is_writable( $local_template )) {
			wc_get_template(
				'pickup-notification.php',
				array(
					'order_id' => $order_id,
					'product_ids' => $product_ids,
					'appt_data' => $appt_data,
					'location' => $location,
				),
				'advanced-local-pickup-pro/', 
				get_stylesheet_directory() . '/woocommerce/emails/' 
			);	
		} else {
			wc_get_template(
				'pickup-notification.php',
				array(
					'order_id' => $order_id,
					'product_ids' => $product_ids,
					'appt_data' => $appt_data,
					'location' => $location,
				),
				'advanced-local-pickup-pro/', 
				alp_pro_addon()->get_plugin_path() . '/templates/emails/'
			);
		}
		
		$message = ob_get_clean();
		return $message;
		
	}
	
	/**
	 * Get the from name for outgoing emails.
	 *
	 * @return string
	 */
	public function get_from_name() {
		$from_name = apply_filters( 'woocommerce_email_from_name', get_option( 'woocommerce_email_from_name' ), $this );
		return wp_specialchars_decode( esc_html( $from_name ), ENT_QUOTES );
	}

	/**
	 * Get the from address for outgoing emails.
	 *
	 * @return string
	 */
	public function get_from_address() {
		$from_address = apply_filters( 'woocommerce_email_from_address', get_option( 'woocommerce_email_from_address' ), $this );
		return sanitize_email( $from_address );
	}
	
	/**
	 * Send non-appointment reminder email.
	 * This method will create a object and call trigger method.
	 *
	 * @since  1.0.0
	*/
	public function action_woocommerce_order_status_changed( $order_id, $status_from, $status_to, $order ) {
		
		if ( 'pickup' == $status_to ) {
			//wp_clear_scheduled_hook( 'alp_pickup_reminder_cron', array( $order_id ) );
			wp_clear_scheduled_hook( 'alp_nonAppt_pickup_reminder_cron', array( $order_id ) );
			wp_clear_scheduled_hook( 'alp_nonAppt_pickup_reminder_2nd_cron', array( $order_id ) );
			return;
		}
		
		if ( 'ready-pickup' != $status_to ) {
			return;
		}
		
		// Iterating through order shipping items
		foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {			
			$shipping_method = $shipping_item_obj->get_method_id();						
		}
		
		//IF  dshipping method is not local pickup then @return;
		if ( !isset($shipping_method ) ) {
			return;
		}
		if ( isset($shipping_method ) && 'local_pickup' != $shipping_method ) {
			return;	
		}
		
		$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';
		$appt_data = $order ? $order->get_meta( 'alp_appt_data', true ) : '';

		if (empty($location_ids) || !empty($appt_data)) {
			return;
		}
		
		$ids = array();
		foreach ( $location_ids as $product_id => $location_id) { 
			$ids[$location_id][] = $product_id;
		}
		
		foreach ( $ids as $location_id => $product_ids ) {
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			if ( isset( $location->store_enable_pickup_reminder ) && '1' == $location->store_enable_pickup_reminder ) {
				$days = isset( $location->store_nonAppt_pickup_days ) ? $location->store_nonAppt_pickup_days : 0;
				if ( isset( $location->store_enable_appt ) && '1' != $location->store_enable_appt && $days > 0 ) {
					$first_cron = new DateTime( gmdate('d-m-Y'), new DateTimeZone( wc_timezone_string() ) ); 
					$first_cron->modify( '+' . $days . ' days' );
					wp_schedule_event( $first_cron->getTimestamp(), 'daily', 'alp_nonAppt_pickup_reminder_cron', array( $order_id ) );
				}
			}
		}
		
	}
	
	/*
	* get pickup info in package slips
	*/
	public function add_pick_info_packing_slip( $type, $order ) {		
		
		if ( 'packing-slip' == $type ) {
			$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-instruction.php';
				
			if ( file_exists( $local_template ) && is_writable( $local_template )) {	
				wc_get_template( 'emails/pickup-instruction.php', array( 'order_id' => $order->get_id(), 'email_id' => $type ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
			} else {
				wc_get_template( 'emails/pickup-instruction.php', array( 'order_id' => $order->get_id(), 'email_id' => $type ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
			}		
		}
		
	}
	

}
