<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class ALP_Fulfillment_Dashboard {
	
	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	 */
	private static $instance;
	
	/**
	 * Initialize the main plugin function
	*/
	public function __construct() {
		
		global $wpdb;		
		$this->init();	
	}
	
	/**
	 * Get the class instance
	 *
	 * @return ALP_Fulfillment_Dashboard
	*/
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
	
	/*
	* init from parent mail class
	*/
	public function init() {
		//load shipments css js 
		add_action( 'admin_enqueue_scripts', array( $this, 'fulfillment_dashboard_styles' ), 1);
		
		add_action( 'wp_ajax_get_local_pickup_orders', array($this, 'get_local_pickup_orders') );
		add_action( 'wp_ajax_reload_fullfillment_widgets', array($this, 'reload_fullfillment_widgets') );

		add_action( 'wp_ajax_handle_local_pickup_action', array( $this, 'handle_local_pickup_action' ) );
		add_action( 'wp_ajax_handle_fulfillment_bulk_action', array( $this, 'handle_fulfillment_bulk_action' ) );

	}
	
		
	/**
	* Load trackship styles.
	*/
	public function fulfillment_dashboard_styles( $hook ) {
		
		if ( !isset( $_GET['page'] ) ) {
			return;
		}

		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';		
		wp_register_script( 'wc-backbone-modal', WC()->plugin_url() . '/assets/js/admin/backbone-modal' . $suffix . '.js', array( 'underscore', 'backbone', 'wp-util' ), alp_pro_addon()->version );
		
		wp_register_style( 'woocommerce_admin_styles', WC()->plugin_url() . '/assets/css/admin.css', array(), WC_VERSION );
		wp_enqueue_style( 'woocommerce_admin_styles' );

		wp_register_script( 'alp_fulfillment_script', alp_pro_addon()->plugin_dir_url() . 'assets/js/fulfillment.js', array( 'jquery' ), alp_pro_addon()->version, true );

		if ( 'alp-fulfillment-dashboard' == $_GET['page'] || 'fulfillment-dashboard' == $_GET['page']) {
			wp_enqueue_script( 'wc-backbone-modal' );
			wp_enqueue_script( 'alp_fulfillment_script' );	
			wp_localize_script('alp_fulfillment_script', 'alp_fulfillment_script', array(
				'admin_url'   =>  admin_url(),
				'preview_nonce' => wp_create_nonce( 'woocommerce-preview-order' ),
			));
			add_action( 'admin_footer', array( $this, 'footer_function'), 1 );
			add_action( 'admin_footer', array( $this, 'order_preview_template' ) );
		}

		if ( 'alp-fulfillment-dashboard' == $_GET['page'] || ( 'fulfillment-dashboard' == $_GET['page'] && !class_exists('Ast_Pro') ) ) {
			//dataTables library
			wp_enqueue_script( 'DataTable', alp_pro_addon()->plugin_dir_url() . 'assets/js/jquery.dataTables.min.js', array ( 'jquery' ), '1.13.14', true);
			wp_enqueue_style( 'DataTable', alp_pro_addon()->plugin_dir_url() . 'assets/css/jquery.dataTables.min.css', array(), '1.13.14', 'all');	
			wp_enqueue_style( 'alp_fulfillment_styles', alp_pro_addon()->plugin_dir_url() . 'assets/css/fulfillment.css', array(), alp_pro_addon()->version );
		}

		if ( 'fulfillment-dashboard' == $_GET['page'] && class_exists('Ast_Pro') ) {
			wp_enqueue_style( 'ast_fulfillment_styles', alp_pro_addon()->plugin_dir_url() . 'assets/css/ast-fulfillment.css', array(), alp_pro_addon()->version );
		}

	}
	
	/*
	* Change style of available for pickup and picked up order label
	*/	
	public function footer_function() {
		$rfp_bg_color = get_option('wclp_ready_pickup_status_label_color', '#255abc');
		$pu_bg_color = get_option('wclp_pickup_status_label_color', '#dd9933');
		?>
		<style>
		a.ready_for_pickup_icon.button::after {
			color: <?php echo !empty($rfp_bg_color) ? esc_html($rfp_bg_color) : '#255abc'; ?>;
		}						
		a.picked_up_icon.button::after {
			color: <?php echo !empty($pu_bg_color) ? esc_html($pu_bg_color) : '#dd9933'; ?>;
		}	
		</style>
		<?php
	}
	
	public function alp_fulfillment_dashboard_page_callback() {		
		?>
		<div class="zorem-layout">			
			<div class="zorem-layout__header">
				<h1 class="page_heading">
					<a href="javascript:void(0)"><?php esc_html_e( 'Fulfillment', 'advanced-local-pickup-pro'); ?></a> <span class="dashicons dashicons-arrow-right-alt2"></span> <span class="breadcums_page_heading"><?php esc_html_e( 'Store Pickup', 'advanced-local-pickup-pro'); ?></span>
				</h1>
				<img class="zorem-layout__header-logo" src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__) . 'assets/images/alp-icon.png'); ?>">
			</div>
			<div class="zorem-layout__sub-header">
				<input class="tab_input" id="alp_orders" name="tabs" type="radio" data-tab="alp-orders" data-label="Local Pickup Orders" checked="">
				<label class="tab_label first_label" for="alp_orders">Local Pickup Orders</label>
				<div class="woocommerce-layout__activity-panel">
					<div class="woocommerce-layout__activity-panel-tabs">
						<button type="button" id="activity-panel-tab-help" class="components-button woocommerce-layout__activity-panel-tab">
							<span class="dashicons dashicons-menu-alt"></span>
						</button>
					</div>
					<div class="woocommerce-layout__activity-panel-wrapper">
						<div class="woocommerce-layout__activity-panel-content" id="activity-panel-true">
							<div class="woocommerce-layout__activity-panel-header">
								<div class="woocommerce-layout__inbox-title">
									<p class="css-activity-panel-Text">Documentation</p>            
								</div>								
							</div>
							<div>
								<ul class="woocommerce-list woocommerce-quick-links__list">
									<li class="woocommerce-list__item has-action">
										<?php
										$support_link = class_exists( 'Advanced_local_pickup_PRO' ) ? 'https://www.zorem.com/?support=1' : 'https://wordpress.org/support/plugin/advanced-local-pickup-for-woocommerce/#new-topic-0' ;
										?>
										<a href="<?php echo esc_url( $support_link ); ?>" class="woocommerce-list__item-inner" target="_blank" >
											<div class="woocommerce-list__item-before">
												<img src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__) . 'assets/images/get-support-icon.svg'); ?>" >
											</div>
											<div class="woocommerce-list__item-text">
												<span class="woocommerce-list__item-title">
													<div class="woocommerce-list-Text">Get Support</div>
												</span>
											</div>
											<div class="woocommerce-list__item-after">
												<span class="dashicons dashicons-arrow-right-alt2"></span>
											</div>
										</a>
									</li>            
									<li class="woocommerce-list__item has-action">
										<a href="https://www.zorem.com/docs/advanced-local-pickup-for-woocommerce/?utm_source=wp-admin&utm_medium=ALPDOCS&utm_campaign=add-ons" class="woocommerce-list__item-inner" target="_blank">
											<div class="woocommerce-list__item-before">
												<img src="<?php echo esc_url(alp_pro_addon()->plugin_dir_url(__FILE__) . 'assets/images/documentation-icon.svg'); ?>" >
											</div>
											<div class="woocommerce-list__item-text">
												<span class="woocommerce-list__item-title">
													<div class="woocommerce-list-Text">Documentation</div>
												</span>
											</div>
											<div class="woocommerce-list__item-after">
												<span class="dashicons dashicons-arrow-right-alt2"></span>
											</div>
										</a>
									</li>
									<?php if ( !class_exists( 'Advanced_local_pickup_PRO' ) ) { ?>
										<li class="woocommerce-list__item has-action">
											<a href="https://www.zorem.com/product/advanced-local-pickup-for-woocommerce/?utm_source=wp-admin&utm_medium=ALP&utm_campaign=add-ons" class="woocommerce-list__item-inner" target="_blank">
												<div class="woocommerce-list__item-before">
													<span class="dashicons dashicons-media-document"></span>
												</div>
												<div class="woocommerce-list__item-text">
													<span class="woocommerce-list__item-title">
														<div class="woocommerce-list-Text">Upgrade To Pro</div>
													</span>
												</div>
												<div class="woocommerce-list__item-after">
													<span class="dashicons dashicons-arrow-right-alt2"></span>
												</div>
											</a>
										</li>
									<?php } ?>
								</ul>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="woocommerce zorem_admin_layout alp_fulfillment_dashboard">
				<div class="alp_menu_container">					
					<?php require_once( 'views/fulfillment_dashboard.php' ); ?>		
				</div>						
			</div>						
		</div>		
		<?php
	}
	
	public function get_local_pickup_orders() {
		
		check_ajax_referer( 'alp_nonce_fullfillment_dashbaord', 'ajax_nonce' );						
		
		$fulfillment_filter = isset( $_POST['alp_fulfillment_filter'] ) ? wc_clean( $_POST['alp_fulfillment_filter'] ) : '';
		$fulfillment_filter_by_location = !empty( $_POST['alp_fulfillment_filter_by_location'] ) ? '"' . wc_clean( $_POST['alp_fulfillment_filter_by_location'] ) . '"' : null;	
		$fulfillment_filter_by_appointment = !empty( $_POST['alp_fulfillment_filter_by_appointment'] ) ? wc_clean( $_POST['alp_fulfillment_filter_by_appointment'] ) : null;			
		if ( !empty($fulfillment_filter) ) {
			$order_status = array($fulfillment_filter);
		} else {
			$defualt_status = array( 'wc-processing', 'wc-ready-pickup', 'wc-pickup' );
			$order_status = get_option('alp_order_display_in_fulfillment_dashboard', $defualt_status);
			$order_status = !empty($order_status) ? $order_status : $defualt_status;
		}
		
		$order_status_string = '';
		$i = 0;
		foreach ( $order_status as $status ) {
			if ( 0 == $i ) {
				$order_status_string .= "'" . $status . "'";	
			} else {
				$order_status_string .= ",'" . $status . "'";	
			}	 		
			 $i++;
		}	

		$row = ( isset( $_POST['start'] ) ) ? wc_clean( $_POST['start'] ) : '' ;
		$rowperpage = ( isset( $_POST['length'] ) ) ? wc_clean( $_POST['length'] ) : '' ;
		$search_input = ( isset( $_POST['alp_fulfillment_search_input'] ) ) ? wc_clean( $_POST['alp_fulfillment_search_input'] ) : null ;

		global $wpdb;
		$limit = 'LIMIT ' . $row . ',' . $rowperpage . '';

		$wc_order_table = $this->check_hpos_enabled();

		if ( !$wc_order_table ) {
			if ( null != $search_input ) {
				$order_query = "AND ( posts.ID LIKE '%" . $search_input . "%' OR postmeta.meta_value LIKE '%" . $search_input . "%' )";
			} else {
				$order_query = '';
			}
			
			if ( null != $fulfillment_filter_by_location ) {
				$meta_value = "( postmeta.meta_key LIKE ( 'alp_location_ids') AND postmeta.meta_value LIKE ( '%$fulfillment_filter_by_location%' ) )";
			} else {
				$meta_value = '';
			}	
			
			if ( null != $fulfillment_filter_by_location ) {
				$oprator = 'OR';
			} else {
				$oprator = '';
			}


			if ( null != $fulfillment_filter_by_appointment ) {
				$appt_meta_value = "$oprator ( postmeta.meta_key LIKE ( 'alp_appt_data') AND postmeta.meta_value LIKE  ( '%$fulfillment_filter_by_appointment%' ) )";
				
			} else {
				$appt_meta_value = '';
			}

			if ( null != $fulfillment_filter_by_appointment || null != $fulfillment_filter_by_location ) {
				$alp_data_query = "AND ( $meta_value $appt_meta_value )";
			} else {
				$alp_data_query = '';
			}
	
			$query = $wpdb->prepare( "
				SELECT 
					posts.post_status as ordr_status,
					posts.ID AS order_id
				FROM {$wpdb->posts} AS posts
				LEFT JOIN {$wpdb->postmeta} AS postmeta ON(posts.ID = postmeta.post_id)
				WHERE 				
					posts.post_type LIKE 'shop_order'
					AND posts.post_status IN (" . $order_status_string . ")
					$order_query
					AND posts.ID IN ( 
						SELECT
							order_id
						FROM
							" . $wpdb->prefix . "woocommerce_order_items T1
						LEFT JOIN " . $wpdb->prefix . "woocommerce_order_itemmeta T2 ON
							T1.order_item_id = T2.order_item_id
						WHERE
							meta_key = 'method_id' AND meta_value = 'local_pickup')	
					$alp_data_query
					GROUP BY order_id
					ORDER BY order_id DESC					
				" );
		} else {
			
			if ( null != $search_input ) {
				$order_query = "AND ( wc_orders.ID LIKE '%" . $search_input . "%' OR wc_orders_meta.meta_value LIKE '%" . $search_input . "%' )";
			} else {
				$order_query = '';
			}
			
			if ( null != $fulfillment_filter_by_location ) {
				$meta_value = "( wc_orders_meta.meta_key LIKE ( 'alp_location_ids') AND wc_orders_meta.meta_value LIKE ( '%$fulfillment_filter_by_location%' ) )";
			} else {
				$meta_value = '';
			}	
			
			if ( null != $fulfillment_filter_by_location ) {
				$oprator = 'OR';
			} else {
				$oprator = '';
			}

			if ( null != $fulfillment_filter_by_appointment ) {
				$appt_meta_value = "$oprator ( wc_orders_meta.meta_key LIKE ( 'alp_appt_data') AND wc_orders_meta.meta_value LIKE  ( '%$fulfillment_filter_by_appointment%' ) )";
				
			} else {
				$appt_meta_value = '';
			}

			if ( null != $fulfillment_filter_by_appointment || null != $fulfillment_filter_by_location ) {
				$alp_data_query = "AND ( $meta_value $appt_meta_value )";
			} else {
				$alp_data_query = '';
			}


			$query = $wpdb->prepare( "
				SELECT 
					wc_orders.status as ordr_status,
					wc_orders.id AS order_id
				FROM " . $wpdb->prefix . "wc_orders AS wc_orders
				LEFT JOIN " . $wpdb->prefix . "wc_orders_meta AS wc_orders_meta ON(wc_orders.id = wc_orders_meta.order_id)
				WHERE 				
					wc_orders.type LIKE 'shop_order'
					AND wc_orders.status IN (" . $order_status_string . ")
					$order_query
					AND wc_orders.id IN ( 
						SELECT
							order_id
						FROM
							" . $wpdb->prefix . "woocommerce_order_items T1
						LEFT JOIN " . $wpdb->prefix . "woocommerce_order_itemmeta T2 ON
							T1.order_item_id = T2.order_item_id
						WHERE
							meta_key = 'method_id' AND meta_value = 'local_pickup')	
					$alp_data_query
					
					GROUP BY order_id
					ORDER BY order_id DESC					
				" );	
		}

		$total_orders = $wpdb->get_results( $query );
		if ( '-1' == $rowperpage ) {
			$limit = 'LIMIT ' . $row . ',' . intval( count($total_orders) );
		}

		$paginated_query = $query . $limit;			
			
		$orders = $wpdb->get_results( $paginated_query );				
		
		$i = 0;
		$result = array();
		foreach ( $orders as $order_data ) {
			
			$result[$i] = new \stdClass();
			$order = wc_get_order( $order_data->order_id);
			
			if ( is_a( $order, 'WC_Order_Refund' ) ) {
				continue;
			}
			
			$datetime = $order->get_date_created();
			$pickup_data = alp_pro_addon()->admin->get_pickup_data($order_data->order_id);

			
			$pickup_appt_details = array();
			foreach ( $pickup_data as $val) {
				if ( isset($val['pickup_appt_data']) && !empty($val['date']) && !empty($val['time'])) {
					$date = isset($val['date']) && !empty($val['date']) ? date_create($val['date']) : '';
					$time = isset($val['time']) && !empty($val['time']) ? ' at ' . gmdate('h:ia', strtotime(explode('-', $val['time'])[0])) : '';
					$pickup_appt_details[] = date_format($date, 'M j') . $time;
				}
			}

			$pickup_location_name = array_column( (array) $pickup_data, 'pickup_location_name');
			$actions = $this->action_data( $order );

			if ( !empty( $datetime ) ) {
				$result[$i]->order_date = $datetime->format('M j') != gmdate('M j') ? $datetime->format('M j') . ' at ' . $datetime->format('H:ia') : 'Today at ' . $datetime->format('H:ia');
			} else {
				$result[$i]->order_date = '';
			}
			$result[$i]->checkbox = '<input id="checkbox-select-' . $order->get_id() . '" class="checkbox" type="checkbox" name="orders[]" value="' . $order->get_id() . '">';
			$result[$i]->order_id = $order->get_id();
			$result[$i]->order_number = $order->get_order_number();
			$result[$i]->locations = implode( ',<br>', $pickup_location_name );
			$result[$i]->appointment_data = !empty($pickup_appt_details) ? implode( ',<br>', $pickup_appt_details ) : '--';
			$result[$i]->order_status = sprintf( '<mark class="order-status %s"><span>%s</span></mark>', esc_attr( sanitize_html_class( 'status-' . $order->get_status() ) ), esc_html( wc_get_order_status_name( $order->get_status() ) ) );
			$result[$i]->order_view = '<a href="#" class="button wc-action-button alp-fulfillment-order-preview" data-order-id="' . $order->get_id() . '" title="Preview">Preview</a>';
			$result[$i]->customer = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
			$result[$i]->item_count = $order->get_item_count();//$order->get_shipping_method();				
			$result[$i]->actions_html = $this->ast_render_action_buttons( $actions );
		
			$i++;
		}
		
		$draw = ( isset( $_POST['draw'] ) ) ? wc_clean( $_POST['draw'] ) : '' ;
		
		$obj_result = new \stdclass();
		$obj_result->draw = intval( $draw );
		$obj_result->recordsTotal = intval( count($total_orders) );
		$obj_result->recordsFiltered = intval( count($total_orders) );
		$obj_result->data = $result;
		$obj_result->filter = 100;
		$obj_result->last_sql = $paginated_query;
		$obj_result->is_success = true;
		echo json_encode($obj_result);
		exit;
	}
	
	
	public function action_data( $order ) {
		
		$actions = array();
		
		if ( $order->has_status( array( 'processing' ) ) ) {
			$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
			$actions['ready_for_pickup'] = array(
				'order_id'	=> $order_id,
				'url'       => '',
				'name'      => __( 'Ready for pickup', 'advanced-local-pickup-pro' ),
				'action'    => 'ready_for_pickup_icon',
			);
		}
		
		if ( $order->has_status( array( 'ready-pickup' ) ) ) {
			$order_id = method_exists( $order, 'get_id' ) ? $order->get_id() : $order->id;
			$actions['pickup'] = array(
				'order_id'	=> $order_id,
				'url'       => '',
				'name'      => __( 'Picked up', 'advanced-local-pickup-pro' ),
				'action'    => 'picked_up_icon',
			);
		}
		
		if ( class_exists( 'WPO_WCPDF' ) ) {
			$documents = WPO_WCPDF()->documents->get_documents();
			foreach ($documents as $document) {
				$document_title = $document->get_title();
				$icon = !empty($document->icon) ? $document->icon : WPO_WCPDF()->plugin_url() . '/assets/images/generic_document.png';
				$document = wcpdf_get_document( $document->get_type(), $order );

				if ( $document ) {
					$document_title = is_callable( array( $document, 'get_title' ) ) ? $document->get_title() : $document_title;
					$document_exists = is_callable( array( $document, 'exists' ) ) ? $document->exists() : false;
					$actions[$document->get_type()] = array(
						'url'    => wp_nonce_url( admin_url( "admin-ajax.php?action=generate_wpo_wcpdf&document_type={$document->get_type()}&order_ids=" . $order->get_id() ), 'generate_wpo_wcpdf' ),
						'img'    => $icon,
						'name'    => 'PDF ' . $document_title,
						'exists' => $document_exists,
						'action' => $document->get_type(),	
						'class'  => apply_filters( 'wpo_wcpdf_action_button_class', $document_exists ? 'exists ' . $document->get_type() : $document->get_type(), $document ),
					);
				}
			}

		}
		
		
		return $actions;
	}

	
	public function handle_local_pickup_action() {
		
		check_ajax_referer( 'alp_nonce_fullfillment_dashbaord', 'ajax_nonce' );

		$order_id = isset($_POST['order_id']) ? sanitize_text_field($_POST['order_id']) : '';
		$status = isset($_POST['status']) ? sanitize_text_field($_POST['status']) : '';
		$order = new WC_Order($order_id);
		$order->update_status($status);

		// Return updated data
		$response = array(
			'status'    => 'success',
		);
		
		echo json_encode($response);
		wp_die();
	}

	public function handle_fulfillment_bulk_action() {
		
		check_ajax_referer( 'alp_nonce_fullfillment_dashbaord', 'ajax_nonce' );

		$orders = isset($_POST['orders']) ? wc_clean($_POST['orders']) : '';
		$status = isset($_POST['status']) ? sanitize_text_field($_POST['status']) : '';

		if ( $status ) {
			foreach ($orders as $order_id) {
				$order = new WC_Order($order_id);
				$order->update_status($status);
			}

			//update status
			$response = array(
				'status'    => 'success',
			);
			echo json_encode($response);
		}
		
		wp_die();
	}
	
	public function ast_render_action_buttons( $actions ) {
		
		$actions_html = '';
		
		foreach ( $actions as $key => $action ) {
			if ( isset( $action[ 'img'] ) ) {
				$actions_html .= sprintf( '<a class="button wc-action-img-button wc-action-button-%1$s %1$s" href="%2$s" aria-label="%3$s" title="%3$s" data-order_id="%5$s" target="blank">%4$s</a>', esc_attr( $action['action'] ), esc_url( $action['url'] ), esc_attr( isset( $action['title'] ) ? $action['title'] : $action['name'] ), '<img src="' . $action['img'] . '" width="20">', esc_attr( $action['order_id'] ) );
			} else {
				$actions_html .= sprintf( '<a class="button wc-action-button wc-action-button-%1$s %1$s" href="%2$s" aria-label="%3$s" title="%3$s" data-order_id="%5$s">%4$s</a>', esc_attr( $action['action'] ), esc_url( $action['url'] ), esc_attr( isset( $action['title'] ) ? $action['title'] : $action['name'] ), esc_html( $action['name'] ), esc_attr( $action['order_id'] ) );
			}
		}
		
		return $actions_html;
	}
	
	public function get_local_pickup_orders_count( $date ) {
		
		$default_order_status = array();
		$default_order_status = array( 'wc-processing', 'wc-ready-pickup', 'wc-pickup' );
		$order_status = $default_order_status;	
		
		if ( null != $date ) {
			$fullfillment_date = explode( ' - ', wc_clean( $date ) );
			$initial_date = date_format( date_create( $fullfillment_date[0] ), 'Y-m-d' );
			$final_date = date_format( date_create( $fullfillment_date[1] ), 'Y-m-d' );
			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => $initial_date . '...' . $final_date,
				'return' => 'ids',	
			);
		} else {			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => '>' . ( time() - 2592000 ),
				'return' => 'ids',				
			);			
		}				
		$orders = wc_get_orders( $args );		
		$local_pickup_orders = count( $orders );
		return $local_pickup_orders;
	}
	
	public function get_ready_for_pickup_orders_count( $date ) {
		
		$default_order_status = array();
		$default_order_status = array( 'wc-ready-pickup' );
		$order_status = $default_order_status;	
		
		if ( null != $date ) {
			$fullfillment_date = explode( ' - ', wc_clean( $date ) );
			$initial_date = date_format( date_create( $fullfillment_date[0] ), 'Y-m-d' );
			$final_date = date_format( date_create( $fullfillment_date[1] ), 'Y-m-d' );
			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => $initial_date . '...' . $final_date,
				'return' => 'ids',	
			);
		} else {			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => '>' . ( time() - 2592000 ),
				'return' => 'ids',				
			);			
		}				
		$orders = wc_get_orders( $args );		
		$ready_for_pickup_orders = count( $orders );
		return $ready_for_pickup_orders;
	}
	
	public function get_picked_up_orders_count( $date ) {
		
		$default_order_status = array();
		$default_order_status = array( 'wc-pickup' );
		$order_status = $default_order_status;	
		
		if ( null != $date ) {
			$fullfillment_date = explode( ' - ', wc_clean( $date ) );
			$initial_date = date_format( date_create( $fullfillment_date[0] ), 'Y-m-d' );
			$final_date = date_format( date_create( $fullfillment_date[1] ), 'Y-m-d' );
			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => $initial_date . '...' . $final_date,
				'return' => 'ids',	
			);
		} else {			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => '>' . ( time() - 2592000 ),
				'return' => 'ids',				
			);			
		}				
		$orders = wc_get_orders( $args );		
		$picked_up_orders = count( $orders );
		return $picked_up_orders;
	}
	
	public function get_total_orders_count( $date ) {
		
		$order_status = wc_get_order_statuses();

		if ( null != $date ) {
			$fullfillment_date = explode( ' - ', wc_clean( $date ) );
			$initial_date = date_format( date_create( $fullfillment_date[0] ), 'Y-m-d' );
			$final_date = date_format( date_create( $fullfillment_date[1] ), 'Y-m-d' );
			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => $initial_date . '...' . $final_date,
				'return' => 'ids',	
			);
			
		} else {			
			$args = array(
				'status' => $order_status,
				'limit'	 => -1,	
				'date_created' => '>' . ( time() - 2592000 ),
				'return' => 'ids',				
			);			
		}		
		
		$orders = wc_get_orders( $args );
		$total_orders = count( $orders );
		return $total_orders;
	}
	
	public function reload_fullfillment_widgets() {
		check_ajax_referer( 'alp_nonce_fullfillment_dashbaord', 'ajax_nonce' );
		$date = ( isset( $_POST['alp_fullfillment_date'] ) ) ? wc_clean( $_POST['alp_fullfillment_date'] ) : '' ;		
		$local_pickup_orders_count = $this->get_local_pickup_orders_count( $date );
		$picked_up_orders_count = $this->get_picked_up_orders_count( $date );
		$ready_for_pickup_orders_count = $this->get_ready_for_pickup_orders_count( $date );
		$total_orders_count = $this->get_total_orders_count( $date );
		
		echo json_encode( array( 'local_pickup_orders_count' => $local_pickup_orders_count, 'picked_up_orders_count' => $picked_up_orders_count, 'ready_for_pickup_orders_count' => $ready_for_pickup_orders_count, 'total_orders_count' => $total_orders_count ) );
		exit;		
	}
	
	/**
	 * Template for order preview.	 
	 */
	public function order_preview_template() {
		?>
		<script type="text/template" id="tmpl-wc-modal-view-order">
			<div class="wc-backbone-modal wc-order-preview">
				<div class="wc-backbone-modal-content">
					<section class="wc-backbone-modal-main" role="main">
						<header class="wc-backbone-modal-header">
							<mark class="order-status status-{{ data.status }}"><span>{{ data.status_name }}</span></mark>
							<?php /* translators: %s: order ID */ ?>
							<h1><?php echo esc_html( sprintf( __( 'Order #%s', 'woocommerce' ), '{{ data.order_number }}' ) ); ?></h1>
							<button class="modal-close modal-close-link dashicons dashicons-no-alt">
								<span class="screen-reader-text"><?php esc_html_e( 'Close modal panel', 'woocommerce' ); ?></span>
							</button>
						</header>
						<article>
							<?php do_action( 'woocommerce_admin_order_preview_start' ); ?>

							<div class="wc-order-preview-addresses">
								<div class="wc-order-preview-address">
									<h2><?php esc_html_e( 'Billing details', 'woocommerce' ); ?></h2>
									{{{ data.formatted_billing_address }}}

									<# if ( data.data.billing.email ) { #>
										<strong><?php esc_html_e( 'Email', 'woocommerce' ); ?></strong>
										<a href="mailto:{{ data.data.billing.email }}">{{ data.data.billing.email }}</a>
									<# } #>

									<# if ( data.data.billing.phone ) { #>
										<strong><?php esc_html_e( 'Phone', 'woocommerce' ); ?></strong>
										<a href="tel:{{ data.data.billing.phone }}">{{ data.data.billing.phone }}</a>
									<# } #>

									<# if ( data.payment_via ) { #>
										<strong><?php esc_html_e( 'Payment via', 'woocommerce' ); ?></strong>
										{{{ data.payment_via }}}
									<# } #>
								</div>
								<# if ( data.needs_shipping ) { #>
									<div class="wc-order-preview-address">
										<h2><?php esc_html_e( 'Shipping details', 'woocommerce' ); ?></h2>
										<# if ( data.ship_to_billing ) { #>
											{{{ data.formatted_billing_address }}}
										<# } else { #>
											<a href="{{ data.shipping_address_map_url }}" target="_blank">{{{ data.formatted_shipping_address }}}</a>
										<# } #>

										<# if ( data.shipping_via ) { #>
											<strong><?php esc_html_e( 'Shipping method', 'woocommerce' ); ?></strong>
											{{ data.shipping_via }}
										<# } #>
									</div>
								<# } #>

								<# if ( data.data.customer_note ) { #>
									<div class="wc-order-preview-note">
										<strong><?php esc_html_e( 'Note', 'woocommerce' ); ?></strong>
										{{ data.data.customer_note }}
									</div>
								<# } #>
							</div>

							{{{ data.item_html }}}

							<?php do_action( 'woocommerce_admin_order_preview_end' ); ?>
						</article>
						<footer>
							<div class="inner">
								{{{ data.actions_html }}}

								<a class="button button-primary button-large" aria-label="<?php esc_attr_e( 'Edit this order', 'woocommerce' ); ?>" href="<?php echo esc_url( admin_url( 'post.php?action=edit' ) ); ?>&post={{ data.data.id }}"><?php esc_html_e( 'Edit', 'woocommerce' ); ?></a>
							</div>
						</footer>
					</section>
				</div>
			</div>
			<div class="wc-backbone-modal-backdrop modal-close"></div>
		</script>
		<?php
	}

	public function check_hpos_enabled() {
		if ( class_exists( '\Automattic\WooCommerce\Utilities\OrderUtil' ) ) {
			if ( \Automattic\WooCommerce\Utilities\OrderUtil::custom_orders_table_usage_is_enabled() ) {
				return true;
			}
		}
		return false;
	}
	
}	
