<?php
/**
 * Alp pro session 
 *
 * @class   Advanced_Local_Pickup_Per_Item_Session
 * @package WooCommerce/Classes
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Advanced_Local_Pickup_Per_Item_Session class.
 */
class Advanced_Local_Pickup_Per_Item_Session {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return Advanced_Local_Pickup_Per_Item_Session
	*/
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	*/
	private static $instance;
	
	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	*/
	public function __construct() {
		$this->init();	
	}
	
	/*
	 * init function
	 *
	 * @since  1.0
	*/
	public function init() {
		
		
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		if ( isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders']) {
			return;
		}
		
		if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 == $wclp_local_pickup_controls['allow_pickup_per_item']) {					
			// hooks for add pickup control option on cart/checkout
			add_filter( 'woocommerce_get_item_data', array( $this,'add_cart_item_data'), 10, 2 );
			
			add_action('woocommerce_checkout_update_order_meta', array( $this, 'alp_add_pickup_location_ids_in_order_meta' ) );
		
			add_filter('woocommerce_cart_calculate_fees', array($this, 'cart_calculate_totals'));
			
			//hooks for run on removed item on checkout
			add_action( 'woocommerce_remove_cart_item', array( $this, 'run_on_removed_cart_item'), 10, 2 );
						
			add_filter( 'woocommerce_cart_shipping_packages', array( $this, 'handle_packages' ), 1 );

			add_action('woocommerce_after_checkout_validation', array($this, 'after_checkout_validation'), 10, 2);
		}
		
	}
	
	/**
	 * Filter packages to separate packages for pickup from ordinary packages.
	 *
	 * @since 2.0.0
	 *
	 * @param array $packages the packages array
	 * @return array
	 */
	public function handle_packages( $packages ) {		
		
		$newpackages = array();
		$split_product_ids = array();
		$split_package_items = array();
		$regular_package_items = array();
		$locations = alp_pro_addon()->admin->get_data();
		
		$shipping_methods = WC()->shipping->get_shipping_methods();
		$shipping_method_ids = array();
		foreach ($shipping_methods as $shipping_method) {
			$shipping_method_ids[$shipping_method->id] = $shipping_method->id;
		}
		
		foreach ( $packages[0]['contents'] as $item_id => $values ) {
			
			$product_id = $packages[0]['contents'][ $item_id ]['product_id'];
			
			$is_pickup_item = alp_pro_addon()->common->is_not_pickup_item_for_all_location( $product_id );
			if ( !$is_pickup_item ) {
				unset($shipping_method_ids['local_pickup']);
			}
		
			$must_be_pickedup = get_post_meta( $product_id, '_per_product_pickedup', true );
			if ( 1 == count(WC()->cart->get_cart()) && 'yes' == $must_be_pickedup ) {
				foreach ($shipping_method_ids as $method_id) {
					if ( 'local_pickup' != $method_id) {
						unset($shipping_method_ids[$method_id]);
					}
				}
			}
			
		}
		
		foreach ( WC()->cart->get_cart() as $item_key => $item ) {
			$regular_package_items[ $item_key ] = $item;
		}	
		
		// Create shipping packages
		if ( $regular_package_items ) {
			$newpackages[] = array(
				'contents'        => $regular_package_items,
				'contents_cost'   => array_sum( wp_list_pluck( $regular_package_items, 'line_total' ) ),
				'applied_coupons' => WC()->cart->get_applied_coupons(),
				'ship_via'        => $shipping_method_ids,
				'user'            => array(
					 'ID' => get_current_user_id(),
				),
				'destination'    => array(
					'country'    => WC()->customer->get_shipping_country(),
					'state'      => WC()->customer->get_shipping_state(),
					'postcode'   => WC()->customer->get_shipping_postcode(),
					'city'       => WC()->customer->get_shipping_city(),
					'address'    => WC()->customer->get_shipping_address(),
					'address_2'  => WC()->customer->get_shipping_address_2()
				)
			);
		}
		
		return $newpackages;
	}
	
	/**
	 * Update cart item price by cart adjustment on cart/checkout
	 *
	 * @param array $total, $cart_object
	 * @return array of modified total
	 */
	public function cart_calculate_totals( $cart ) {
		
		if ( is_admin() && ! defined( 'DOING_AJAX' ) ) {
			return;
		}

		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		
		if ( isset($get_shipping[0]) && 'local_pickup' != $get_shipping[0]) {
			return;
		}
		
		if ( !WC()->cart->is_empty() ) {
						
			$newprice = 0;

			// change prices
			foreach ( $cart->get_cart() as $hash => $value ) {
				if ( ! $value['data']->needs_shipping() ) {
					continue;	
				}

				$session_data = unserialize(WC()->session->get($hash));
				
				
				if (isset($session_data['pickup_data'][$hash]['enabled']) && 'yes' == $session_data['pickup_data'][$hash]['enabled']) {

					$location_id = isset($session_data['pickup_data'][$hash]['location_id']) ? $session_data['pickup_data'][$hash]['location_id'] : ''; //alp_pro_addon()->common->get_defualt_location_id($value['product_id']);
				}
				
				if (!isset($location_id)) {
					continue;
				}

				$location = alp_pro_addon()->admin->get_data_byid($location_id);

				if (isset($location->store_apply_cart_adjustment_price) && '1' == $location->store_apply_cart_adjustment_price) {
					if ('percentage_discount' == $location->store_price_adjustment && $location->store_price_amount > 0) {
						$newprice -= ( $value['line_subtotal'] * ( $location->store_price_amount / 100 ) );
					}
				}

				if (isset($location->store_price_adjustment) && 'fixed_discount' == $location->store_price_adjustment) {
					$newprice -= ( $location->store_price_amount );
				}
				if (isset($location->store_price_adjustment) && 'percentage_fee' == $location->store_price_adjustment && $location->store_price_amount > 0) {
					$newprice += ( $value['line_subtotal'] * ( $location->store_price_amount / 100 ) );
				}
				if (isset($location->store_price_adjustment) && 'fixed_fee' == $location->store_price_adjustment) {
					$newprice += ( $location->store_price_amount );
				}

			}

			if (0 == $newprice) {
				return;
			}

			if ( $newprice > 0 ) {
				$cart->add_fee( __('Local Pickup Fee', 'advanced-local-pickup-pro'), $newprice, true );
			} else {
				$cart->add_fee( __('Local Pickup Discount', 'advanced-local-pickup-pro'), $newprice, true );
			}

		}
		
	}

	/*
	 * Checkout validation error display
	 *
	 * @since  1.0
	 */
	public function after_checkout_validation( $fields, $errors ) {

		$checkout_nonce = isset($_REQUEST['woocommerce-process-checkout-nonce']) ? sanitize_text_field($_REQUEST['woocommerce-process-checkout-nonce']) : '';
		$_wpnonce = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
		$nonce_value = wc_get_var( $checkout_nonce, wc_get_var( $_wpnonce, '' ) ); // @codingStandardsIgnoreLine.

		if ( !function_exists('run_thwmsc') ) {
			if ( empty( $nonce_value ) || ! wp_verify_nonce( $nonce_value, 'woocommerce-process_checkout' ) ) {
				WC()->session->set( 'refresh_totals', true );
				throw new Exception( __( 'We were unable to process your order, please try again.', 'advanced-local-pickup-pro' ) );
			}
		}

		$pickup_location = isset($_POST['pickup_location']) ? sanitize_text_field($_POST['pickup_location']) : '';
		if ( !empty($pickup_location) ) {
			foreach ( $pickup_location as $session_data ) {
				if ( empty($session_data['location_id']) ) {
					$pickup_location_message = esc_html__('Please select a location for pickup items.', 'advanced-local-pickup-pro');
					$errors->add('validation', $pickup_location_message);
				}
			}
		}
		

	}
	
	
	/**
	* Add to cart item.
	*
	* @param int   $item_data
	* @param int   $cart_item
	*
	* @return array
	*/
	public function add_cart_item_data( $item_data, $cart_item ) {
		
		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		$session_data = unserialize(WC()->session->get( $cart_item['key'] ));
		$product_id = !empty( $cart_item['product_id'] ) ? $cart_item['product_id'] : 0;
		$is_pickup_item = alp_pro_addon()->common->is_not_pickup_item_for_all_location( $product_id );
		
		if ( !$is_pickup_item ) {
			echo '<i style="display:block;font-size:12px;">' . esc_html__( 'This product is not available for local pickup', 'advanced-local-pickup-pro' ) . '</i>';
		}
		
		if ( isset($get_shipping[0]) && 'local_pickup' != $get_shipping[0] ) {
			return $item_data;
		}
		
		if ( isset( $cart_item['key'] ) && ( is_cart() || is_checkout() ) ) {
			$product    = wc_get_product( $product_id );
			$locationsData = alp_pro_addon()->admin->get_data();
			$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
			$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
			$must_be_pickedup = get_post_meta( $product_id, '_per_product_pickedup', true );
			
			if ( count($locations) == 1 ) { 
				$session_data['pickup_data'][$cart_item['key']]['location_id'] = '';//get_option('location_defualt', min($locations)->id);
				WC()->session->set( $cart_item['key'], serialize($session_data) );
			}
			
			$location_id = isset($session_data['pickup_data'][$cart_item['key']]['location_id']) ? $session_data['pickup_data'][$cart_item['key']]['location_id'] : '';//alp_pro_addon()->common->get_defualt_location_id($product_id);
			
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
			
			$country_code = isset($location->store_country) ? $location->store_country : get_option('woocommerce_default_country');
			$split_country = explode( ':', $country_code );
			$store_country = isset($split_country[0]) ? $split_country[0] : '';
			$store_state   = isset($split_country[1]) ? $split_country[1] : '';

			if ( $product && $product->needs_shipping() && $is_pickup_item ) {
				?>
				<div class="alp-cart-option">
					<input type="hidden" name="cart_item_key" value="<?php echo esc_html($cart_item['key']); ?>">
					<input type="hidden" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][enabled]" class="enabled_pickup" value="1" checked/>
					<?php if ( count($locations) != 1 ) { ?>
					<select class="select selected_location" name="pickup_location[<?php echo esc_html($cart_item['key']); ?>][location_id]" style="padding-right: 25px;">
						<option value="" data-address="Please select a location for pickup item"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
						<?php foreach ( (array) $locations as $key => $location2 ) { ?>
						<?php 
							if ( isset($location2->store_enable) && 1 == $location2->store_enable && alp_pro_addon()->common->is_local_pickup_item_by_location( $product_id, $location2 ) ) { 
								//if ( empty($session_data['pickup_data'][$cart_item['key']]['location_id']) ) { 
									//$session_data['pickup_data'][$cart_item['key']]['location_id'] = $location2->id;
									//WC()->session->set( $cart_item['key'], serialize($session_data) );
								//}
								?>
							<option value="<?php echo esc_html($location2->id); ?>" <?php echo ( $location_id == $location2->id ) ? 'selected' : ''; ?>><?php echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location2->store_name)); ?></option>
							<?php } ?>
						<?php } ?>
					</select>
					<?php } ?>
					<?php 
					$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
					if (isset($wclp_local_pickup_controls['display_location_address']) 
						&& 1 == $wclp_local_pickup_controls['display_location_address'] || count($locations) == 1) {
						echo'<small>' . esc_html($address) . '</small>';  
					}

					//appointment options
					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
						$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
						for ($i = 1; $i < 8; $i++) {
							$defualt_date = strtotime('+' . $i . ' day');
							$new_format = gmdate('j-n-Y', $defualt_date);
							$dayofweek = gmdate('l', strtotime($new_format));
							if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
								$new_format = gmdate('d-m-Y', $defualt_date);
								break;
							}
						}

						$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
						$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

						$defualt_date = strtotime('+' . $days . ' day');
						$new_format = gmdate('d-m-Y', $defualt_date);

						if ( get_option('allow_force_date_selection', '0') == '1') {
							$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
						} else {
							$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
						}
						$time = isset($session_data['pickup_data'][$cart_item['key']]['time']) ? $session_data['pickup_data'][$cart_item['key']]['time'] : '';
						?>
						<p class="pickup-appt-fields" style="">
							<input type="text" name ="pickup_data[<?php echo esc_html($cart_item['key']); ?>][date]" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="margin-right: 10px;" readonly>
						<?php

						$disabled = '';
						if ( empty($date) ) {
							$disabled = 'disabled';
						}

						$date = gmdate('j-n-Y', strtotime($date));

						//get full name of day
						$dayofweek = gmdate('l', strtotime($date));

						$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
						$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
						$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

						if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
							$appt_data = $exclusive_appt_data[$date];
						} else {
							$appt_data = $store_appt_days;
						}

						//get full name of day
						$dayofweek = gmdate('l', strtotime($date));
						if (isset($appt_data[strtolower($dayofweek)])) {
							$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
							$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
							$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
							$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
						}

						if (isset($start)) {
							$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
							$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
							$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
							$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
							$slot = 'hour' == $unit ? $Time * 60 : $Time;

							$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
							$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
							$time_slots = array_merge($time_slot1, $time_slot2);

							?>
							
							<select class="select appt_time--items" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][time]" style="" <?php echo esc_html($disabled); ?>> 
								<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
								<?php
								foreach ((array) $time_slots as $key1 => $val1) {
									if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
										if ('12' == $time_format) {
											$last_digit = explode(':', $val1);
											if ('00' == end($last_digit)) {
												$val1 = gmdate('g:ia', strtotime($val1));
												$preVal = gmdate('g:ia', strtotime($preVal));
											} else {
												$val1 = gmdate('g:ia', strtotime($val1));
												$preVal = gmdate('g:ia', strtotime($preVal));
											}
										}
										
										if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { 
											?>
											<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
											<?php
										}
									}
									$preVal = $val1;
								}
								?>
							</select>
							<?php
						} 
						?>
						</p>
					<?php
					}
					?>
				</div>
				<?php
			}
		}
		
		if ( empty( $session_data ) ) {
			return $item_data;
		}
		
		$item_data[] = array(
			'key'     => 'pickup-data',
			'value'   => $session_data,
			'hidden' => true,	
		);

		return $item_data;
	}

	/**
	 * Add selected pickup location id in order meta
	 */
	public function alp_add_pickup_location_ids_in_order_meta( $order_id ) {
		
		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		
		if ( isset($get_shipping[0]) && 'local_pickup' != $get_shipping[0]) {
			return;	
		}
		
		$location_ids = array();
		foreach ( WC()->cart->get_cart() as $cart_item_key => $item ) {
			if ( $item['data']->needs_shipping() ) {
				$session_data = unserialize(WC()->session->get( $cart_item_key ));
				
				$locations = alp_pro_addon()->admin->get_data();
					
				$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
				if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 == $wclp_local_pickup_controls['allow_pickup_per_item']) {
					$location_id = isset($session_data['pickup_data'][$cart_item_key]['location_id']) ? $session_data['pickup_data'][$cart_item_key]['location_id'] : '';//alp_pro_addon()->common->get_defualt_location_id($item['product_id']);
					$date = isset($session_data['pickup_data'][$cart_item_key]['date']) ? $session_data['pickup_data'][$cart_item_key]['date'] : '';
					$time = isset($session_data['pickup_data'][$cart_item_key]['time']) ? $session_data['pickup_data'][$cart_item_key]['time'] : '';
				} 
				if ( !empty($location_id) ) {
					$location_ids[$item['product_id']] = $location_id;
					if ( !empty($date) && !empty($time) ) {
						$appt_data[$order_id][$item['product_id']]['location_id'] = $location_id;
						$appt_data[$order_id][$item['product_id']]['pickup_date'] = $date;//gmdate('d-m-Y', strtotime($date));
						$appt_data[$order_id][$item['product_id']]['pickup_time'] = $time;
					}
				}
			}
			
		}
		$order = wc_get_order($order_id);
		if ( !empty($location_ids) ) {
			$order->update_meta_data( 'alp_location_ids', $location_ids );
			$order->save();
		}

		if (!empty($appt_data)) {
			$order->update_meta_data( 'alp_appt_data', $appt_data );
			$order->save();
		}
	}
	
	/**
	 * Run on removed item on checkout
	 */	
	public function run_on_removed_cart_item( $cart_item_key, $cart ) {

		foreach ( WC()->cart->get_cart() as $item_key => $item ) {
			if ($item_key === $cart_item_key ) {
				if ( isset($item['product_id']) && alp_pro_addon()->common->is_local_pickup_item( $item['product_id'] ) ) {
					WC()->session->__unset( $cart_item_key );
					WC()->session->set( 'chosen_shipping_methods', array('flat_rate') );
				}
			}
		}
		
	}
	
}
