<?php
/**
 * Alp pro session 
 *
 * @class   Advanced_Local_Pickup_Session
 * @package WooCommerce/Classes
 */


if (!defined('ABSPATH')) {
	exit;
}

/**
 * Advanced_Local_Pickup_Session class.
 */
class Advanced_Local_Pickup_Session {

	/**
	 * Get the class instance
	 *
	 * @since  1.0
	 * @return alp_pro_session
	 */
	public static function get_instance() {

		if (null === self::$instance) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Instance of this class.
	 *
	 * @var object Class Instance
	 */
	private static $instance;

	public $adjustment_volume;

	/**
	 * Initialize the main plugin function
	 * 
	 * @since  1.0
	 */
	public function __construct() {
		$this->init();
	}

	/*
	 * init function
	 *
	 * @since  1.0
	 */
	public function init() {

		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		add_action('woocommerce_admin_order_items_after_shipping', array($this, 'alp_display_order_meta_data_in_order_admin'), 10, 1);

		if ( ( isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 != $wclp_local_pickup_controls['allow_mixed_orders'] ) && ( isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 == $wclp_local_pickup_controls['allow_pickup_per_item'] ) ) {
			return;
		}

		if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
			if ( get_option('wclp_cart_checkout_layout', 'inline') == 'popup') {
				add_action('woocommerce_after_shipping_rate', array($this, 'alp_add_pickup_location_dropdown_popup_after_shipping') , 10, 2);
				add_action('woocommerce_after_shipping_rate', array($this, 'alp_checkoutWC_pickup_location_dropdown_popup_after_shipping'), 10, 2);
			} else {
				add_action('woocommerce_cart_totals_after_shipping', array($this, 'alp_add_pickup_location_dropdown_after_shipping'));
				add_action('woocommerce_review_order_after_shipping', array($this, 'alp_add_pickup_location_dropdown_after_shipping'));
				add_action('woocommerce_after_shipping_rate', array($this, 'alp_checkoutWC_pickup_location_dropdown_after_shipping'), 10, 2);
			}
			

			add_action('woocommerce_checkout_update_order_meta', array($this, 'alp_add_location_id_in_ordermeta_to_display_location'));

			add_action('woocommerce_order_status_completed', array($this, 'update_order_status_after_completed'), 10);

			add_filter( 'woocommerce_payment_complete_order_status', array( $this, 'update_order_status_to_processing_lp' ), -1, 2 );

			add_action('woocommerce_after_checkout_validation', array($this, 'after_checkout_validation'), 10, 2);
		}

		if (isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders']) {

			// hooks for shipping packages
			add_filter('woocommerce_package_rates', array($this, 'hide_local_pickup_shipping_when_avaliable_shipping'), 10, 2);
			add_filter('woocommerce_cart_shipping_packages', array($this, 'handle_packages'), 1);
			add_filter('woocommerce_shipping_package_name', array($this, 'alp_rename_shipping_package_name'), 10, 3);

			// hooks for add pickup control option on cart/checkout
			add_filter('woocommerce_get_item_data', array($this, 'add_cart_item_data'), 10, 2);

		} else {
			add_filter('woocommerce_cart_shipping_packages', array($this, 'handle_packages_single_cart_item'), 1);
			add_filter('woocommerce_get_item_data', array($this, 'add_cart_item_data_single_cart_item'), 10, 2);
			add_filter('woocommerce_shipping_package_name', array($this, 'alp_rename_shipping_package_name'), 10, 3);
		}

		add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'alp_add_pickup_location_ids_in_order_meta' ) );

		//hooks for cart adjustment price on cart/checkout
		add_filter('woocommerce_cart_calculate_fees', array($this, 'cart_calculate_totals'));

		//hooks for run on removed item on checkout
		add_action('woocommerce_remove_cart_item', array($this, 'run_on_removed_cart_item'), 10, 2);

		add_action('alp_after_pickup_instruction_details', array($this, 'get_reschadule_options_html'), 10, 4);

	}

	

	/**
	 * Update cart item price by cart adjustment on cart/checkout
	 *
	 * @param array $total, $cart_object
	 * @return array of modified total
	 */
	public function cart_calculate_totals( $cart ) {
		
		if ( is_admin() && ! defined( 'DOING_AJAX' ) ) {
			return;
		}

		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		
		if ( isset($get_shipping[0]) && 'local_pickup' != $get_shipping[0]) {
			return;
		}
		
		if ( !WC()->cart->is_empty() ) {

			$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

			if (isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 == $wclp_local_pickup_controls['allow_pickup_per_item']) {
				$newprice = 0;

				// change prices
				foreach ( $cart->get_cart() as $hash => $value ) {
					if ( ! $value['data']->needs_shipping() ) {
						continue;	
					}

					$session_data = unserialize(WC()->session->get($hash));

					if (isset($session_data['pickup_data'][$hash]['enabled']) && 'yes' == $session_data['pickup_data'][$hash]['enabled']) {

						$location_id = isset($session_data['pickup_data'][$hash]['location_id']) ? $session_data['pickup_data'][$hash]['location_id'] : ''; //alp_pro_addon()->common->get_defualt_location_id($value['product_id']);

					}
					
					if (!isset($location_id)) {
						continue;
					}

					$location = alp_pro_addon()->admin->get_data_byid($location_id);

					if (isset($location->store_apply_cart_adjustment_price) && '1' == $location->store_apply_cart_adjustment_price) {
						if ('percentage_discount' == $location->store_price_adjustment && $location->store_price_amount > 0) {
							$newprice -= ( $value['line_subtotal'] * ( $location->store_price_amount / 100 ) );
						}
					}

					if (isset($location->store_price_adjustment) && 'fixed_discount' == $location->store_price_adjustment) {
						$newprice -= ( $location->store_price_amount );
					}
					if (isset($location->store_price_adjustment) && 'percentage_fee' == $location->store_price_adjustment && $location->store_price_amount > 0) {
						$newprice += ( $value['line_subtotal'] * ( $location->store_price_amount / 100 ) );
					}
					if (isset($location->store_price_adjustment) && 'fixed_fee' == $location->store_price_adjustment) {
						$newprice += ( $location->store_price_amount );
					}

				}

				if (0 == $newprice) {
					return;
				}

				if ( $newprice > 0 ) {
					$cart->add_fee( __('Local Pickup Fee', 'advanced-local-pickup-pro'), $newprice, true );
				} else {
					$cart->add_fee( __('Local Pickup Discount', 'advanced-local-pickup-pro'), $newprice, true );
				}
			} else {
				$session_data = WC()->session->get('pickup_location_id');
				$location_id = !empty($session_data) ? $session_data : '';

				if (!isset($location_id)) {
					return;
				}
	
				$location = alp_pro_addon()->admin->get_data_byid($location_id);
	
				$subtotal = $cart->get_totals();
				$cart_contents_total = $subtotal['cart_contents_total'];
				
				if (isset($location->store_apply_cart_adjustment_price) && '1' == $location->store_apply_cart_adjustment_price) {
					if ('percentage_discount' == $location->store_price_adjustment && $location->store_price_amount > 0) {
						$newprice = $cart_contents_total * ( $location->store_price_amount / 100 );
						$cart->add_fee( __('Local Pickup Discount', 'advanced-local-pickup-pro'), -$newprice, true );
					}
				}
				if (isset($location->store_price_adjustment) && 'fixed_discount' == $location->store_price_adjustment) {
					$newprice = $location->store_price_amount;
					$cart->add_fee( __('Local Pickup Discount', 'advanced-local-pickup-pro'), -$newprice, true );
				}
				if (isset($location->store_price_adjustment) && 'percentage_fee' == $location->store_price_adjustment && $location->store_price_amount > 0) {
					$newprice = $cart_contents_total * ( $location->store_price_amount / 100 );
					$cart->add_fee( __('Local Pickup Fee', 'advanced-local-pickup-pro'), +$newprice, true );
				}
				if (isset($location->store_price_adjustment) && 'fixed_fee' == $location->store_price_adjustment) {
					$newprice = $location->store_price_amount;
					$cart->add_fee( __('Local Pickup Fee', 'advanced-local-pickup-pro'), +$newprice, true );
				}
			}	

		}
		
	}

	/**
	 * Hide shipping rates when free shipping is available
	 *
	 * @param array $rates Array of rates found for the package
	 * @param array $package The package array/object being shipped
	 * @return array of modified rates
	 */
	public function hide_local_pickup_shipping_when_avaliable_shipping( $rates, $package ) {

		foreach ($package['contents'] as $item_id => $values) {
			$product_id = $package['contents'][$item_id]['product_id'];
			$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);

			if ( ( alp_pro_addon()->common->is_local_pickup_item($product_id) || 'yes' == $must_be_pickedup ) ) {
				$location_avalibale = true;
			} else {
				$location_avalibale = false;
			}
		}
		foreach ($rates as $rate_id => $rate_val) {
			if ('local_pickup' === $rate_val->get_method_id() && false === $location_avalibale) {
				unset($rates[$rate_id]);
			}
		}
		return $rates;
	}


	/**
	 * Add to cart item.
	 *
	 * @param int   $item_data
	 * @param int   $cart_item
	 *
	 * @return array
	 */
	public function add_cart_item_data( $item_data, $cart_item ) {

		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		if (!empty(WC()->cart->get_cart()) && count(WC()->cart->get_cart()) < 2 && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
			return $item_data;
		}

		$chosen_methods = WC()->session->get('chosen_shipping_methods');
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : array();
		if ( !in_array('local_pickup', $get_shipping) && !empty(WC()->cart->get_cart()) && count(WC()->cart->get_cart()) < 2 ) {
			return $item_data;
		}

		$session_data = unserialize(WC()->session->get($cart_item['key']));

		if (isset($session_data['pickup_data'][$cart_item['key']]['enabled'])
		&& 'yes' == $session_data['pickup_data'][$cart_item['key']]['enabled']) {

			$checked = 'checked';
			$multiple_locations = true;
		} else {
			$checked = '';
			$multiple_locations = false;
		}

		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		if ( isset($wclp_local_pickup_controls['allow_pickup_per_item'])
		&& 1 == $wclp_local_pickup_controls['allow_pickup_per_item'] ) {
			$allow_pickup_per_item = true;
		} else {
			$allow_pickup_per_item = false;
		}

		if ( isset($cart_item['key']) && ( is_cart() || is_checkout() ) ) {
			$product_id = !empty($cart_item['product_id']) ? $cart_item['product_id'] : 0;
			$product = wc_get_product($product_id);
			$locationsData = alp_pro_addon()->admin->get_available_locations_data();
			$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
			$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
			$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);

			if (1 == count($locations)) {
				$session_data['pickup_data'][$cart_item['key']]['location_id'] = min($locations)->id;
				WC()->session->set($cart_item['key'], serialize($session_data));
			}

			$location_id = isset($session_data['pickup_data'][$cart_item['key']]['location_id']) ? $session_data['pickup_data'][$cart_item['key']]['location_id'] : '';

			$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);


			if (alp_pro_addon()->common->is_local_pickup_item($product_id)) {
				$location_avalibale = true;
			} else {
				$location_avalibale = false;
			}

			$is_pickup_item = alp_pro_addon()->common->is_not_pickup_item_for_all_location($product_id);

			if ('yes' != $must_be_pickedup) {
				if ($product && true == $location_avalibale && $product->needs_shipping() && $is_pickup_item) {
					?>
				<div class="alp-cart-option">
					<input type="hidden" name="cart_item_key" value="<?php echo esc_html($cart_item['key']); ?>">
					<input type="hidden" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][enabled]" class="enabled_pickup" value="0"/>
					<label><input type="checkbox" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][enabled]" class="checkbox-input enabled_pickup" <?php echo esc_html($checked); ?> value="1"/><span><?php esc_html_e('Local Pickup', 'advanced-local-pickup-pro'); ?></span></label>
					<?php if ($multiple_locations && true == $allow_pickup_per_item) { ?>
						<?php if (1 != count($locations)) { ?>
						<select class="select selected_location" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][location_id]" style="padding-right: 25px;">
							<option value="" data-address="<?php esc_html_e('Please select a location for pickup item', 'advanced-local-pickup-pro'); ?>"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
							<?php foreach ((array) $locations as $key => $location2) { ?>
								<?php if ( isset($location2->store_enable) && 1 == $location2->store_enable && alp_pro_addon()->common->is_local_pickup_item_by_location($product_id, $location2) ) { ?>
									<option value="<?php echo esc_html($location2->id); ?>" <?php echo( $location_id == $location2->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid($location2->store_name) ); ?></option>
								<?php
								}
							}
							?>
						</select>
						<?php
						}
						$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
						if (isset($wclp_local_pickup_controls['display_location_address'])
						&& 1 == $wclp_local_pickup_controls['display_location_address'] || 1 == count($locations)) {
							echo '<small>' . esc_html($address) . '</small>';
						}
						//appointment options
						$location = alp_pro_addon()->admin->get_data_byid($location_id);
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
							$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
							for ($i = 1; $i < 8; $i++) {
								$defualt_date = strtotime('+' . $i . ' day');
								$new_format = gmdate('j-n-Y', $defualt_date);
								$dayofweek = gmdate('l', strtotime($new_format));
								if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
									$new_format = gmdate('d-m-Y', $defualt_date);
									break;
								}
							}

							$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
							$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

							$defualt_date = strtotime('+' . $days . ' day');
							$new_format = gmdate('d-m-Y', $defualt_date);

							if ( get_option('allow_force_date_selection', '0') == '1') {
								$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
							} else {
								$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
							}
							$time = isset($session_data['pickup_data'][$cart_item['key']]['time']) ? $session_data['pickup_data'][$cart_item['key']]['time'] : '';
							?>
							<p class="pickup-appt-fields" style="">
								<input type="text" name ="pickup_data[<?php echo esc_html($cart_item['key']); ?>][date]" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="margin-right: 10px;" readonly>
							<?php

							$disabled = '';
							if ( empty($date) ) {
								$disabled = 'disabled';
							}

							$date = gmdate('j-n-Y', strtotime($date));

							//get full name of day
							$dayofweek = gmdate('l', strtotime($date));

							$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
							$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
							$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

							if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
								$appt_data = $exclusive_appt_data[$date];
							} else {
								$appt_data = $store_appt_days;
							}

							//get full name of day
							$dayofweek = gmdate('l', strtotime($date));
							if (isset($appt_data[strtolower($dayofweek)])) {
								$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
								$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
								$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
								$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
							}

							if (isset($start)) {
								$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
								$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
								$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
								$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
								$slot = 'hour' == $unit ? $Time * 60 : $Time;

								$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
								$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
								$time_slots = array_merge($time_slot1, $time_slot2);

								?>
								
								<select class="select appt_time--items" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][time]" style="" <?php echo esc_html($disabled); ?>> 
									<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
									<?php
									foreach ((array) $time_slots as $key1 => $val1) {
										if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
											if ('12' == $time_format) {
												$last_digit = explode(':', $val1);
												if ('00' == end($last_digit)) {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												} else {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												}
											}
											
											if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { 
												?>
												<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
												<?php
											}
										}
										$preVal = $val1;
									}
									?>
								</select>
								<?php
							} 
							?>
							</p>
							<?php
						}
					}
					?>
				</div>
				<?php
				} else {
					echo '<i style="display:block;font-size:12px;">' . esc_html__('This product is not available for local pickup', 'advanced-local-pickup-pro') . '</i>';
				}
			} else {
				if ($is_pickup_item) {
					?>
					<div class="alp-cart-option">
						<?php echo '<i style="display:block;font-size:12px;">' . esc_html__('This item must be picked up', 'advanced-local-pickup-pro') . '</i>'; ?>
						<input type="hidden" name="cart_item_key" value="<?php echo esc_html($cart_item['key']); ?>">
						<input type="hidden" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][enabled]" class="enabled_pickup" value="1" checked/>
						<?php 
						if (true == $allow_pickup_per_item) { 
							if ( 1 != count($locations) ) { 
								?>
							<select class="select selected_location" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][location_id]" style="padding-right: 25px;">
								<option value="" data-address="<?php esc_html_e('Please select a location for pickup item', 'advanced-local-pickup-pro'); ?>"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
								<?php 
								foreach ((array) $locations as $key => $location2) { 
									if (isset($location2->store_enable) && 1 == $location2->store_enable && alp_pro_addon()->common->is_local_pickup_item_by_location($product_id, $location2)) { 
										?>
										<option value="<?php echo esc_html( $location2->id ); ?>" <?php echo( $location_id == $location2->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid( $location2->store_name ) ); ?></option>
										<?php
									}	
								}
								?>
							</select>
							<?php
							}
							$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
							if ( isset($wclp_local_pickup_controls['display_location_address'])
							&& 1 == $wclp_local_pickup_controls['display_location_address'] || 1 == count($locations) ) {
								echo '<small>' . esc_html($address) . '</small>';
							}

							//appointment options
							$location = alp_pro_addon()->admin->get_data_byid($location_id);
							if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
								$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
								for ($i = 1; $i < 8; $i++) {
									$defualt_date = strtotime('+' . $i . ' day');
									$new_format = gmdate('j-n-Y', $defualt_date);
									$dayofweek = gmdate('l', strtotime($new_format));
									if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
										$new_format = gmdate('d-m-Y', $defualt_date);
										break;
									}
								}

								$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
								$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

								$defualt_date = strtotime('+' . $days . ' day');
								$new_format = gmdate('d-m-Y', $defualt_date);

								if ( get_option('allow_force_date_selection', '0') == '1') {
									$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
								} else {
									$date = isset($session_data['pickup_data'][$cart_item['key']]['date']) ? $session_data['pickup_data'][$cart_item['key']]['date'] : '';
								}
								$time = isset($session_data['pickup_data'][$cart_item['key']]['time']) ? $session_data['pickup_data'][$cart_item['key']]['time'] : '';
								?>
								<p class="pickup-appt-fields" style="">
									<input type="text" name ="pickup_data[<?php echo esc_html($cart_item['key']); ?>][date]" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="margin-right: 10px;" readonly>
								<?php

								$disabled = '';
								if ( empty($date) ) {
									$disabled = 'disabled';
								}

								$date = gmdate('j-n-Y', strtotime($date));

								//get full name of day
								$dayofweek = gmdate('l', strtotime($date));

								$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
								$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
								$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

								if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
									$appt_data = $exclusive_appt_data[$date];
								} else {
									$appt_data = $store_appt_days;
								}

								//get full name of day
								$dayofweek = gmdate('l', strtotime($date));
								if (isset($appt_data[strtolower($dayofweek)])) {
									$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
									$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
									$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
									$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
								}

								if (isset($start)) {
									$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
									$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
									$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
									$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
									$slot = 'hour' == $unit ? $Time * 60 : $Time;

									$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
									$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
									$time_slots = array_merge($time_slot1, $time_slot2);

									?>
									
									<select class="select appt_time--items" name="pickup_data[<?php echo esc_html($cart_item['key']); ?>][time]" style="" <?php echo esc_html($disabled); ?>> 
										<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
										<?php
										foreach ((array) $time_slots as $key1 => $val1) {
											if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
												if ('12' == $time_format) {
													$last_digit = explode(':', $val1);
													if ('00' == end($last_digit)) {
														$val1 = gmdate('g:ia', strtotime($val1));
														$preVal = gmdate('g:ia', strtotime($preVal));
													} else {
														$val1 = gmdate('g:ia', strtotime($val1));
														$preVal = gmdate('g:ia', strtotime($preVal));
													}
												}
												
												if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { 
													?>
													<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
													<?php
												}
											}
											$preVal = $val1;
										}
										?>
									</select>
									<?php
								} 
								?>
								</p>
								<?php
							}
						}
						?>
					</div>
					<?php
				} else {
					echo '<i style="display:block;font-size:12px;">' . esc_html__('This product is not available for local pickup', 'advanced-local-pickup-pro') . '</i>';
				}
			}
		}

		if (empty($session_data)) {
			return $item_data;
		}

		return $item_data;
	}


	/**
	 * Add to cart item.
	 *
	 * @param int   $item_data
	 * @param int   $cart_item
	 *
	 * @return array
	 */
	public function add_cart_item_data_single_cart_item( $item_data, $cart_item ) {
		
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		if (!empty(WC()->cart->get_cart()) && count(WC()->cart->get_cart()) < 2 && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
			return $item_data;
		}

		if ( isset($cart_item['key']) && ( is_cart() || is_checkout() ) ) {
			$product_id = !empty($cart_item['product_id']) ? $cart_item['product_id'] : 0;
			$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);
			if ('yes' == $must_be_pickedup) {
				echo '<i style="display:block;font-size:12px;">' . esc_html__('This item must be picked up', 'advanced-local-pickup-pro') . '</i>';
			}
		}

		if (empty($session_data)) {
			return $item_data;
		}

		return $item_data;
	}

	/**
	 * Filter packages to separate packages for pickup from ordinary packages.
	 *
	 * @since 2.0.0
	 *
	 * @param array $packages the packages array
	 * @return array
	 */
	public function handle_packages( $packages ) {
		$newpackages = array();
		$split_product_ids = array();
		$split_package_items = array();
		$regular_package_items = array();

		$shipping_methods = WC()->shipping->get_shipping_methods();
		$shipping_method_ids = array();
		foreach ($shipping_methods as $shipping_method) {
			$shipping_method_ids[$shipping_method->id] = $shipping_method->id;
		}

		if (isset($packages[0]['contents'])) {
			foreach ($packages[0]['contents'] as $item_id => $values) {

				$product_id = $packages[0]['contents'][$item_id]['product_id'];

				$is_pickup_item = alp_pro_addon()->common->is_not_pickup_item_for_all_location($product_id);
				if (count(WC()->cart->get_cart()) == 1 && !$is_pickup_item) {
					unset($shipping_method_ids['local_pickup']);
				}

				$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);
				if (1 == count(WC()->cart->get_cart()) && 'yes' == $must_be_pickedup) {
					foreach ($shipping_method_ids as $method_id) {
						if ('local_pickup' != $method_id) {
							unset($shipping_method_ids[$method_id]);
						}
					}
				}

				if (alp_pro_addon()->common->is_local_pickup_item($product_id) && count(WC()->cart->get_cart()) > 1) {
					$split_product_ids[] = $product_id;
				}

			}
		}

		foreach (WC()->cart->get_cart() as $item_key => $item) {
			$session_data = unserialize(WC()->session->get($item_key));
			if ($item['data']->needs_shipping()) {
				if ( in_array($item['product_id'], $split_product_ids) && ( isset($session_data['pickup_data'][$item_key]['enabled']) && 'yes' == $session_data['pickup_data'][$item_key]['enabled'] ) && alp_pro_addon()->common->is_not_pickup_item_for_all_location($item['product_id']) ) {
					$split_package_items[$item_key] = $item;
				} else {
					$regular_package_items[$item_key] = $item;
				}

			}
		}


		if (!empty($split_package_items) || !empty($split_product_ids)) {
			unset($shipping_method_ids['local_pickup']);
		}

		// Create shipping packages
		if ($regular_package_items) {
			$newpackages[] = array(
				'contents' => $regular_package_items,
				'contents_cost' => array_sum(wp_list_pluck($regular_package_items, 'line_total')),
				'applied_coupons' => WC()->cart->get_applied_coupons(),
				'ship_via' => $shipping_method_ids,
				'user' => array(
					'ID' => get_current_user_id(),
				),
				'destination' => array(
					'country' => WC()->customer->get_shipping_country(),
					'state' => WC()->customer->get_shipping_state(),
					'postcode' => WC()->customer->get_shipping_postcode(),
					'city' => WC()->customer->get_shipping_city(),
					'address' => WC()->customer->get_shipping_address(),
					'address_2' => WC()->customer->get_shipping_address_2()
				)
			);
		}

		if ($split_package_items) {

			$newpackages[] = array(
				'contents' => $split_package_items,
				'contents_cost' => array_sum(wp_list_pluck($split_package_items, 'line_total')),
				'applied_coupons' => WC()->cart->get_applied_coupons(),
				'ship_via' => array('local_pickup' => 'local_pickup'),
				'user' => array(
					'ID' => get_current_user_id(),
				),
				'destination' => array(
					'country' => WC()->customer->get_shipping_country(),
					'state' => WC()->customer->get_shipping_state(),
					'postcode' => WC()->customer->get_shipping_postcode(),
					'city' => WC()->customer->get_shipping_city(),
					'address' => WC()->customer->get_shipping_address(),
					'address_2' => WC()->customer->get_shipping_address_2()
				)
			);
		}

		return $newpackages;
	}

	/**
	 * Filter packages to separate packages for pickup from ordinary packages.
	 *
	 * @since 2.0.0
	 *
	 * @param array $packages the packages array
	 * @return array
	 */
	public function handle_packages_single_cart_item( $packages ) {

		$newpackages = array();
		$split_product_ids = array();
		$split_package_items = array();
		$regular_package_items = array();

		$shipping_methods = WC()->shipping->get_shipping_methods();
		$shipping_method_ids = array();
		foreach ($shipping_methods as $shipping_method) {
			$shipping_method_ids[$shipping_method->id] = $shipping_method->id;
		}

		foreach ($packages[0]['contents'] as $item_id => $values) {

			$product_id = $packages[0]['contents'][$item_id]['product_id'];

			$is_pickup_item = alp_pro_addon()->common->is_not_pickup_item_for_all_location($product_id);
			if (!$is_pickup_item) {
				unset($shipping_method_ids['local_pickup']);
			}

			$must_be_pickedup = get_post_meta($product_id, '_per_product_pickedup', true);
			if ('yes' == $must_be_pickedup) {
				foreach ($shipping_method_ids as $method_id) {
					if ('local_pickup' != $method_id) {
						unset($shipping_method_ids[$method_id]);
					}
				}
			}

			if ('yes' == $must_be_pickedup) {
				$split_product_ids[] = $product_id;
			}

		}

		foreach (WC()->cart->get_cart() as $item_key => $item) {
			if ( isset($item_key) ) {
				$session_data = unserialize(WC()->session->get($item_key));
				if ($item['data']->needs_shipping()) {
					if (in_array($item['product_id'], $split_product_ids)) {
						$split_package_items[$item_key] = $item;
					} else {
						$regular_package_items[$item_key] = $item;
					}
				}
			}
		}


		if (!empty($split_package_items) || !empty($split_product_ids)) {
			unset($shipping_method_ids['local_pickup']);
		}

		// Create shipping packages
		if ($regular_package_items) {
			$newpackages[] = array(
				'contents' => $regular_package_items,
				'contents_cost' => array_sum(wp_list_pluck($regular_package_items, 'line_total')),
				'applied_coupons' => WC()->cart->get_applied_coupons(),
				'ship_via' => $shipping_method_ids,
				'user' => array(
					'ID' => get_current_user_id(),
				),
				'destination' => array(
					'country' => WC()->customer->get_shipping_country(),
					'state' => WC()->customer->get_shipping_state(),
					'postcode' => WC()->customer->get_shipping_postcode(),
					'city' => WC()->customer->get_shipping_city(),
					'address' => WC()->customer->get_shipping_address(),
					'address_2' => WC()->customer->get_shipping_address_2()
				)
			);
		}

		if ($split_package_items) {

			$newpackages[] = array(
				'contents' => $split_package_items,
				'contents_cost' => array_sum(wp_list_pluck($split_package_items, 'line_total')),
				'applied_coupons' => WC()->cart->get_applied_coupons(),
				'ship_via' => array('local_pickup' => 'local_pickup'),
				'user' => array(
					'ID' => get_current_user_id(),
				),
				'destination' => array(
					'country' => WC()->customer->get_shipping_country(),
					'state' => WC()->customer->get_shipping_state(),
					'postcode' => WC()->customer->get_shipping_postcode(),
					'city' => WC()->customer->get_shipping_city(),
					'address' => WC()->customer->get_shipping_address(),
					'address_2' => WC()->customer->get_shipping_address_2()
				)
			);
		}

		return $newpackages;
	}

	

	/**
	 * Display multiple pickup location dropdown after shipping in cart/checkout page
	 */
	public function alp_add_pickup_location_dropdown_after_shipping() {

		if ( is_plugin_active('checkout-for-woocommerce/checkout-for-woocommerce.php') && is_checkout() ) {
			return;
		}
		if ( is_checkout() && !wp_doing_ajax() ) {
			return;
		}

		$chosen_methods = WC()->session->get('chosen_shipping_methods');
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		$locationsData = alp_pro_addon()->admin->get_available_locations_data();
		$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
		$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
		$session_data = WC()->session->get('pickup_location_id');
		$appt_session_data = unserialize(WC()->session->get('appt_data'));
		$location_id = !empty($session_data) ? $session_data : '';
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		if (isset($get_shipping[0]) && 'local_pickup' == $get_shipping[0]) { 
			?>
			<tr class="alp-pickup-data location-dropdown-details">
				<th class="pickup__items_locations" colspan="2">
					<strong class="pickup__title">
					<?php
					if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && count($locations) != 1) {
						esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
					} else if (1 == count($locations)) {
						esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
							esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
						}
					} else {
						esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
					}
					?>
					</strong>
					
					<?php if (1 != count($locations)) { ?>
						<select class="select selected_pickup_location" name="selected_pickup_location" style="padding-right: 25px;">
							<option value="" data-address="Please select a location for pickup items"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
							<?php
							foreach ((array) $locations as $key => $location) {
								if ( isset($location->store_enable) && 1 == $location->store_enable && alp_pro_addon()->common->is_pickup_location_exclude($location) ) {
									$address = alp_pro_addon()->admin->get_store_address_by_id($location->id);
									?>
										<option value="<?php echo esc_html( $location->id ); ?>" data-address="<?php echo esc_html( $address ); ?>" <?php echo( $location_id == $location->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid( $location->store_name ) ); ?></option>
									<?php
								}
							}
							?>
						</select>
						<?php
					} else {
						?>
						<input type="hidden" class="selected_pickup_location" name="selected_pickup_location" value="<?php echo esc_html( min($locations)->id ); ?>">
						<?php
					}
					if (isset($wclp_local_pickup_controls['display_location_address']) && 0 == $wclp_local_pickup_controls['display_location_address'] && count($locations) == 1) {
						echo '<span>';
						echo isset($location->store_name) ? esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location->store_name)) : '';
						echo '</span><br>';
					}

					if (isset($wclp_local_pickup_controls['display_location_address'])
					&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) == 1) {
						$address = alp_pro_addon()->admin->get_store_address_by_id(min($locations)->id);
						echo '<small>';
						echo '<strong>' . esc_html(min($locations)->store_name) . ' - </strong>';
						echo esc_html($address);
						echo '</small>';
					}

					if (isset($wclp_local_pickup_controls['display_location_address'])
					&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) > 1) {
						$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
						echo '<small>';
						echo esc_html($address);
						echo '</small>';
					}

					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
						$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
						for ($i = 1; $i < 8; $i++) {
							$defualt_date = strtotime('+' . $i . ' day');
							$new_format = gmdate('j-n-Y', $defualt_date);
							$dayofweek = gmdate('l', strtotime($new_format));
							if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
								$new_format = gmdate('d-m-Y', $defualt_date);
								break;
							}
						}

						$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
						$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

						$defualt_date = strtotime('+' . $days . ' day');
						$new_format = gmdate('d-m-Y', $defualt_date);

						if ( get_option('allow_force_date_selection', '0') == '1') {
							$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';
						} else {
							$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';//gmdate(get_option('date_format'), strtotime($new_format));
						}
						$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';
						?>
						<p class="pickup-appt-fields" style=""><input type="text" name ="appt_date_option" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="margin-right: 10px;" readonly>
						<?php

						$disabled = '';
						if ( empty($date) ) {
							$disabled = 'disabled';
						}

						$date = gmdate('j-n-Y', strtotime($date));

						//get full name of day
						$dayofweek = gmdate('l', strtotime($date));

						$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
						$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
						$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

						if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
							$appt_data = $exclusive_appt_data[$date];
						} else {
							$appt_data = $store_appt_days;
						}

						//get full name of day
						$dayofweek = gmdate('l', strtotime($date));
						if (isset($appt_data[strtolower($dayofweek)])) {
							$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
							$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
							$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
							$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
						}

						if (isset($start)) {
							$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
							$slotSetting = !empty($location->store_appt_pickup_increment) && isset($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
							$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
							$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
							$slot = 'hour' == $unit ? $Time * 60 : $Time;

							$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
							$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
							$time_slots = array_merge($time_slot1, $time_slot2);

							?>
							
							<select class="select appt_time--items" name="appt_time_option" style="" <?php echo esc_html($disabled); ?>> 
								<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
								<?php
								foreach ((array) $time_slots as $key1 => $val1) {
									if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
										if ('12' == $time_format) {
											$last_digit = explode(':', $val1);
											if ('00' == end($last_digit)) {
												$val1 = gmdate('g:ia', strtotime($val1));
												$preVal = gmdate('g:ia', strtotime($preVal));
											} else {
												$val1 = gmdate('g:ia', strtotime($val1));
												$preVal = gmdate('g:ia', strtotime($preVal));
											}
										}
										
										if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { 
											?>
											<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
											<?php
										}
									}
									$preVal = $val1;
								}
								?>
							</select>
							<?php
						} 
						?>
						</p>
						<?php
					}
					?>
			</th>
		</tr>
	<?php
		} else {
			$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$location_dropdown = false;
			if (isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders'] && count(WC()->cart->get_cart()) > 1) {
				foreach (WC()->cart->get_cart() as $item_key => $item) {
					$session_data = unserialize(WC()->session->get($item_key));
					if ($item['data']->needs_shipping()) {
						if ( alp_pro_addon()->common->is_local_pickup_item($item['product_id']) && ( isset($session_data['pickup_data'][$item_key]['enabled']) && 'yes' == $session_data['pickup_data'][$item_key]['enabled'] ) ) {
							?>
							<?php $location_dropdown = true; ?>
						<?php
						}
					}
				}
				?>
				<?php if ($location_dropdown) { ?>
					<tr class="alp-pickup-data location-dropdown-details">
						<th class="pickup__items_locations" colspan="2">
							<strong class="pickup__title">
							<?php
							if ( isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && 1 != count($locations) ) {
								esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
							} else if (1 == count($locations)) {
								esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
								if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
									esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
								}
							} else {
								esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
							}
							?>
							</strong>
							<?php if (1 != count($locations)) { ?>
							<select class="select selected_pickup_location" name="selected_pickup_location" style="padding-right: 25px;">
								<option value="" data-address="Please select a location for pickup items"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
								<?php
								foreach ((array) $locations as $key => $location) {
									if ( isset($location->store_enable) && 1 == $location->store_enable && alp_pro_addon()->common->is_pickup_location_exclude($location) ) {
										$address = alp_pro_addon()->admin->get_store_address_by_id($location->id);
										?>
										<option value="<?php echo esc_html( $location->id ); ?>" data-address="<?php echo esc_html( $address ); ?>" <?php echo( $location_id == $location->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid( $location->store_name ) ); ?></option>
										<?php
									}
								}
								?>
							</select>
							<?php
							} else { 
								?>
								<input type="hidden" class="selected_pickup_location" name="selected_pickup_location" value="<?php echo esc_html( min($locations)->id ) ; ?>">
								<?php
							}
							if (isset($wclp_local_pickup_controls['display_location_address']) && 0 == $wclp_local_pickup_controls['display_location_address'] && 1 == count($locations)) {
								echo '<span>';
								echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location->store_name));
								echo '</span><br>';
							}

							if (isset($wclp_local_pickup_controls['display_location_address'])
							&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) == 1) {
								$address = alp_pro_addon()->admin->get_store_address_by_id(min($locations)->id);
								echo '<small>';
								echo '<strong>' . esc_html(min($locations)->store_name) . ' - </strong>';
								echo esc_html($address);
								echo '</small>';
							}

							if (isset($wclp_local_pickup_controls['display_location_address'])
							&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) > 1) {
								$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
								echo '<small>';
								echo esc_html($address);
								echo '</small>';
							}

							$location = alp_pro_addon()->admin->get_data_byid($location_id);
							if ('1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
								$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
								for ($i = 1; $i < 8; $i++) {
									$defualt_date = strtotime('+' . $i . ' day');
									$new_format = gmdate('j-n-Y', $defualt_date);
									$dayofweek = gmdate('l', strtotime($new_format));
									if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
										$first_date = gmdate('d-m-Y', $defualt_date);
										break;
									}
								}

								$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
								$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

								$defualt_date = strtotime('+' . $days . ' day');
								$new_format = gmdate('d-m-Y', $defualt_date);

								if ( get_option('allow_force_date_selection', '0') == '1') {
									$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';
								} else {
									$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';//gmdate(get_option('date_format'), strtotime($new_format));
								}
								$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';
								?>
								<p class="pickup-appt-fields" style=""><input type="text" name ="appt_date_option" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="margin-right: 10px;" readonly>
								<?php

								$disabled = '';
								if ( empty($date) ) {
									$disabled = 'disabled';
								}

								$date = gmdate('j-n-Y', strtotime($date));

								//get full name of day
								$dayofweek = gmdate('l', strtotime($date));

								$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
								$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
								$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

								if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
									$appt_data = $exclusive_appt_data[$date];
								} else {
									$appt_data = $store_appt_days;
								}

								if (isset($appt_data[strtolower($dayofweek)])) {
									$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
									$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
									$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
									$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
								}

								if (isset($start)) {
									$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';

									$slotSetting = !empty($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
									$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
									$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
									$slot = 'hour' == $unit ? $Time * 60 : $Time;

									$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
									$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
									$time_slots = array_merge($time_slot1, $time_slot2);
									?>
								<select class="select appt_time--items" name="appt_time_option" style="" <?php echo esc_html($disabled); ?>> 
									<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
									<?php
									foreach ((array) $time_slots as $key1 => $val1) {
										if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
											if ('12' == $time_format) {
												$last_digit = explode(':', $val1);
												if ('00' == end($last_digit)) {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												} else {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												}
											}
											if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { 
												?>
											<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
											<?php
											}
										}
										$preVal = $val1;
									}
									?>
								</select>
								<?php
								}
								?>
								</p>
								<?php
							}
							?>
						</th>
					</tr>
				<?php
				}
			}
		}

	}

	/**
	 * Display multiple pickup location dropdown after shipping in cart/checkout page
	 */
	public function alp_checkoutWC_pickup_location_dropdown_after_shipping( $method, $index ) {

		if ( !is_plugin_active('checkout-for-woocommerce/checkout-for-woocommerce.php') || !is_checkout() ) {
			return;
		}
		if ( 'local_pickup' != $method->method_id ) {
			return;
		}
		if ( is_checkout() && !wp_doing_ajax() ) {
			return;
		}

		$chosen_methods = WC()->session->get('chosen_shipping_methods');
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		$locationsData = alp_pro_addon()->admin->get_available_locations_data();
		$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
		$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
		$session_data = WC()->session->get('pickup_location_id');
		$appt_session_data = unserialize(WC()->session->get('appt_data'));
		$location_id = !empty($session_data) ? $session_data : '';
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
		
		if (isset($get_shipping[0]) && 'local_pickup' == $get_shipping[0]) { 
			?>
			<div class="row cfw-input-wrap-row pickup__items_locations">
				<div class="col-lg-6">
					<div class="cfw-input-wrap cfw-select-input cfw-floating-label">
						<label class="pickup__title">
							<?php
							if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && count($locations) != 1) {
								esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
							} else if (1 == count($locations)) {
								esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
								if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
									esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
								}
							} else {
								esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
							}
							?>
						</label>
						<?php if (1 != count($locations)) { ?>
						<select class="select selected_pickup_location" name="selected_pickup_location">
							<option value="" data-address="Please select a location for pickup items"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
							<?php
							foreach ((array) $locations as $key => $location) {
								if (isset($location->store_enable) && 1 == $location->store_enable && alp_pro_addon()->common->is_pickup_location_exclude($location)) {
									$address = alp_pro_addon()->admin->get_store_address_by_id($location->id);
									?>
										<option value="<?php echo esc_html( $location->id ); ?>" data-address="<?php echo esc_html( $address ); ?>" <?php echo( $location_id == $location->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid( $location->store_name ) ); ?></option>
									<?php
								}
							}
							?>
						</select>
						<?php
						} else { 
							?>
							<input type="hidden" class="selected_pickup_location" name="selected_pickup_location" value="<?php echo esc_html( min($locations)->id ); ?>">
							<?php
						}
						?>
					</div>
					<?php
					if (isset($wclp_local_pickup_controls['display_location_address']) && 0 == $wclp_local_pickup_controls['display_location_address'] && 1 == count($locations)) {
						echo '<span>';
						echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location->store_name));
						echo '</span><br>';
					}

					if (isset($wclp_local_pickup_controls['display_location_address'])
					&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) == 1) {
						$address = alp_pro_addon()->admin->get_store_address_by_id(min($locations)->id);
						echo '<small>';
						echo '<strong>' . esc_html(min($locations)->store_name) . ' - </strong>';
						echo esc_html($address);
						echo '</small>';
					}

					if (isset($wclp_local_pickup_controls['display_location_address'])
					&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) > 1) {
						$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
						echo '<small>';
						echo esc_html($address);
						echo '</small>';
					}
					?>
				</div>
				<?php
				$location = alp_pro_addon()->admin->get_data_byid($location_id);
				if ('1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
					$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
					for ($i = 1; $i < 8; $i++) {
						$defualt_date = strtotime('+' . $i . ' day');
						$new_format = gmdate('j-n-Y', $defualt_date);
						$dayofweek = gmdate('l', strtotime($new_format));
						if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
							$first_date = gmdate('d-m-Y', $defualt_date);
							break;
						}
					}

					$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
					$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

					$defualt_date = strtotime('+' . $days . ' day');
					$new_format = gmdate('d-m-Y', $defualt_date);

					if ( get_option('allow_force_date_selection', '0') == '1') {
						$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';
					} else {
						$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';//gmdate(get_option('date_format'), strtotime($new_format));
					}
					$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';
					?>
					<div class="col-lg-3">
						<div class="cfw-input-wrap cfw-floating-label pickup-appt-fields">
							<label class="pickup__title">
								<?php esc_html_e('Appointment Date', 'advanced-local-pickup-pro'); ?>
							</label>
							<input type="text" name ="appt_date_option" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" readonly>
						</div>
					</div>
					<div class="col-lg-3">
						<div class="cfw-input-wrap cfw-select-input cfw-floating-label">
							<label class="pickup__title">
								<?php esc_html_e('Appointment time', 'advanced-local-pickup-pro'); ?>
							</label>
							<?php

							$disabled = '';
							if ( empty($date) ) {
								$disabled = 'disabled';
							}

							$date = gmdate('j-n-Y', strtotime($date));

							//get full name of day
							$dayofweek = gmdate('l', strtotime($date));

							$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
							$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
							$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

							if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
								$appt_data = $exclusive_appt_data[$date];
							} else {
								$appt_data = $store_appt_days;
							}

							if (isset($appt_data[strtolower($dayofweek)])) {
								$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
								$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
								$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
								$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
							}

							if (isset($start)) {
								$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
								$slotSetting = !empty($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
								$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
								$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
								$slot = 'hour' == $unit ? $Time * 60 : $Time;

								$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
								$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
								$time_slots = array_merge($time_slot1, $time_slot2);
								?>
								<select class="select appt_time--items" name="appt_time_option" style="" <?php echo esc_html($disabled); ?>> 
									<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
									<?php
									foreach ((array) $time_slots as $key1 => $val1) {
										if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
											if ('12' == $time_format) {
												$last_digit = explode(':', $val1);
												if ('00' == end($last_digit)) {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												} else {
													$val1 = gmdate('g:ia', strtotime($val1));
													$preVal = gmdate('g:ia', strtotime($preVal));
												}
											}
											?>
									<?php if ( alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id) ) { ?>
										<option value="<?php echo esc_html( $preVal . '-' . $val1 ); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html( $preVal . ' - ' . $val1 ); ?></option>
									<?php
											}
										}
								$preVal = $val1;
									}
									?>
							</select>
						<?php
							}
							?>
					</div>
				</div>
			</div>
			<?php
				}
		} else {
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
			$location_dropdown = false;
			if (isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders'] && count(WC()->cart->get_cart()) > 1) {
				foreach (WC()->cart->get_cart() as $item_key => $item) {
					$session_data = unserialize(WC()->session->get($item_key));
					if ($item['data']->needs_shipping()) {
						if ( alp_pro_addon()->common->is_local_pickup_item($item['product_id']) && ( isset($session_data['pickup_data'][$item_key]['enabled']) && 'yes' == $session_data['pickup_data'][$item_key]['enabled'] ) ) {
							$location_dropdown = true;
						}
					}
				}
				if ($location_dropdown) { 
					?>
					<div class="row cfw-input-wrap-row pickup__items_locations">
						<div class="col-lg-6">
							<div class="cfw-input-wrap cfw-select-input cfw-floating-label">
								<label class="pickup__title">
								<?php
								if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && count($locations) != 1) {
									esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
								} else if (1 == count($locations)) {
									esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
									if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
										esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
									}
								} else {
									esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
								}
								?>
								</label>
								<?php if (1 != count($locations)) { ?>
								<select class="select selected_pickup_location" name="selected_pickup_location">
									<option value="" data-address="Please select a location for pickup items"><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
									<?php
									foreach ((array) $locations as $key => $location) {
										if (isset($location->store_enable) && 1 == $location->store_enable && alp_pro_addon()->common->is_pickup_location_exclude($location)) {
											$country_code = isset($location) ? $location->store_country : get_option('woocommerce_default_country');
											$split_country = explode(':', $country_code);
											$address = alp_pro_addon()->admin->get_store_address_by_id($location->id);
											?>
											<option value="<?php echo esc_html( $location->id ); ?>" data-address="<?php echo esc_html( $address ); ?>" <?php echo( $location_id == $location->id ) ? 'selected' : ''; ?>><?php echo esc_html( alp_pro_addon()->admin->get_slaches_data_byid( $location->store_name ) ); ?></option>
										<?php
										}
									}
									?>
								</select>
								<?php
								} else { 
									?>
									<input type="hidden" class="selected_pickup_location" name="selected_pickup_location" value="<?php echo esc_html( min($locations)->id); ?>">
									<?php
								}
								?>
							</div>
							<?php
							if (isset($wclp_local_pickup_controls['display_location_address']) && 0 == $wclp_local_pickup_controls['display_location_address'] && 1 == count($locations)) {
								echo '<span>';
								echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid($location->store_name));
								echo '</span><br>';
							}

							if (isset($wclp_local_pickup_controls['display_location_address'])
							&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) == 1) {
								$address = alp_pro_addon()->admin->get_store_address_by_id(min($locations)->id);
								echo '<small>';
								echo '<strong>' . esc_html(min($locations)->store_name) . ' - </strong>';
								echo esc_html($address);
								echo '</small>';
							}

							if (isset($wclp_local_pickup_controls['display_location_address'])
							&& 1 == $wclp_local_pickup_controls['display_location_address'] && count($locations) > 1) {
								$address = alp_pro_addon()->admin->get_store_address_by_id($location_id);
								echo '<small>';
								echo esc_html($address);
								echo '</small>';
							}
							?>
						</div>
						<?php
						$location = alp_pro_addon()->admin->get_data_byid($location_id);
						if ('1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {

							$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
							for ($i = 1; $i < 8; $i++) {
								$defualt_date = strtotime('+' . $i . ' day');
								$new_format = gmdate('j-n-Y', $defualt_date);
								$dayofweek = gmdate('l', strtotime($new_format));
								if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
									$first_date = gmdate('d-m-Y', $defualt_date);
									break;
								}

							}

							$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
							$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

							$defualt_date = strtotime('+' . $days . ' day');
							$new_format = gmdate('d-m-Y', $defualt_date);

							if ( get_option('allow_force_date_selection', '0') == '1') {
								$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';
							} else {
								$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : '';//gmdate(get_option('date_format'), strtotime($new_format));
							}
							$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';

							?>
							<div class="col-lg-3">
								<div class="cfw-input-wrap cfw-floating-label pickup-appt-fields">
									<label class="pickup__title">
										<?php esc_html_e('Appointment Date', 'advanced-local-pickup-pro'); ?>
									</label>
									<input type="text" name ="appt_date_option" class="datepicker appt_date--items" value="<?php !empty($date) ? esc_html_e(gmdate(get_option('date_format'), strtotime($date))) : ''; ?>" placeholder="<?php esc_html_e('Select date', 'advanced-local-pickup-pro'); ?>" style="" readonly>
								</div>
							</div>
							<div class="col-lg-3">
								<div class="cfw-input-wrap cfw-select-input cfw-floating-label">
									<label class="pickup__title">
										<?php esc_html_e('Appointment time', 'advanced-local-pickup-pro'); ?>
									</label>
									<?php

									$disabled = '';
									if ( empty($date) ) {
										$disabled = 'disabled';
									}

									$date = gmdate('j-n-Y', strtotime($date));

									//get full name of day
									$dayofweek = gmdate('l', strtotime($date));

									$store_days = isset($location->store_days) ? unserialize($location->store_days) : get_option('wclp_store_days');
									$store_appt_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : $store_days;
									$exclusive_appt_data = isset($location->store_appt_exclusive_days) ? unserialize($location->store_appt_exclusive_days) : array();

									if (isset($exclusive_appt_data[$date]) && !empty($exclusive_appt_data[$date])) {
										$appt_data = $exclusive_appt_data[$date];
									} else {
										$appt_data = $store_appt_days;
									}

									if (isset($appt_data[strtolower($dayofweek)])) {
										$start = $appt_data[strtolower($dayofweek)]['wclp_store_hour'];
										$end = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end'];
										$start2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour2'];
										$end2 = $appt_data[strtolower($dayofweek)]['wclp_store_hour_end2'];
									}

									if (isset($start)) {
										$time_format = isset($location->store_time_format) ? $location->store_time_format : '24';
										$slotSetting = !empty($location->store_appt_pickup_increment) ? unserialize($location->store_appt_pickup_increment) : array();
										$Time = !empty($slotSetting['time']) ? $slotSetting['time'] : '15';
										$unit = !empty($slotSetting['unit']) ? $slotSetting['unit'] : 'min';
										$slot = 'hour' == $unit ? $Time * 60 : $Time;

										$time_slot1 = alp_pro_addon()->common->getTimeSlots($slot, $start, $end);
										$time_slot2 = alp_pro_addon()->common->getTimeSlots($slot, $start2, $end2);
										$time_slots = array_merge($time_slot1, $time_slot2);

										?>
										<select class="select appt_time--items" name="appt_time_option" style="" <?php echo esc_html( $disabled ); ?>> 
											<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
											<?php
											foreach ((array) $time_slots as $key1 => $val1) {
												if ( isset($preVal) && ( isset($end) && strtotime($val1) <= strtotime($end) || isset($start2) && strtotime($preVal) >= strtotime($start2) ) ) {
													if ('12' == $time_format) {
														$last_digit = explode(':', $val1);
														if ( '00' == end($last_digit) ) {
															$val1 = gmdate('g:ia', strtotime($val1));
															$preVal = gmdate('g:ia', strtotime($preVal));
														} else {
															$val1 = gmdate('g:ia', strtotime($val1));
															$preVal = gmdate('g:ia', strtotime($preVal));
														}
													}
													if (alp_pro_addon()->common->is_available_time_slot($preVal, $val1, $date, $location_id)) { 
														?>
														<option value="<?php echo esc_html($preVal . '-' . $val1); ?>" <?php echo( $preVal . '-' . $val1 == $time ) ? 'selected' : ''; ?>><?php echo esc_html($preVal . ' - ' . $val1); ?></option>
														<?php
													}
												}
												$preVal = $val1;
											}
											?>
										</select>
									<?php
									}
									?>
								</div>
							</div>
						</div>
						<?php
						}
				}
			}
		}
	}

	/**
	 * Display multiple pickup location dropdown after shipping in cart/checkout page
	 */
	public function alp_add_pickup_location_dropdown_popup_after_shipping( $method, $index ) {
		if (is_plugin_active('checkout-for-woocommerce/checkout-for-woocommerce.php') && is_checkout()) {
			return;
		}

		if ('local_pickup' != $method->method_id) {
			return;
		}

		if (is_checkout() && !wp_doing_ajax()) {
			return;
		}

		$chosen_methods = WC()->session->get('chosen_shipping_methods');
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		$locationsData = alp_pro_addon()->admin->get_available_locations_data();
		$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
		$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
		$session_data = WC()->session->get('pickup_location_id');
		$location_id = !empty($session_data) ? $session_data : '';
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		if (isset($get_shipping[0]) && 'local_pickup' == $get_shipping[0]) { 
			?>

			<label class="pickup__items_locations pickup__title">
				<?php
				if ( empty($session_data)) {
					if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && 1 != count($locations)) {
						esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
					} else if (1 == count($locations)) {
						esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
							esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
						}
					} else {
						esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
					}
				} else {
					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					esc_html_e($location->store_name);
				}
				?>
				<span class="dashicons dashicons-edit"></span>
			</label>
			<div id="local_pickup_cart_checkout_popup_html" class="popupwrapper local-pickup-cart-checkout" style="display:none;">
				<div class="popuprow">
					<span class="dashicons dashicons-no-alt popup_close_icon"></span>
					<?php alp_pro_addon()->common->get_local_pickup_cart_checkout_html($location_id, $location, $locations); ?>
				</div>
				<div class="popupclose"></div>
			</div>
			<?php
		} else {

			$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$location_dropdown = false;
			if (isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders'] && count(WC()->cart->get_cart()) > 1) {
				foreach (WC()->cart->get_cart() as $item_key => $item) {
					$pickup_session_data = unserialize(WC()->session->get($item_key));
					if ($item['data']->needs_shipping()) {
						if ( alp_pro_addon()->common->is_local_pickup_item($item['product_id']) && ( isset($pickup_session_data['pickup_data'][$item_key]['enabled']) && 'yes' == $pickup_session_data['pickup_data'][$item_key]['enabled'] ) ) {
						 $location_dropdown = true;
						}
					}
				}
				
				if ($location_dropdown) {  
					?>
				<label class="pickup__items_locations pickup__title">
					<?php
					if ( empty( $session_data ) ) {
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && 1 != count($locations)) {
							esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
						} else if (1 == count($locations)) {
							esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
							if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
								esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
							}
						} else {
							esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
						}
					} else {
						$location = alp_pro_addon()->admin->get_data_byid($location_id);
						esc_html_e($location->store_name);
					}
					?>
					<span class="dashicons dashicons-edit"></span>
				</label>
				<div id="local_pickup_cart_checkout_popup_html" class="popupwrapper local-pickup-cart-checkout" style="display:none;">
					<div class="popuprow">
						<span class="dashicons dashicons-no-alt popup_close_icon"></span>
						<?php alp_pro_addon()->common->get_local_pickup_cart_checkout_html($location_id, $location, $locations); ?>
					</div>
					<div class="popupclose"></div>
				</div>
				<?php
				}
			}
		}
	}

	/**
	 * Display multiple pickup location dropdown after shipping in cart/checkout page
	 */
	public function alp_checkoutWC_pickup_location_dropdown_popup_after_shipping( $method, $index ) {

		if (!is_plugin_active('checkout-for-woocommerce/checkout-for-woocommerce.php') || !is_checkout()) {
			return;
		}
		if ('local_pickup' != $method->method_id) {
			return;
		}
		if (is_checkout() && !wp_doing_ajax()) {
			return;
		}

		$chosen_methods = WC()->session->get('chosen_shipping_methods');
		$get_shipping = isset($chosen_methods) ? explode(':', $chosen_methods[0]) : '';
		$locationsData = alp_pro_addon()->admin->get_available_locations_data();
		$locationSortingArray = alp_pro_addon()->common->get_sorting_array();
		$locations = !empty($locationSortingArray) ? $locationSortingArray : $locationsData;
		$session_data = WC()->session->get('pickup_location_id');
		$location_id = !empty($session_data) ? $session_data : '';
		$location = alp_pro_addon()->admin->get_data_byid($location_id);
		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		if (isset($get_shipping[0]) && 'local_pickup' == $get_shipping[0]) { 
			?>
			<div class="row cfw-input-wrap-row pickup__items_locations">
				<div class="col-lg-12">
					<label class="pickup__items_locations pickup__title" style="margin-top: 12px;">
					<?php
					if ( empty( $session_data ) ) {
						if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && 1 != count($locations)) {
							esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
						} else if (1 == count($locations)) {
							esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
							if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
								esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
							}
						} else {
							esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
						}
					} else {
						$location = alp_pro_addon()->admin->get_data_byid($location_id);
						esc_html_e($location->store_name);
					}
					?>
					<span class="dashicons dashicons-edit"></span>
					</label>
					<div id="local_pickup_cart_checkout_popup_html" class="popupwrapper local-pickup-cart-checkout" style="display:none;">
						<div class="popuprow">
							<span class="dashicons dashicons-no-alt popup_close_icon"></span>
							<?php alp_pro_addon()->common->get_local_pickup_cart_checkout_html($location_id, $location, $locations); ?>
						</div>
						<div class="popupclose"></div>
					</div>
				</div>
			</div>
		<?php
		} else {
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');
			$location_dropdown = false;
			if ( isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 == $wclp_local_pickup_controls['allow_mixed_orders'] && count(WC()->cart->get_cart()) > 1 ) {
				foreach (WC()->cart->get_cart() as $item_key => $item) {
					$pickup_session_data = unserialize(WC()->session->get($item_key));
					if ($item['data']->needs_shipping()) {
						if ( alp_pro_addon()->common->is_local_pickup_item($item['product_id']) && ( isset($pickup_session_data['pickup_data'][$item_key]['enabled']) && 'yes' == $pickup_session_data['pickup_data'][$item_key]['enabled'] ) ) {
							$location_dropdown = true; 
						}
					}
				}
				if ($location_dropdown) { 
					?>
					<div class="row cfw-input-wrap-row">
						<div class="col-lg-12">
							<label class="pickup__items_locations pickup__title" style="margin-top: 12px;">
								<?php
								if ( empty($session_data)) {
									if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item'] && count($locations) != 1) {
										esc_html_e('Select location and schedule pick up', 'advanced-local-pickup-pro');
									} else if (count($locations) == 1) {
										esc_html_e('Pickup Location', 'advanced-local-pickup-pro');
										if (isset($location->store_enable_appt) && '1' == $location->store_enable_appt) {
											esc_html_e(' and schedule pick up', 'advanced-local-pickup-pro');
										}
									} else {
										esc_html_e('Select Pickup Location', 'advanced-local-pickup-pro');
									}
								} else {
									$location = alp_pro_addon()->admin->get_data_byid($location_id);
									esc_html_e($location->store_name);
								}
								?>
								<span class="dashicons dashicons-edit"></span>
							</label>
							<div id="local_pickup_cart_checkout_popup_html" class="popupwrapper local-pickup-cart-checkout" style="display:none;">
								<div class="popuprow">
									<span class="dashicons dashicons-no-alt popup_close_icon"></span>
									<?php alp_pro_addon()->common->get_local_pickup_cart_checkout_html($location_id, $location, $locations); ?>
								</div>
								<div class="popupclose"></div>
							</div>
						</div>
					</div>
					<?php
				}
			}
		}
	}

	/*
	 * Rename shipping method label in cart/checkout page
	 */
	public function alp_rename_shipping_package_name( $sprintf, $i, $package ) {
		if (isset($package['ship_via']['local_pickup']) && 1 == count($package['ship_via'])) {
			$sprintf = 'Local Pickup';
		}
		return $sprintf;
	}

	/*
	 * Add selected pickup location id in order meta
	 */
	public function alp_add_pickup_location_ids_in_order_meta( $order_id ) {

		$order = wc_get_order($order_id);

		// Iterating through order shipping items
		foreach ($order->get_items('shipping') as $item_id => $shipping_item_obj) {
			$shipping_method = $shipping_item_obj->get_method_id();
		}

		//IF  dshipping method is not local pickup then @return;
		if (!isset($shipping_method)) {
			return;
		}
		if (isset($shipping_method) && 'local_pickup' != $shipping_method) {
			return;
		}

		$location_ids = array();
		$appt_data = array();
		foreach (WC()->cart->get_cart() as $cart_item_key => $item) {

			if ($item['data']->needs_shipping()) {

				$session_data = unserialize(WC()->session->get($cart_item_key));

				$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

				if (isset($session_data['pickup_data'][$cart_item_key]['enabled'])
				&& 'yes' == $session_data['pickup_data'][$cart_item_key]['enabled'] || count(WC()->cart->get_cart()) < 2) {

					if (isset($wclp_local_pickup_controls['allow_pickup_per_item'])
					&& 1 == $wclp_local_pickup_controls['allow_pickup_per_item']) {

						$location_id = isset($session_data['pickup_data'][$cart_item_key]['location_id']) ? $session_data['pickup_data'][$cart_item_key]['location_id'] : ''; //alp_pro_addon()->common->get_defualt_location_id($item['product_id']);
						$date = isset($session_data['pickup_data'][$cart_item_key]['date']) ? $session_data['pickup_data'][$cart_item_key]['date'] : '';
						$time = isset($session_data['pickup_data'][$cart_item_key]['time']) ? $session_data['pickup_data'][$cart_item_key]['time'] : '';
						if (!empty($location_id)) {
							$location_ids[$item['product_id']] = $location_id;
							if ( !empty($date) && !empty($time) ) {
								$appt_data[$order_id][$item['product_id']]['location_id'] = $location_id;
								$appt_data[$order_id][$item['product_id']]['pickup_date'] = $date;//gmdate('d-m-Y', strtotime($date));
								$appt_data[$order_id][$item['product_id']]['pickup_time'] = $time;
							}
						}

						//automation not available for pickup per item

					}

					if (isset($wclp_local_pickup_controls['allow_mixed_orders'])
					&& 1 == $wclp_local_pickup_controls['allow_mixed_orders']
					&& isset($wclp_local_pickup_controls['allow_pickup_per_item'])
					&& 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {

						$session_data = WC()->session->get('pickup_location_id');
						$location_id = !empty($session_data) ? $session_data : '';

						if (!empty($location_id)) {
							$location_ids[$item['product_id']] = $location_id;
						}

						$location = alp_pro_addon()->admin->get_data_byid($location_id);
						if (!empty($location_id) && isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
							$appt_session_data = unserialize(WC()->session->get('appt_data'));
							$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : gmdate('d-m-Y', time() + 86400);
							$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';

							$appt_data[$order_id]['location_id'] = $location_id;
							$appt_data[$order_id]['pickup_date'] = $date;//gmdate('d-m-Y', strtotime($date));
							$appt_data[$order_id]['pickup_time'] = $time;
						}

						//order meta use only for Automation
						$order->update_meta_data( 'alp_automation_location_id', $location_id );
						$order->save();

					}

				}

				if ( ( !isset($wclp_local_pickup_controls['allow_mixed_orders'] )
				|| 0 == $wclp_local_pickup_controls['allow_mixed_orders'] )
				&& ( !isset( $wclp_local_pickup_controls['allow_pickup_per_item'] )
				|| 0 == $wclp_local_pickup_controls['allow_pickup_per_item'] ) ) {

					$session_data = WC()->session->get('pickup_location_id');
					$location_id = !empty($session_data) ? $session_data : '';

					if (!empty($location_id)) {
						$location_ids[$item['product_id']] = $location_id;
					}

					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					if (!empty($location_id) && isset($location->store_enable_appt) && '1' == $location->store_enable_appt && isset($wclp_local_pickup_controls['allow_pickup_per_item']) && 1 != $wclp_local_pickup_controls['allow_pickup_per_item']) {
						$appt_session_data = unserialize(WC()->session->get('appt_data'));
						$date = isset($appt_session_data['date']) ? $appt_session_data['date'] : gmdate('d-m-Y', time() + 86400);
						$time = isset($appt_session_data['time']) ? $appt_session_data['time'] : '';

						$appt_data[$order_id]['location_id'] = $location_id;
						$appt_data[$order_id]['pickup_date'] = $date;//gmdate('d-m-Y', strtotime($date));
						$appt_data[$order_id]['pickup_time'] = $time;
					}

					if (!empty($location_id)) {
						//order meta use only for Automation
						$order->update_meta_data( 'alp_automation_location_id', $location_id );
						$order->save();
					}
				}
			}
		}
		if (!empty($location_ids)) {
			$order->update_meta_data( 'alp_location_ids', $location_ids );
			$order->save();
		}
		if (!empty($appt_data)) {
			$order->update_meta_data( 'alp_appt_data', $appt_data );
			$order->save();
		}
	}

	/*
	 * Checkout validation error display
	 *
	 * @since  1.0
	 */
	public function after_checkout_validation( $fields, $errors ) {

		$checkout_nonce = isset($_REQUEST['woocommerce-process-checkout-nonce']) ? sanitize_text_field($_REQUEST['woocommerce-process-checkout-nonce']) : '';
		$_wpnonce = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
		$nonce_value = wc_get_var( $checkout_nonce, wc_get_var( $_wpnonce, '' ) ); // @codingStandardsIgnoreLine.

		if ( !function_exists('run_thwmsc') ) {
			if ( empty( $nonce_value ) || ! wp_verify_nonce( $nonce_value, 'woocommerce-process_checkout' ) ) {
				WC()->session->set( 'refresh_totals', true );
				throw new Exception( __( 'We were unable to process your order, please try again.', 'advanced-local-pickup-pro' ) );
			}
		}

		if (isset($_POST['selected_pickup_location']) && empty($_POST['selected_pickup_location']) || isset($_POST['selected_location']) && empty($_POST['selected_location'])) {
			$pickup_location_message = esc_html__('Please select a location for pickup items.', 'advanced-local-pickup-pro');
			$errors->add('validation', $pickup_location_message);
		}
		
		$selected_location = isset($_POST['selected_location']) && !empty($_POST['selected_location']) ? sanitize_text_field($_POST['selected_location']) : '';
		$selected_pickup_location = isset($_POST['selected_pickup_location']) && !empty($_POST['selected_pickup_location']) ? sanitize_text_field($_POST['selected_pickup_location']) : $selected_location;
		
		$location = alp_pro_addon()->admin->get_data_byid($selected_pickup_location);
		if (isset($location->store_enable_appt) && 1 == $location->store_enable_appt) {
			if (isset($_POST['appt_date_option']) && empty($_POST['appt_date_option'])) { 
				$message = esc_html__('Please select pick up date.', 'advanced-local-pickup-pro');
				$errors->add('validation', $message);
			}
	
			if (isset($_POST['appt_time_option']) && empty($_POST['appt_time_option'])) {
				$message = esc_html__('Please select pick up time.', 'advanced-local-pickup-pro');
				$errors->add('validation', $message);
			}
		}

	}

	/**
	 * Update order status after WooCommerce set an order status as completed
	 */
	public function update_order_status_after_completed( $order_id ) {

		$ready_for_pickup = get_option('wclp_status_ready_pickup', 0);
		if (true == $ready_for_pickup) {
			$order = wc_get_order( $order_id );
			$location_id = $order->get_meta( 'alp_automation_location_id', true );
			$location = alp_pro_addon()->admin->get_data_byid($location_id);
			if (isset($location->store_enable_appt) && 1 != $location->store_enable_appt && isset($location->store_enable_automation) && 1 == $location->store_enable_automation) {
				$order = new WC_Order($order_id);
				$order->update_status('ready-pickup');
			}
		}

	}

	/**
	 * Update order status Processing LP after payment is completed
	 */
	public function update_order_status_to_processing_lp( $order_status, $order_id ) {

		$processing_lp = get_option( 'wclp_status_processing_lp', 0);
		if ( '1' == get_option('enable_processing_lp_automation', '0') && true == $processing_lp ) {
			if ( !isset($_GET['preview']) ) {
				$order = wc_get_order($order_id);
				$shipping_methods = isset($order) ? $order->get_items( 'shipping' ) : '';
				if ( 1 == count( $shipping_methods ) && $order->has_shipping_method('local_pickup')) {				
					return 'processing-lp';
				}
			}
		}

		return $order_status;
	}

	/**
	 * Add pickup details in line item meta data
	 */
	public function alp_display_order_meta_data_in_order_admin( $order_id ) {
		$order = wc_get_order( $order_id );
		$display_location_id = $order->get_meta( 'display_order_meta', true );
		$alp_location_ids = $order->get_meta( 'alp_location_ids', true );
		$alp_appt_data = $order->get_meta( 'alp_appt_data', true );
		
		if (!empty($alp_location_ids)) {
			$order = wc_get_order($order_id);
			$items = $order->get_items();
			$product_data = array();
			
			foreach ( $alp_location_ids as $id => $uid) {
				foreach ( $items as $item ) {
					$item_id = $item->get_id();
					$product_id = $item->get_product_id();
					if ($id == $item_id || $id == $product_id) { 
						$product_name = $item->get_name();
						$qty = $item->get_quantity();
						$sku = $item->get_product()->get_sku();
					}
					if ( isset($alp_appt_data) && !empty($alp_appt_data) ) {
						if ( isset($alp_appt_data[$order_id][$id]) ) {
							$val = $alp_appt_data[$order_id][$id];
							$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
							$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
						} else {
							$val = $alp_appt_data[$order_id];
							$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
							$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
						}
					}
				}

				$new_product_data[$id] = array(
					'location_id' => $uid,
					'date'	=> isset($date) ? $date : '',
					'time' =>  isset($time) ? $time : '',
					'product' => $product_name . '(' . $sku . ') x ' . $qty,
				);
			}
			
			$outputArray = isset($new_product_data) ? alp_pro_addon()->common->get_grouping_array_of_appt_data($new_product_data) : array();

			if (!empty($outputArray)) {

				foreach ($outputArray as $data) {
					?>
					<table cellpadding="0" cellspacing="0" class="woocommerce_order_items">
					<tbody id="alp--order_line_items">
						<tr class="alp--order_meta_details">
							<td class="thumb"><div></div></td>
							<td class="name">
							<?php
							$location = alp_pro_addon()->admin->get_data_byid($data['location_id']);

							$country_code = isset($location) ? $location->store_country : get_option('woocommerce_default_country');

							$item_location = $location->store_name;

							$appt_details = '';
							if (isset($data['date']) && !empty($data['date']) && isset($data['time']) && !empty($data['time']) ) {
								$appt_details = gmdate(get_option('date_format'), strtotime($data['date'])) . ' ' . $data['time'];
							}
							?>
							<div class="pickup-instruction items">
								<?php if (!empty($item_location)) { ?>
									<p><strong><?php esc_html_e('Pickup Location: ', 'advanced-local-pickup-pro'); ?></strong><?php echo esc_html($item_location); ?></p>
								<?php
								}
								?>
								<?php if (!empty($data['product'])) { ?>
									<p><strong><?php esc_html_e('Items: ', 'advanced-local-pickup-pro'); ?></strong><?php echo esc_html($data['product']); ?></p>
								<?php
								}
								?>
								<?php if (!empty($appt_details)) { ?>
									<p><strong><?php esc_html_e('Appointment Detail: ', 'advanced-local-pickup-pro'); ?></strong><?php echo esc_html($appt_details); ?></p>
								<?php
								}
								?>
							</div>
						</td>
						<td></td>
						<td></td>
						<td></td>
						<td></td>
					</tr>
				</tbody>
				</table>
				<?php
				}
			}
		} else { 
			if (!empty($display_location_id)) { 
				$location = alp_pro_addon()->admin->get_data_byid($display_location_id);
				if ( empty($location) ) {
					return;
				}
				?>
				<table cellpadding="0" cellspacing="0" class="woocommerce_order_items">
				<tbody id="alp--order_line_items">
					<tr class="alp--order_meta_details">
						<td class="thumb"><div></div></td>
						<td class="name">
						<?php
						
						$country_code = isset($location) ? $location->store_country : get_option('woocommerce_default_country');
						$split_country = explode(':', $country_code);

						$item_location = isset($location->store_name) ? $location->store_name : '';   

						$appt_details = '';
						if (isset($alp_appt_data) && !empty($alp_appt_data)) {
							$appt_details = is_array($alp_appt_data[$location_id]) ? esc_html(implode(', ', $alp_appt_data[$location_id])) : esc_html($alp_appt_data[$location_id]);
						}
						?>
							<div class="pickup-instruction">
								<?php if (!empty($item_location)) { ?>
									<p><strong><?php esc_html_e('Pickup Location: ', 'advanced-local-pickup-pro'); ?></strong><?php echo esc_html($item_location); ?></p>
								<?php
								}
								?>
								<?php if (!empty($appt_details)) { ?>
									<p><strong><?php esc_html_e('Appointment Detail: ', 'advanced-local-pickup-pro'); ?></strong><?php echo esc_html($appt_details); ?></p>
								<?php
								} 
								?>
							</div>
						</td>
						<td></td>
						<td></td>
						<td></td>
						<td></td>
					</tr>
				</tbody>
				</table>
			<?php
			}
		}
	}

	/**
	 * Add selected pickup location id in order meta to display location
	 */
	public function alp_add_location_id_in_ordermeta_to_display_location( $order_id ) {

		$order = wc_get_order($order_id);

		// Iterating through order shipping items
		foreach ($order->get_items('shipping') as $item_id => $shipping_item_obj) {
			$shipping_method = $shipping_item_obj->get_method_id();
		}

		//IF  shipping method is not local pickup then @return;
		if (!isset($shipping_method)) {
			return;
		}
		if (isset($shipping_method) && 'local_pickup' != $shipping_method) {
			return;
		}

		$wclp_local_pickup_controls = get_option('wclp_local_pickup_controls');

		if (isset($wclp_local_pickup_controls['allow_mixed_orders']) && 1 != $wclp_local_pickup_controls['allow_mixed_orders'] || ( 1 == $wclp_local_pickup_controls['allow_mixed_orders'] && count(WC()->cart->get_cart()) < 2 )) {

			$session_data = WC()->session->get('pickup_location_id');
			$location_id = !empty($session_data) ? $session_data : '';
			if (empty($location_id)) {
				return;
			}
			$order->update_meta_data( 'display_order_meta', $location_id );
			$order->save();

		}

	}

	/**
	 * Get time array by slot(duration)
	 */
	public function get_reschadule_options_html( $order_id, $location_id, $pickup_items, $Appt_data ) {

		if (!is_wc_endpoint_url('view-order') || !isset($_GET['wcs_renewal_order']) || true != $_GET['wcs_renewal_order']) {
			return;
		}

		$locations = alp_pro_addon()->admin->get_available_locations_data();

		?>
		<div class="reschedule pickup-instruction">
			<span style="line-height: 1.3;"><strong><?php esc_html_e('Reschedule Pickup Location:', 'advanced-local-pickup-pro'); ?></strong></span>
			<form method="post" id="wclp_reschadule_pickup_form">
				<input type="hidden" name="order_id" value="<?php echo esc_attr($order_id); ?>" >
				<input type="hidden" name="pickup_items" value="<?php echo esc_attr(implode(',', $pickup_items)); ?>" >
				<p class="reschedule-pickup-fields" style="display:flex;">
				<select class="select alp_location--reschadule reschadule_location" name="reschadule_location" style="width: auto;min-width: 250px;margin: 5px 5px 0 0;">
						<option value=""><?php esc_html_e('Select a pickup location', 'advanced-local-pickup-pro'); ?></option>
						<?php
						foreach ((array) $locations as $key => $location) {
							$availble_pickup = true;
							foreach ((array) $pickup_items as $product_id) {
								if (!alp_pro_addon()->common->is_local_pickup_item_by_location($product_id, $location)) {
									$availble_pickup = false;
								}
							}
							if (isset($location->store_enable) && 1 == $location->store_enable && $availble_pickup) {
								?>
									<option value="<?php echo esc_html( $location->id ); ?>" <?php echo( $location_id == $location->id ) ? 'selected' : ''; ?>><?php echo esc_html(alp_pro_addon()->admin->get_slaches_data_byid( $location->store_name )); ?></option>
								<?php
							}
						}

						?>
				</select>
				<?php
				if (!empty($Appt_data)) {
					$location = alp_pro_addon()->admin->get_data_byid($location_id);
					$store_days = isset($location->store_appt_days) ? unserialize($location->store_appt_days) : get_option('wclp_store_days');
					for ($i = 1; $i < 8; $i++) {
						$defualt_date = strtotime('+' . $i . ' day');
						$new_format = gmdate('j-n-Y', $defualt_date);
						$dayofweek = gmdate('l', strtotime($new_format));
						if (isset($store_days[strtolower($dayofweek)]['checked']) && '1' == $store_days[strtolower($dayofweek)]['checked']) {
							$new_format = gmdate('d-m-Y', $defualt_date);
							break;
						}
					}
			$same_day = isset($location->store_appt_start_date) && 1 == $location->store_appt_start_date ? 0 : 1;
			$days = isset($location->store_appt_first_date) ? $location->store_appt_first_date : $same_day;

			$defualt_date = strtotime('+' . $days . ' day');
			$new_format = gmdate('d-m-Y', $defualt_date);
			$date = $new_format;

					?>
					<input type="text" name ="appt_date_option" class="datepicker alp_location--reschadule_date" value="<?php //echo esc_html(gmdate( get_option('date_format'), strtotime($date) )); ?>
					" style="display:none;width: auto;min-width: 250px;margin: 5px 5px 0 0;" readonly>
					<select class="select alp_location--reschadule_time" name="appt_time_option" style="display:none;width: auto;min-width: 250px;margin: 5px 5px 0 0;"> 
						<option value="" ><?php esc_html_e('Select time', 'advanced-local-pickup-pro'); ?></option>
					</select>
				<?php
				}
				?>
				</p>
				<button name="save" class="alp_reschadule--update button-primary woocommerce-save-button" type="submit"><?php esc_html_e('Update', 'advanced-local-pickup-pro'); ?></button>
				<input type="hidden" name="action" value="alp_reschadule_pickup_form_update">				
			</form>
		</div>
		<?php
	}

	/**
	 * Run on removed item on checkout
	 */
	public function run_on_removed_cart_item( $cart_item_key, $cart ) {
		foreach (WC()->cart->get_cart() as $item_key => $item) {
			if ($item_key === $cart_item_key) {
				if (isset($item['product_id']) && alp_pro_addon()->common->is_local_pickup_item($item['product_id'])) {
					WC()->session->__unset($cart_item_key);
					WC()->session->set('chosen_shipping_methods', array('flat_rate'));
				}
			}
		}

	}

	


}
