<?php
/**
 * Order details table shown in emails.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/email-order-details.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates/Emails
 * @version 3.3.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$text_align = is_rtl() ? 'right' : 'left'; 
$margin_side = is_rtl() ? 'left' : 'right';

do_action( 'alp_email_before_order_table', $order, $sent_to_admin, $plain_text, $email );

$table_font_size = '';
$kt_woomail = get_option( 'kt_woomail' );
if ( !empty($kt_woomail) && isset( $kt_woomail['font_size'] ) ) {
	$table_font_size = 'font-size:' . $kt_woomail['font_size'] . 'px';	
}

$order_id = $order->get_id();
$locations = alp_pro_addon()->admin->get_data();
$location_ids = $order ? $order->get_meta( 'alp_location_ids', true ) : '';

$preview_id = get_option( 'selected_order_id', 'mockup' );
if ( empty($location_ids) && !empty($locations) ) {
	$location_ids = array();
	if (empty($location_ids)) { 
		$items = $order->get_items();
		foreach ( $order->get_items() as $item ) {
			$item_id = $item->get_id();
			$location_ids[$item_id] = get_option('location_defualt', min($locations)->id);
		}
	} else {
		$location_ids = array( get_option('location_defualt', min($locations)->id) );
	}
	
}

if (is_array($location_ids)) { 
	?>
<div class="order-items-list" style="margin-bottom: 20px;">
		<table class="td" cellspacing="0" cellpadding="6" style="width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;border:0;<?php echo esc_html($table_font_size); ?>" border="0">
			<tbody>
				<?php
				foreach ( $location_ids as $item_id => $location_id ) {
					$all_ids[$location_id][] = $item_id; 

					$appt_data = $order ? $order->get_meta( 'alp_appt_data', true ) : '';
					if ( isset($appt_data) && !empty($appt_data) ) {
						if ( isset($appt_data[$order->get_id()][$item_id]) ) {
							$val = $appt_data[$order->get_id()][$item_id];
							$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
							$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
						} else {
							$val = $appt_data[$order->get_id()];
							$date = isset( $val[ 'pickup_date' ] ) ? $val[ 'pickup_date' ] : '';
							$time = isset( $val[ 'pickup_time' ] ) ? $val[ 'pickup_time' ] : '';
						}
					}
					
					$new_product_data[$item_id] = array(
						'location_id' =>  isset($location_id) ? $location_id : '',
						'date'	=> isset($date) ? $date : '',
						'time' =>  isset($time) ? $time : '',
					);
				}
				$outputArray = isset($new_product_data) ? alp_pro_addon()->common->get_grouping_array_of_appt_data($new_product_data) : array();
				if ( !empty($location_ids) && 'customer_ready_pickup_order' !== $email->id && 'customer_processing_lp_order' !== $email->id && !empty($email->id) ) { 
					?>
						<tr><td colspan="3" style="padding:0;padding-top: 5px;border-bottom:1px solid #e0e0e0;"><h2 class="pickup_items_heading"><?php echo esc_html($pickup_items_heading); ?></h2></td><tr>	
				<?php 
				}
				
				foreach ( $outputArray as $value ) {

					if ( '' == $email->id && ( !empty($locationID) && $locationID != $value['location_id'] ) ) {
						continue;
					}

					if ( 'customer_ready_pickup_order' == $email->id || 'customer_processing_lp_order' == $email->id ) {
						?>
							<tr><td colspan="3" style="padding:0;padding-top:10px;">
							<?php
							$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-instruction.php';
							if ( file_exists( $local_template ) && is_writable( $local_template )) {
								wc_get_template( 'emails/ready-for-pickup-instruction.php', array( 'location_id' => $value['location_id'], 'order_id' => $order_id, 'data' => $value ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
							} else {
								wc_get_template( 'emails/ready-for-pickup-instruction.php', array( 'location_id' => $value['location_id'], 'order_id' => $order_id, 'data' => $value ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
							}
							?>
							</td></tr>
							<tr><td colspan="3" style="padding:0;padding-top: 5px;border-bottom:1px solid #e0e0e0;"><h2 class="pickup_items_heading"><?php echo esc_html($pickup_items_heading); ?></h2></td><tr>
						<?php 
					}
					if ( '' == $email->id ) {
						?>
							<tr><td colspan="3" style="padding:0;padding-top:10px;">
							<?php
							$local_template	= get_stylesheet_directory() . '/woocommerce/emails/pickup-reminder-instruction.php';
							if ( file_exists( $local_template ) && is_writable( $local_template )) {
								wc_get_template( 'emails/pickup-reminder-instruction.php', array( 'location_id' => $value['location_id'], 'order_id' => $order_id, 'data' => $value ), 'advanced-local-pickup-pro/', get_stylesheet_directory() . '/woocommerce/' );
							} else {
								wc_get_template( 'emails/pickup-reminder-instruction.php', array( 'location_id' => $value['location_id'], 'order_id' => $order_id, 'data' => $value ), 'advanced-local-pickup-pro/', alp_pro_addon()->get_plugin_path() . '/templates/' );	
							}
							?>
							</td></tr>
							<tr><td colspan="3" style="padding:0;padding-top: 5px;border-bottom:1px solid #e0e0e0;"><h2 class="pickup_items_heading"><?php echo esc_html($pickup_items_heading); ?></h2></td><tr>
						<?php
					}

					foreach ( $order->get_items() as $item_id => $item ) :
						$product       = $item->get_product();
						$image         = '';
						$image_size = array( 64, 64 );
						$product_id = $item->get_product_id();

						if ( !in_array( $item->get_id(), $value['ids']) && !in_array( $product_id, $value['ids']) ) {
							continue;
						}

						if ( is_object( $product ) ) {
							$image         = $product->get_image( $image_size );
						} else {
							$image         = '<img src=' . esc_url( alp_pro_addon()->plugin_dir_url() ) . 'assets/images/dummy-product-image.jpg>';
						}
						
						?>
						<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_order_item_class', 'order_item', $item, $order ) ); ?> item-row">
							<?php if ($display_product_images) { ?>
							<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align: middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; word-wrap:break-word;border-left:0;border:0;border-bottom:1px solid #e0e0e0;padding: 12px 5px;width: 70px;">
								<?php echo wp_kses_post( apply_filters( 'woocommerce_order_item_thumbnail', $image, $item ) ); ?>
							</td>
							<?php } ?>
							<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align: middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; word-wrap:break-word;border-left:0;border:0;border-bottom:1px solid #e0e0e0;padding: 12px 5px;">
								<?php
								// Product name.
								echo wp_kses_post( apply_filters( 'woocommerce_order_item_name', $item->get_name(), $item, false ) ); 
								echo ' x ';
								echo esc_html($item->get_quantity()); 
								?>
							</td>
							<?php if ($display_product_prices) { ?>
							<td class="td" style="text-align:<?php echo esc_attr( $margin_side ); ?>; vertical-align: middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; word-wrap:break-word;border-left:0;border:0;border-bottom:1px solid #e0e0e0;padding: 12px 5px;">
								<?php echo wp_kses_post( $order->get_formatted_line_subtotal( $item ) ); ?>
							</td>
							<?php } ?>	
						</tr>
				<?php endforeach; } ?>
			</tbody>			
		</table>
	</div>
	<style>
	@media screen and (max-width: 400px) {
		.pickup_items_heading{
			font-size: 12px !important;
		}
	}
	</style>
<?php } ?>
<?php do_action( 'alp_email_after_order_table', $order, $sent_to_admin, $plain_text, $email ); ?>
